<?php
/**
 * Registers Custom Field for the plugin.
 *
 * @package    AdveitsPortfolio
 * @subpackage Includes
 * @author     Adveits <support@adveits.com>
 * @copyright  Copyright (c) 2019, Adveits
 * @link       https://store.adveits.com/
 * @license    https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Check if ACF exists.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
if ( function_exists('acf_add_local_field_group' ) ) {
    add_action( 'acf/init', 'adveits_portfolio_register_custom_field' );
} else {
    add_action( 'admin_notices', 'adveits_portfolio_register_custom_field_warning' );
}

/**
 * Register custom field.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function adveits_portfolio_register_custom_field() {
    acf_add_local_field_group(array(
        'key' => 'group_5d94bf988de1d',
        'title' => 'Gallery',
        'fields' => array(
            array(
                'key' => 'field_5d94bf9cf145a',
                'label' => 'Images',
                'name' => 'adveits_portfolio_images',
                'type' => 'repeater',
                'instructions' => '',
                'required' => 0,
                'conditional_logic' => 0,
                'wrapper' => array(
                    'width' => '',
                    'class' => '',
                    'id' => ''
                ),
                'collapsed' => '',
                'min' => 0,
                'max' => 0,
                'layout' => 'table',
                'button_label' => '',
                'sub_fields' => array(
                    array(
                        'key' => 'field_5d94c0bd36138',
                        'label' => 'Image',
                        'name' => 'adveits_portfolio_image',
                        'type' => 'image',
                        'instructions' => '',
                        'required' => 0,
                        'conditional_logic' => 0,
                        'wrapper' => array(
                            'width' => '',
                            'class' => '',
                            'id' => ''
                        ),
                        'return_format' => 'array',
                        'preview_size' => 'medium',
                        'library' => 'all',
                        'min_width' => '',
                        'min_height' => '',
                        'min_size' => '',
                        'max_width' => '',
                        'max_height' => '',
                        'max_size' => '',
                        'mime_types' => ''
                    )
                )
            )
        ),
        'location' => array(
            array(
                array(
                    'param' => 'post_type',
                    'operator' => '==',
                    'value' => adveits_portfolio_get_item_post_type()
                )
            )
        ),
        'menu_order' => 0,
        'position' => 'acf_after_title',
        'style' => 'default',
        'label_placement' => 'top',
        'instruction_placement' => 'label',
        'hide_on_screen' => '',
        'active' => true,
        'description' => ''
    ));
}

/**
 * Admin notice if no ACF plugin.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function adveits_portfolio_register_custom_field_warning() {
    $theme_name                = wp_get_theme()->get( 'TextDomain' );
    $theme_plugin_required_url = admin_url( 'themes.php?page=welcome_to_'. $theme_name .'_theme#install-plugins' );
    ?>

    <div class="error">
        <p><?php printf( esc_html__( 'The %s must be installed and activated!', 'adveits-portfolio' ), '<a href="'. $theme_plugin_required_url .'">Advanced Custom Fields PRO</a>' ); ?></p>
    </div>
<?php }
