<?php
/**
 * Hooks into the Members plugin and registers capabilities.
 *
 * @package    AdveitsPortfolio
 * @subpackage Includes
 * @author     Adveits <support@adveits.com>
 * @copyright  Copyright (c) 2019, Adveits
 * @link       https://store.adveits.com/
 * @license    https://www.gnu.org/licenses/gpl-2.0.html
 */

# Register cap groups.
add_action( 'members_register_cap_groups', 'adveits_portfolio_register_cap_groups' );

# Register caps.
add_action( 'members_register_caps', 'adveits_portfolio_register_caps' );

/**
 * Overwrites the cap group registered within the Members plugin.  We want
 * the label to read "Portfolio".
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function adveits_portfolio_register_cap_groups() {
	$group = members_get_cap_group( 'type-' . adveits_portfolio_get_item_post_type() );

	if ( $group ) {
		$group->label = __( 'Portfolio', 'adveits-portfolio' );
	}
}

/**
 * Registers caps with the Members plugin.  This gives pretty labels for each
 * of the capabilities.
 *
 * @since  1.0.0
 * @access public
 * @return void
 */
function adveits_portfolio_register_caps() {
	$caps  = array();
	$group = sprintf( 'type-%s', adveits_portfolio_get_item_post_type() );

	// Item caps.
	$caps['create_adveits_portfolio_items']           = __( 'Create Projects',           'adveits-portfolio' );
	$caps['edit_adveits_portfolio_items']             = __( 'Edit Projects',             'adveits-portfolio' );
	$caps['edit_others_adveits_portfolio_items']      = __( "Edit Others' Projects",     'adveits-portfolio' );
	$caps['read_private_adveits_portfolio_items']     = __( 'Read Private Projects',     'adveits-portfolio' );
	$caps['delete_adveits_portfolio_items']           = __( 'Delete Projects',           'adveits-portfolio' );
	$caps['delete_private_adveits_portfolio_items']   = __( 'Delete Private Projects',   'adveits-portfolio' );
	$caps['delete_published_adveits_portfolio_items'] = __( 'Delete Published Projects', 'adveits-portfolio' );
	$caps['delete_others_adveits_portfolio_items']    = __( "Delete Others' Projects",   'adveits-portfolio' );
	$caps['edit_private_adveits_portfolio_items']     = __( 'Edit Private Projects',     'adveits-portfolio' );
	$caps['edit_published_adveits_portfolio_items']   = __( 'Edit Published Projects',   'adveits-portfolio' );
	$caps['publish_adveits_portfolio_items']          = __( 'Publish Projects',          'adveits-portfolio' );

	// Category caps.
	$caps['assign_adveits_portfolio_categories'] = __( 'Assign Project Categories', 'adveits-portfolio' );
	$caps['delete_adveits_portfolio_categories'] = __( 'Delete Project Categories', 'adveits-portfolio' );
	$caps['edit_adveits_portfolio_categories']   = __( 'Edit Project Categories',   'adveits-portfolio' );
	$caps['manage_adveits_portfolio_categories'] = __( 'Manage Project Categories', 'adveits-portfolio' );

	// Tag caps.
	$caps['assign_adveits_portfolio_tags'] = __( 'Assign Project Tags', 'adveits-portfolio' );
	$caps['delete_adveits_portfolio_tags'] = __( 'Delete Project Tags', 'adveits-portfolio' );
	$caps['edit_adveits_portfolio_tags']   = __( 'Edit Project Tags',   'adveits-portfolio' );
	$caps['manage_adveits_portfolio_tags'] = __( 'Manage Project Tags', 'adveits-portfolio' );

	// Register each of the capabilities
	foreach ( $caps as $name => $label )
		members_register_cap( $name, array( 'label' => $label, 'group' => $group ) );
}
