<?php
/**
 * Plugin options functions.
 *
 * @package    AdveitsPortfolio
 * @subpackage Includes
 * @author     Adveits <support@adveits.com>
 * @copyright  Copyright (c) 2019, Adveits
 * @link       https://store.adveits.com/
 * @license    https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Returns the portfolio title.
 *
 * @since  1.0.0
 * @access public
 * @return string
 */
function adveits_portfolio_get_portfolio_title() {
	return apply_filters( 'adveits_portfolio_get_portfolio_title', adveits_portfolio_get_setting( 'portfolio_title' ) );
}

/**
 * Returns the portfolio rewrite base. Used for the item archive and as a prefix for taxonomy,
 * author, and any other slugs.
 *
 * @since  1.0.0
 * @access public
 * @return string
 */
function adveits_portfolio_get_portfolio_rewrite_base() {
	return apply_filters( 'adveits_portfolio_get_portfolio_rewrite_base', adveits_portfolio_get_setting( 'portfolio_rewrite_base' ) );
}

/**
 * Returns the item rewrite base. Used for single items.
 *
 * @since  1.0.0
 * @access public
 * @return string
 */
function adveits_portfolio_get_item_rewrite_base() {
	return apply_filters( 'adveits_portfolio_get_item_rewrite_base', adveits_portfolio_get_setting( 'item_rewrite_base' ) );
}

/**
 * Returns the category rewrite base. Used for category archives.
 *
 * @since  1.0.0
 * @access public
 * @return string
 */
function adveits_portfolio_get_category_rewrite_base() {
	return apply_filters( 'adveits_portfolio_get_category_rewrite_base', adveits_portfolio_get_setting( 'category_rewrite_base' ) );
}

/**
 * Returns the tag rewrite base. Used for tag archives.
 *
 * @since  1.0.0
 * @access public
 * @return string
 */
function adveits_portfolio_get_tag_rewrite_base() {
	return apply_filters( 'adveits_portfolio_get_tag_rewrite_base', adveits_portfolio_get_setting( 'tag_rewrite_base' ) );
}

/**
 * Returns the default category term ID.
 *
 * @since  1.0.0
 * @access public
 * @return int
 */
function adveits_portfolio_get_default_category() {
	return apply_filters( 'adveits_portfolio_get_default_category', 0 );
}

/**
 * Returns the default tag term ID.
 *
 * @since  1.0.0
 * @access public
 * @return int
 */
function adveits_portfolio_get_default_tag() {
	return apply_filters( 'adveits_portfolio_get_default_tag', 0 );
}

/**
 * Returns a plugin setting.
 *
 * @since  1.0.0
 * @access public
 * @param  string  $setting
 * @return mixed
 */
function adveits_portfolio_get_setting( $setting ) {
	$defaults = adveits_portfolio_get_default_settings();
	$settings = wp_parse_args( get_option( 'adveits_portfolio_settings', $defaults ), $defaults );

	return isset( $settings[ $setting ] ) ? $settings[ $setting ] : false;
}

/**
 * Returns the default settings for the plugin.
 *
 * @since  1.0.0
 * @access public
 * @return array
 */
function adveits_portfolio_get_default_settings() {
	$settings = array(
		'portfolio_title'        => __( 'Portfolio', 'adveits-portfolio' ),
		'portfolio_rewrite_base' => 'portfolio',
		'item_rewrite_base'      => '',
		'category_rewrite_base'  => 'categories',
		'tag_rewrite_base'       => 'tags'
	);

	return $settings;
}
