<?php
/**
 * General template tags for theme authors to use in their themes.
 *
 * @package    AdveitsPortfolio
 * @subpackage Includes
 * @author     Adveits <support@adveits.com>
 * @copyright  Copyright (c) 2019, Adveits
 * @link       https://store.adveits.com/
 * @license    https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Conditional tag to check if viewing any portfolio page.
 *
 * @since  1.0.0
 * @access public
 * @param  mixed  $term
 * @return bool
 */
function adveits_portfolio_is_portfolio() {
	$is_portfolio = adveits_portfolio_is_archive() || adveits_portfolio_is_single_item();

	return apply_filters( 'adveits_portfolio_is_portfolio', $is_portfolio );
}

/**
 * Conditional tag to check if viewing any type of portfolio archive page.
 *
 * @since  1.0.0
 * @access public
 * @return bool
 */
function adveits_portfolio_is_archive() {
	$is_archive = adveits_portfolio_is_item_archive() || adveits_portfolio_is_category() || adveits_portfolio_is_tag();

	return apply_filters( 'adveits_portfolio_is_archive', $is_archive );
}

/**
 * Conditional tag to check if viewing a portfolio category archive.
 *
 * @since  1.0.0
 * @access public
 * @param  mixed  $term
 * @return bool
 */
function adveits_portfolio_is_category( $term = '' ) {
	return apply_filters( 'adveits_portfolio_is_category', is_tax( adveits_portfolio_get_category_taxonomy(), $term ) );
}

/**
 * Conditional tag to check if viewing a portfolio tag archive.
 *
 * @since  1.0.0
 * @access public
 * @param  mixed  $term
 * @return bool
 */
function adveits_portfolio_is_tag( $term = '' ) {
	return apply_filters( 'adveits_portfolio_is_tag', is_tax( adveits_portfolio_get_tag_taxonomy(), $term ) );
}
