<?php
/**
 * Template tags related to portfolio items for theme authors to use in their theme templates.
 *
 * @package    AdveitsPortfolio
 * @subpackage Includes
 * @author     Adveits <support@adveits.com>
 * @copyright  Copyright (c) 2019, Adveits
 * @link       https://store.adveits.com/
 * @license    https://www.gnu.org/licenses/gpl-2.0.html
 */

/**
 * Makes sure the post ID is an absolute integer if passed in.  Else, returns the result
 * of `get_the_ID()`.
 *
 * @since  1.0.0
 * @access public
 * @param  int     $post_id
 * @return int
 */
function adveits_portfolio_get_item_id( $post_id = '' ) {
	return $post_id ? absint( $post_id ) : get_the_ID();
}

/**
 * Checks if viewing a single item.
 *
 * @since  1.0.0
 * @access public
 * @param  mixed  $post
 * @return bool
 */
function adveits_portfolio_is_single_item( $post = '' ) {
	$is_single = is_singular( adveits_portfolio_get_item_post_type() );

	if ( $is_single && $post )
		$is_single = is_single( $post );

	return apply_filters( 'adveits_portfolio_is_single_item', $is_single, $post );
}

/**
 * Checks if viewing the item archive.
 *
 * @since  1.0.0
 * @access public
 * @return bool
 */
function adveits_portfolio_is_item_archive() {
	return apply_filters( 'adveits_portfolio_is_item_archive', is_post_type_archive( adveits_portfolio_get_item_post_type() )  );
}

/**
 * Checks if the current post is a item.
 *
 * @since  1.0.0
 * @access public
 * @param  int     $post_id
 * @return bool
 */
function adveits_portfolio_is_item( $post_id = '' ) {
	$post_id = adveits_portfolio_get_item_id( $post_id );

	return apply_filters( 'adveits_portfolio_is_item', adveits_portfolio_get_item_post_type() === get_post_type( $post_id ), $post_id );
}
