<?php
//=================================================
// Elementor
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

//=================================================
// Admin preview/editor style
//=================================================
function loversy_core_elementor_admin_editor_styles() {
    wp_enqueue_style( 'loversy-core-elementor-editor-style', LOVERSY_CORE_BASE_URL . '/inc/elementor/assets/css/elementor-editor-style.css', array(), LOVERSY_CORE_VERSION );
}

add_action( 'elementor/editor/after_enqueue_styles', 'loversy_core_elementor_admin_editor_styles' );

//=================================================
// Admin preview inline script
//=================================================
function loversy_core_elementor_admin_preview_inline_script() { ?>
    <script>
        ( function( $ ) {
            var Widget_Loversy_Gallery = function( $scope, $ ) {
                var swiper_adv_slider = new Swiper ('.adv-slider .adv-swiper-container', {
                    noSwipingClass: 'adv-swiper-no-swiping',
                    containerModifierClass: 'adv-swiper-container-',
                    slideClass: 'adv-swiper-slide',
                    slideBlankClass: 'adv-swiper-slide-invisible-blank',
                    slideActiveClass: 'adv-swiper-slide-active',
                    slideDuplicateActiveClass: 'adv-swiper-slide-duplicate-active',
                    slideVisibleClass: 'adv-swiper-slide-visible',
                    slideDuplicateClass: 'adv-swiper-slide-duplicate',
                    slideNextClass: 'adv-swiper-slide-next',
                    slideDuplicateNextClass: 'adv-swiper-slide-duplicate-next',
                    slidePrevClass: 'adv-swiper-slide-prev',
                    slideDuplicatePrevClass: 'adv-swiper-slide-duplicate-prev',
                    wrapperClass: 'adv-swiper-wrapper',
                    navigation: {
                        disabledClass: 'adv-swiper-button-disabled',
                        hiddenClass: 'adv-swiper-button-hidden',
                        lockClass: 'adv-swiper-button-lock',
                        nextEl: '.adv-2-swiper-button-next',
                        prevEl: '.adv-2-swiper-button-prev'
                    },
                    spaceBetween: 0
                });
            };

            $( window ).on( 'elementor/frontend/init', function() {
                // Gallery
                elementorFrontend.hooks.addAction( 'frontend/element_ready/loversy-gallery.default', Widget_Loversy_Gallery );
            } );
        } )( jQuery );
    </script>
<?php }

if ( defined( 'ELEMENTOR_VERSION' ) && isset( $_GET['elementor-preview'] ) ) {
    add_action( 'wp_footer', 'loversy_core_elementor_admin_preview_inline_script' );
}

//=================================================
// Widgets
//=================================================
// Elements
function loversy_core_get_elements() {
    $elements = array();
    
    $elements['image-width-object-fit'] = array(
        'class' => 'Loversy_Core_Image_Width_Object_Fit'
    );
    
    $elements['service'] = array(
        'class' => 'Loversy_Core_Service'
    );
    
    $elements['contact-me'] = array(
        'class' => 'Loversy_Core_Contact_Me'
    );
    
    $elements['contacts'] = array(
        'class' => 'Loversy_Core_Contacts'
    );
    
    $elements['clients'] = array(
        'class' => 'Loversy_Core_Clients'
    );
    
    if ( class_exists( 'ADVEITS_PORTFOLIO_Plugin' ) ) {
        $elements['portfolio-project-info'] = array(
            'class' => 'Loversy_Core_Portfolio_Project_Info'
        );
    
        $elements['portfolio-gallery'] = array(
            'class' => 'Loversy_Core_Portfolio_Gallery'
        );
    
        $elements['portfolio-pagination'] = array(
            'class' => 'Loversy_Core_Portfolio_Pagination'
        );
    }
    
    return $elements;
}

// Widgets path
function loversy_core_get_widgets_path( $name ) {
    $widget_file   = 'overrides/elementor/' . $name . '.php';
    $template_file = locate_template( $widget_file );
    
    if ( ! $template_file || ! is_readable( $template_file ) ) {
        $template_file = dirname( __FILE__ ) . '/widgets/' . $name . '.php';
    }
    
    if ( $template_file && is_readable( $template_file ) ) {
        return $template_file;
    }
    
    return false;
}

// Widget register category
function loversy_core_elementor_widget_categories( $elements_manager ) {
    $elements_manager->add_category(
        'loversy-elements', array(
        'title' => __( 'Loversy Elements', 'loversy' ),
        'icon'  => 'fa fa-plug',
    ), 1
    );
}

add_action( 'elementor/elements/categories_registered', 'loversy_core_elementor_widget_categories' );

// Widgets registered
function loversy_core_elementor_widgets_registered() {
    if ( defined( 'ELEMENTOR_PATH' ) && class_exists( 'Elementor\Widget_Base' ) ) {
        if ( class_exists( 'Elementor\Plugin' ) ) {
            if ( is_callable( 'Elementor\Plugin', 'instance' ) ) {
                $elementor = Elementor\Plugin::instance();
                
                if ( isset( $elementor->widgets_manager ) ) {
                    if ( method_exists( $elementor->widgets_manager, 'register_widget_type' ) ) {
                        $elements = loversy_core_get_elements();
                        
                        foreach ( $elements as $k => $element ) {
                            if ( $template_file = loversy_core_get_widgets_path( $k ) ) {
                                require_once $template_file;
                                $class_name = 'Elementor\\' . $element['class'];
                                
                                Elementor\Plugin::instance()->widgets_manager->register_widget_type( new $class_name );
                            }
                        }
                    }
                }
            }
        }
    }
}

add_action( 'elementor/widgets/widgets_registered', 'loversy_core_elementor_widgets_registered' );

//=================================================
// Affiliate url
//=================================================
// First rewrite
function loversy_core_elementor_affiliate_url() {
    ob_start(
        function( $html ) {
            $theme_obj = wp_get_theme();
            
            if ( $theme_obj->parent() ) {
                $theme_name = $theme_obj->parent()->get( 'Name' );
            } else {
                $theme_name = $theme_obj->get( 'Name' );
            }
            
            $theme_name = sanitize_key( $theme_name );
            
            $html = str_replace(
                array(
                    'https://elementor.com/pro/',
                    'https://elementor.com/?ref=6580?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?ref=6580?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    '?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?ref=6580?utm_source=panel-widgets&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=wp-plugins&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'admin.php?page=go_elementor_pro',
                    'https://elementor.com/pro/?utm_source=wp-custom-fonts&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?utm_source=panel-widgets&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=panel-global&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=panel-library&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=wp-menu&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/popup-builder/?utm_source=popup-templates&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=wp-overview-widget&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=editor-notice-bar&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=icon-library-go-pro&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=panel-custom-css&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/pro/?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?ref=6580?utm_source=panel-global&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?ref=6580?utm_source=wp-plugins&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?ref=6580?utm_source=panel-library&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name,
                    'https://elementor.com/?ref=6580?utm_source=editor-notice-bar&utm_campaign=gopro&utm_medium=wp-dash&utm_term='.$theme_name
                ), 'https://elementor.com/?ref=6580', $html
            );
            
            return $html;
        }
    );
}

add_action( 'admin_init', 'loversy_core_elementor_affiliate_url' );

// Second rewrite
function loversy_core_elementor_affiliate_url_script() {
    wp_enqueue_script( 'loversy-core-elementor-url-rewrites', LOVERSY_CORE_BASE_URL . '/inc/elementor/assets/js/elementor-preview-rewrites.min.js', array(), LOVERSY_CORE_VERSION );
}

if ( class_exists( 'Elementor\Plugin' ) ) {
    add_action( 'elementor/editor/before_enqueue_scripts', 'loversy_core_elementor_affiliate_url_script' );
    add_action( 'admin_enqueue_scripts', 'loversy_core_elementor_affiliate_url_script' );
}
