<?php
//=================================================
// Elementor clients widget
//
// Elementor widget that displays clients.
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Clients extends Widget_Base {
    public function get_name() {
        return 'loversy-clients';
    }
    
    public function get_title() {
        return __( 'Clients ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }
    
    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }
    
    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
        
        $this->start_controls_section(
            'section_content_clients', [
                'label' => __( 'Clients', 'loversy-core' )
            ]
        );
        
        $repeater = new Repeater();
        
        $repeater->add_control(
            'item_name', [
                'label'       => __( 'Name', 'loversy-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => 'Client',
                'label_block' => true,
                'separator'   => 'after'
            ]
        );
        
        $repeater->add_control(
            'item_image', [
                'label'   => __( 'Image', 'loversy-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src()
                ]
            ]
        );
        
        $this->add_control(
            'items', [
                'label'       => __( 'Items', 'loversy-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'item_name' => __( 'Item #1', 'loversy-core' )
                    ],
                    [
                        'item_name' => __( 'Item #2', 'loversy-core' )
                    ],
                    [
                        'item_name' => __( 'Item #3', 'loversy-core' )
                    ]
                ],
                'title_field' => '{{{ item_name }}}'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_clients', [
                'label' => __( 'Clients', 'loversy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
    
        $this->add_responsive_control(
            'clients_padding', [
                'label'      => __( 'Padding', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .clients' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        
        $this->add_control(
            'heading_image', [
                'label'     => __( 'Image', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        
        $this->add_responsive_control(
            'item_image_size', [
                'label'     => __( 'Size', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 400
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .clients .clients-items .clients-item .clients-item-content img' => 'width: {{SIZE}}{{UNIT}};'
                ]
            ]
        );
        
        $this->add_responsive_control(
            'item_image_gap', [
                'label'     => __( 'Gap', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => $space_lg
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .clients .clients-items'       => 'margin-left: -{{SIZE}}{{UNIT}}; margin-right: -{{SIZE}}{{UNIT}}; margin-bottom: -{{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .clients .clients-items .clients-item' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}}'
                ]
            ]
        );
        
        $this->add_control(
            'item_image_border', [
                'label'     => __( 'Border', 'loversy-core' ),
                'type'      => Controls_Manager::SWITCHER,
                'selectors' => [
                    '{{WRAPPER}} .clients .clients-items .clients-item .clients-item-content img' => 'border-style: solid'
                ]
            ]
        );
        
        $this->add_control(
            'item_image_border_color', [
                'label'     => __( 'Border Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '#000',
                'selectors' => [
                    '{{WRAPPER}} .clients .clients-items .clients-item .clients-item-content img' => 'border-color: {{VALUE}}'
                ],
                'condition' => [
                    'client_image_border' => 'yes'
                ]
            ]
        );
        
        $this->add_responsive_control(
            'item_image_border_width', [
                'label'     => __( 'Border Width', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 20,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .clients .clients-items .clients-item .clients-item-content img' => 'border-width: {{SIZE}}{{UNIT}}'
                ],
                'condition' => [
                    'client_image_border' => 'yes'
                ]
            ]
        );
        
        $this->add_control(
            'item_image_border_radius', [
                'label'     => __( 'Border Radius', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .clients .clients-items .clients-item .clients-item-content img' => 'border-radius: {{SIZE}}{{UNIT}}'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
    
        printf( '<div class="clients"><div class="clients-items">' );
        
        foreach ( $settings['items'] as $item ) {
            printf( '<div class="clients-item"><div class="clients-item-content"><img src="%s" alt="%s"></div></div>', $item['item_image']['url'], $item['item_name'] );
        }

        printf( '</div></div>' );
    }
    
    protected function _content_template() { ?>
        <div class="clients">
            <div class="clients-items">
                <# _.each( settings.items, function( item, index ) { #>
                    <div class="clients-item">
                        <div class="clients-item-content">
                            <img src="{{ item.item_image.url }}" alt="{{ item.item_name }}">
                        </div>
                    </div>
                <# } ); #>
            </div>
        </div>
        <?php
    }
}
