<?php
//=================================================
// Elementor contact me
//
// Elementor widget that displays contact me.
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Contact_Me extends Widget_Base {
    public function get_name() {
        return 'loversy-contact-me';
    }
    
    public function get_title() {
        return __( 'Contact Me ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }
    
    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }
    
    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
    
        $this->start_controls_section(
            'section_content_contact_me', [
                'label' => __( 'Contact Me', 'loversy-core' )
            ]
        );
    
        $this->add_control(
            'image', [
                'label'   => __( 'Image', 'loversy-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src()
                ]
            ]
        );
    
        $this->add_control(
            'title', [
                'label'       => __( 'Title', 'loversy-core' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => __( 'Title', 'loversy-core' ),
                'placeholder' => __( 'Enter your title', 'loversy-core' ),
                'label_block' => true
            ]
        );
    
        $this->add_control(
            'title_size', [
                'label'   => __( 'Title HTML Tag', 'loversy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p'
                ],
                'default' => 'h2'
            ]
        );
    
        $this->add_control(
            'description', [
                'label'       => __( 'Description', 'loversy-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'dynamic'     => [
                    'active' => true,
                ],
                'label_block' => true,
                'default'     => __( 'Lorem ipsum dolor sit amet', 'loversy-core' ),
                'placeholder' => __( 'Enter your description', 'loversy-core' )
            ]
        );
    
        $this->add_control(
            'shortcode', [
                'label'       => __( 'Shortcode', 'loversy-core' ),
                'description' => __( 'Refresh the page after adding the shortcode.', 'loversy-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'dynamic'     => [
                    'active' => true,
                ],
                'placeholder' => '[gallery id="123" size="medium"]',
                'default'     => '',
                'separator'   => 'after'
            ]
        );
        
        
        $this->end_controls_section();
    
        $this->start_controls_section(
            'section_style_contact_me', [
                'label'      => __( 'Contact me', 'loversy-core' ),
                'tab'        => Controls_Manager::TAB_STYLE,
                'show_label' => false
            ]
        );
    
        $this->add_control(
            'heading_content_parent', [
                'label'     => __( 'Content parent', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_responsive_control(
            'content_parent_padding', [
                'label'      => __( 'Padding', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .contact-me .contact-me-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
    
        $this->add_control(
            'heading_content_children', [
                'label'     => __( 'Content children', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_responsive_control(
            'content_children_padding', [
                'label'      => __( 'Padding', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .contact-me .contact-me-content .contact-me-content-2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
    
        $this->add_control(
            'content_children_bg_color', [
                'label'     => __( 'Background Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .contact-me .contact-me-content .contact-me-content-2' => 'background-color: {{VALUE}} !important'
                ]
            ]
        );
    
        $this->add_control(
            'heading_image', [
                'label'     => __( 'Image', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        
        $this->add_responsive_control(
            'image_width', [
                'label'          => __( 'Width', 'loversy-core' ),
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units'     => [
                    '%',
                    'px',
                    'vw'
                ],
                'range'          => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100
                    ]
                ],
                'selectors'      => [
                    '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img' => 'width: {{SIZE}}{{UNIT}} !important'
                ]
            ]
        );
    
        $this->add_responsive_control(
            'image_max_width', [
                'label'          => __( 'Max Width', 'loversy-core' ) . ' (%)',
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%'
                ],
                'tablet_default' => [
                    'unit' => '%'
                ],
                'mobile_default' => [
                    'unit' => '%'
                ],
                'size_units'     => [ '%' ],
                'range'          => [
                    '%' => [
                        'min' => 1,
                        'max' => 100
                    ]
                ],
                'selectors'      => [
                    '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img' => 'max-width: {{SIZE}}{{UNIT}} !important'
                ]
            ]
        );
        
        $this->add_control(
            'image_opacity', [
                'label'     => __( 'Opacity', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'min'  => 0.10,
                        'step' => 0.01
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img' => 'opacity: {{SIZE}}'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(), [
                'name'     => 'image_css_filters',
                'selector' => '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img'
            ]
        );
        
        
        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'      => 'image_border',
                'selector'  => '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img',
                'separator' => 'before'
            ]
        );
    
        $this->add_responsive_control(
            'image_border_radius', [
                'label'      => __( 'Border Radius', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(), [
                'name'     => 'image_box_shadow',
                'exclude'  => [
                    'box_shadow_position'
                ],
                'selector' => '{{WRAPPER}} .contact-me .contact-me-img-and-title .img.object-fit img'
            ]
        );
        
        $this->add_control(
            'heading_title', [
                'label'     => __( 'Title', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'title_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .contact-me .contact-me-img-and-title .contact-me-title' => 'color: {{VALUE}}'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .contact-me .contact-me-img-and-title .contact-me-title',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
        
        $this->add_control(
            'heading_description', [
                'label'     => __( 'Description', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'description_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .contact-me .contact-me-content .contact-me-content-2 .contact-me-description > *' => 'color: {{VALUE}}'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'description_typography',
                'selector' => '{{WRAPPER}} .contact-me .contact-me-content .contact-me-content-2 .contact-me-description > *',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
    
        $this->add_responsive_control(
            'description_align', [
                'label'     => __( 'Alignment', 'loversy-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'    => [
                        'title' => __( 'Left', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center'  => [
                        'title' => __( 'Center', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'   => [
                        'title' => __( 'Right', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-justify'
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .contact-me .contact-me-content .contact-me-content-2 .contact-me-description > *' => 'text-align: {{VALUE}};'
                ]
            ]
        );
    
        $this->add_control(
            'heading_shortcode', [
                'label'     => __( 'Shortcode', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_responsive_control(
            'shortcode_padding', [
                'label'      => __( 'Padding', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .contact-me .contact-me-content .contact-me-content-2 .contact-me-shortcode' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        
        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
    
        $this->add_render_attribute( 'contact-me', 'class', 'contact-me' );
        
        $this->add_render_attribute( 'title', 'class', 'contact-me-title' );
        $this->add_inline_editing_attributes( 'title', 'none' );
    
        $this->add_inline_editing_attributes( 'description', 'none' );
        ?>

        <div <?php $this->print_render_attribute_string( 'contact-me' ); ?>>
            <?php if ( $settings['image']['url'] || $settings['title'] ) : ?>
                <div class="contact-me-img-and-title">
                    <?php if ( $settings['image']['url'] ) : ?>
                        <div class="img object-fit">
                            <div class="object-fit-cover">
                                <img src="<?php echo $settings['image']['url']; ?>" alt="<?php echo $settings['title']; ?>">
                            </div>
                        </div>
                    <?php endif; ?>
        
                    <?php if ( $settings['title'] ): ?>
                        <<?php echo $settings['title_size']; ?> <?php $this->print_render_attribute_string( 'title' ); ?>><?php echo $settings['title']; ?></<?php echo $settings['title_size']; ?>>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
            
            <div class="contact-me-content">
                <div class="contact-me-content-2">
                    <?php if ( $settings['description'] ) : ?>
                        <div class="contact-me-description">
                            <p <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $settings['description']; ?></p>
                        </div>
                    <?php endif; ?>
    
                    <?php if ( $settings['shortcode'] ) : ?>
                        <div class="contact-me-shortcode">
                            <?php
                            $shortcode = $this->get_settings_for_display( 'shortcode' );
                            $shortcode = do_shortcode( shortcode_unautop( $shortcode ) );
                            
                            echo $shortcode;
                            ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <?php
    }
    
    protected function _content_template() { ?>
        <#
        view.addRenderAttribute( 'contact-me' , 'class' , 'contact-me' );
        
        view.addRenderAttribute( 'title' , 'class' , 'contact-me-title' );
        view.addInlineEditingAttributes( 'title', 'none' );

        view.addInlineEditingAttributes( 'description', 'none' );
        #>
        
        <div {{{ view.getRenderAttributeString( 'contact-me' ) }}}>
            <# if ( settings.image.url || settings.title ) { #>
                <div class="contact-me-img-and-title">
                    <# if ( settings.image.url ) { #>
                        <div class="img object-fit">
                            <div class="object-fit-cover">
                                <img src="{{{ settings.image.url }}}" alt="{{ settings.title }}">
                            </div>
                        </div>
                    <# } #>

                    <# if ( settings.title ) { #>
                        <{{ settings.title_size }} {{{ view.getRenderAttributeString( 'title' ) }}}>{{{ settings.title }}}<{{{ '/' + settings.title_size }}}>
                    <# } #>
                </div>
            <# } #>

            <div class="contact-me-content">
                <div class="contact-me-content-2">
                    <# if ( settings.description ) { #>
                        <div class="contact-me-description">
                            <p {{{ view.getRenderAttributeString( 'description' ) }}}>{{ settings.description }}</p>
                        </div>
                    <# } #>

                    <# if ( settings.shortcode ) { #>
                        <div class="contact-me-shortcode">
                            {{ settings.shortcode }}
                        </div>
                    <# } #>
                </div>
            </div>
        </div>
        <?php
    }
}
