<?php
//=================================================
// Elementor contacts widget
//
// Elementor widget that displays contacts.
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Contacts extends Widget_Base {
    public function get_name() {
        return 'loversy-contacts';
    }
    
    public function get_title() {
        return __( 'Contacts ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }
    
    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }
    
    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
        
        $this->start_controls_section(
            'section_content_contacts', [
                'label' => __( 'Contacts', 'loversy-core' )
            ]
        );
    
        $this->add_control(
            'image', [
                'label'   => __( 'Image', 'loversy-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src()
                ]
            ]
        );
        
        $this->add_control(
            'title', [
                'label'       => __( 'Title', 'loversy-core' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => __( 'Title', 'loversy-core' ),
                'placeholder' => __( 'Enter your title', 'loversy-core' ),
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'title_size', [
                'label'   => __( 'Title HTML Tag', 'loversy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p'
                ],
                'default' => 'h3'
            ]
        );
    
        $this->add_control(
            'description', [
                'label'       => __( 'Description', 'loversy-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'dynamic'     => [
                    'active' => true,
                ],
                'label_block' => true,
                'default'     => __( 'Lorem ipsum dolor sit amet', 'loversy-core' ),
                'placeholder' => __( 'Enter your description', 'loversy-core' )
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_contacts', [
                'label' => __( 'Contacts', 'loversy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
    
        $this->add_control(
            'contacts_bg_color', [
                'label'     => __( 'Background Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .contacts-item' => 'background-color: {{VALUE}} !important'
                ]
            ]
        );
    
        $this->add_control(
            'contacts_bg_opacity', [
                'label'     => __( 'Opacity', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'min'  => 0.10,
                        'step' => 0.01
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .contacts-item' => 'opacity: {{SIZE}};'
                ]
            ]
        );
    
        $this->add_responsive_control(
            'contacts_padding', [
                'label'      => __( 'Padding', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .contacts-item .contacts-item-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        
        $this->add_responsive_control(
            'contacts_text_align', [
                'label'     => __( 'Alignment', 'loversy-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'    => [
                        'title' => __( 'Left', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center'  => [
                        'title' => __( 'Center', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'   => [
                        'title' => __( 'Right', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-justify'
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .contacts-item .contacts-item-content' => 'text-align: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'heading_image', [
                'label'     => __( 'Image', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'image_opacity', [
                'label'     => __( 'Opacity', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'min'  => 0.10,
                        'step' => 0.01
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .contacts-item .img.object-fit img' => 'opacity: {{SIZE}};'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(), [
                'name'     => 'image_css_filters',
                'selector' => '{{WRAPPER}} .contacts-item .img.object-fit img'
            ]
        );
        
        $this->add_control(
            'heading_title', [
                'label'     => __( 'Title', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        
        $this->add_control(
            'title_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .contacts-item .contacts-item-content .contacts-item-title' => 'color: {{VALUE}}'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .contacts-item .contacts-item-content .contacts-item-title',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
        
        $this->add_control(
            'heading_description', [
                'label'     => __( 'Description', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'description_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .contacts-item .contacts-item-content .contacts-item-description' => 'color: {{VALUE}}'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'description_typography',
                'selector' => '{{WRAPPER}} .contacts-item .contacts-item-content .contacts-item-description',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
    
        $this->add_control(
            'description_top_space', [
                'label'     => __( 'Spacing', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => $space_lg
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .contacts-item .contacts-item-content .contacts-item-description' => 'padding-top: {{SIZE}}{{UNIT}} !important'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function htmlspecialvars_decode( $text ) {
        echo strtr( $text, array_flip( get_html_translation_table( HTML_SPECIALCHARS ) ) );
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
    
        $this->add_render_attribute( 'contacts', 'class', 'contacts-item' );
        
        $this->add_render_attribute( 'title', 'class', 'contacts-item-title after' );
        $this->add_inline_editing_attributes( 'title', 'none' );
    
        $this->add_render_attribute( 'description', 'class', 'contacts-item-description' );
        $this->add_inline_editing_attributes( 'description', 'none' );
        ?>
        <div <?php $this->print_render_attribute_string( 'contacts' ); ?>>
            <div class="img object-fit">
                <div class="object-fit-cover">
                    <?php $image_array = wp_get_attachment_image_src( $settings['image']['id'], 'medium_large' ); ?>
                
                    <?php if ( is_array( $image_array ) ) : ?>
                        <?php $image_medium_large = wp_get_attachment_image_src( $settings['image']['id'], 'medium_large' )[0]; ?>
    
                        <img src="<?php echo $image_medium_large; ?>" alt="<?php echo $settings['title']; ?>">
                    <?php else : ?>
                        <img src="<?php echo $settings['image']['url']; ?>" alt="<?php echo $settings['title']; ?>">
                    <?php endif; ?>
                </div>
            </div>
    
            <?php if ( $settings['title'] || $settings['description'] ): ?>
                <div class="contacts-item-content">
                    <?php if ( $settings['title'] ): ?>
                        <<?php echo $settings['title_size']; ?> <?php $this->print_render_attribute_string( 'title' ); ?>><?php echo $settings['title']; ?></<?php echo $settings['title_size']; ?>>
                    <?php endif; ?>
        
                    <?php if ( $settings['description'] ) : ?>
                        <p <?php $this->print_render_attribute_string( 'description' ); ?>><?php echo $settings['description']; ?></p>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    <?php }
    
    protected function _content_template() { ?>
        <#
        view.addRenderAttribute( 'contacts', 'class', 'contacts-item' );
        
        view.addRenderAttribute( 'title', 'class', 'contacts-item-title after' );
        view.addInlineEditingAttributes( 'title', 'none' );

        view.addRenderAttribute( 'description', 'class', 'contacts-item-description' );
        view.addInlineEditingAttributes( 'description', 'none' );
        #>
        <div {{{ view.getRenderAttributeString( 'contacts' ) }}}>
            <div class="img object-fit">
                <div class="object-fit-cover">
                    <img src="{{ settings.image.url }}" alt="{{ settings.title }}">
                </div>
            </div>

            <# if ( settings.title || settings.description ) { #>
                <div class="contacts-item-content">
                    <# if ( settings.title ) { #>
                        <{{ settings.title_size }} {{{ view.getRenderAttributeString( 'title' ) }}}>{{{ settings.title }}}<{{{ '/' + settings.title_size }}}>
                    <# } #>
                    
                    <# if ( settings.description ) { #>
                        <p {{{ view.getRenderAttributeString( 'description' ) }}}>{{ settings.description }}</p>
                    <# } #>
                </div>
            <# } #>
        </div>
        <?php
    }
}
