<?php
//=================================================
// Elementor image width object fit widget
//
// Elementor widget that displays image width object fit.
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Image_Width_Object_Fit extends Widget_Base {
    public function get_name() {
        return 'loversy-image-width-object-fit';
    }
    
    public function get_title() {
        return __( 'Image width Object Fit ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }

    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }

    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
        
        $this->start_controls_section(
            'section_content_image', [
                'label' => __( 'Image', 'loversy-core' )
            ]
        );
        
        $this->add_control(
            'image', [
                'label'   => __( 'Choose Image', 'loversy-core' ),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true
                ],
                'default' => [
                    'url' => Utils::get_placeholder_image_src()
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Image_Size::get_type(), [
                'name'      => 'image',
                'default'   => 'large',
                'separator' => 'none'
            ]
        );
        
        $this->add_responsive_control(
            'align', [
                'label'     => __( 'Alignment', 'loversy-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => __( 'Left', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-left'
                    ],
                    'center' => [
                        'title' => __( 'Center', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-center'
                    ],
                    'right'  => [
                        'title' => __( 'Right', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-right'
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'caption_source', [
                'label'   => __( 'Caption', 'loversy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'none'       => __( 'None', 'loversy-core' ),
                    'attachment' => __( 'Attachment Caption', 'loversy-core' ),
                    'custom'     => __( 'Custom Caption', 'loversy-core' )
                ],
                'default' => 'none'
            ]
        );
        
        $this->add_control(
            'caption', [
                'label'       => __( 'Custom Caption', 'loversy-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'placeholder' => __( 'Enter your image caption', 'loversy-core' ),
                'condition'   => [
                    'caption_source' => 'custom'
                ],
                'dynamic'     => [
                    'active' => true
                ]
            ]
        );
        
        $this->add_control(
            'link_to', [
                'label'   => __( 'Link', 'loversy-core' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'none',
                'options' => [
                    'none'   => __( 'None', 'loversy-core' ),
                    'file'   => __( 'Media File', 'loversy-core' ),
                    'custom' => __( 'Custom URL', 'loversy-core' )
                ]
            ]
        );
        
        $this->add_control(
            'link', [
                'label'       => __( 'Link', 'loversy-core' ),
                'type'        => Controls_Manager::URL,
                'dynamic'     => [
                    'active' => true
                ],
                'placeholder' => __( 'https://your-link.com', 'loversy-core' ),
                'condition'   => [
                    'link_to' => 'custom'
                ],
                'show_label'  => false
            ]
        );
        
        $this->add_control(
            'open_lightbox', [
                'label'     => __( 'Lightbox', 'loversy-core' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'default',
                'options'   => [
                    'default' => __( 'Default', 'loversy-core' ),
                    'yes'     => __( 'Yes', 'loversy-core' ),
                    'no'      => __( 'No', 'loversy-core' )
                ],
                'condition' => [
                    'link_to' => 'file'
                ]
            ]
        );
        
        $this->add_control(
            'view', [
                'label'   => __( 'View', 'loversy-core' ),
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'traditional'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_image', [
                'label' => __( 'Image', 'loversy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_responsive_control(
            'width', [
                'label'          => __( 'Width', 'loversy-core' ),
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units'     => [
                    '%',
                    'px',
                    'vw'
                ],
                'range'          => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100
                    ]
                ],
                'selectors'      => [
                    '{{WRAPPER}} .img.object-fit img' => 'width: {{SIZE}}{{UNIT}} !important;'
                ]
            ]
        );
        
        $this->add_responsive_control(
            'max_width', [
                'label'          => __( 'Max Width', 'loversy-core' ) . ' (%)',
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%'
                ],
                'tablet_default' => [
                    'unit' => '%'
                ],
                'mobile_default' => [
                    'unit' => '%'
                ],
                'size_units'     => [ '%' ],
                'range'          => [
                    '%' => [
                        'min' => 1,
                        'max' => 100
                    ]
                ],
                'selectors'      => [
                    '{{WRAPPER}} .img.object-fit img' => 'max-width: {{SIZE}}{{UNIT}} !important;'
                ]
            ]
        );
        
        $this->add_control(
            'separator_panel_style_image', [
                'type'  => Controls_Manager::DIVIDER,
                'style' => 'thick',
            ]
        );
        
        $this->start_controls_tabs( 'tabs_image_effects' );
        
        $this->start_controls_tab(
            'tab_normal', [
                'label' => __( 'Normal', 'loversy-core' )
            ]
        );
        
        $this->add_control(
            'opacity', [
                'label'     => __( 'Opacity', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'min'  => 0.10,
                        'step' => 0.01
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .img.object-fit img' => 'opacity: {{SIZE}};'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(), [
                'name'     => 'css_filters',
                'selector' => '{{WRAPPER}} .img.object-fit img'
            ]
        );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'tab_hover', [
                'label' => __( 'Hover', 'loversy-core' )
            ]
        );
        
        $this->add_control(
            'opacity_hover', [
                'label'     => __( 'Opacity', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'min'  => 0.10,
                        'step' => 0.01
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .img.object-fit:hover img' => 'opacity: {{SIZE}};'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(), [
                'name'     => 'css_filters_hover',
                'selector' => '{{WRAPPER}} .img.object-fit:hover img'
            ]
        );
        
        $this->add_control(
            'background_hover_transition', [
                'label'     => __( 'Transition Duration', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 3,
                        'step' => 0.1
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .img.object-fit img' => 'transition-duration: {{SIZE}}s'
                ]
            ]
        );
        
        $this->add_control(
            'hover_animation', [
                'label' => __( 'Hover Animation', 'loversy-core' ),
                'type'  => Controls_Manager::HOVER_ANIMATION
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'      => 'image_border',
                'selector'  => '{{WRAPPER}} .img.object-fit img',
                'separator' => 'before'
            ]
        );
        
        $this->add_responsive_control(
            'image_border_radius', [
                'label'      => __( 'Border Radius', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .img.object-fit img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(), [
                'name'     => 'image_box_shadow',
                'exclude'  => [
                    'box_shadow_position'
                ],
                'selector' => '{{WRAPPER}} .img.object-fit img'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_caption', [
                'label'     => __( 'Caption', 'loversy-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'caption_source!' => 'none'
                ]
            ]
        );
        
        $this->add_control(
            'caption_align', [
                'label'     => __( 'Alignment', 'loversy-core' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'    => [
                        'title' => __( 'Left', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-left'
                    ],
                    'center'  => [
                        'title' => __( 'Center', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-center'
                    ],
                    'right'   => [
                        'title' => __( 'Right', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-right'
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'loversy-core' ),
                        'icon'  => 'eicon-text-align-justify'
                    ]
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .widget-image-caption' => 'text-align: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'text_color', [
                'label'     => __( 'Text Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .widget-image-caption' => 'color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'caption_background_color', [
                'label'     => __( 'Background Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .widget-image-caption' => 'background-color: {{VALUE}};'
                ],
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'caption_typography',
                'selector' => '{{WRAPPER}} .widget-image-caption',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_3
            ]
        );
        
        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(), [
                'name'     => 'caption_text_shadow',
                'selector' => '{{WRAPPER}} .widget-image-caption'
            ]
        );
        
        $this->add_responsive_control(
            'caption_space', [
                'label'     => __( 'Spacing', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => $space_lg
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .widget-image-caption' => 'margin-top: {{SIZE}}{{UNIT}};'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    private function has_caption( $settings ) {
        return ( ! empty( $settings['caption_source'] ) && 'none' !== $settings['caption_source'] );
    }

    private function get_caption( $settings ) {
        $caption = '';
        
        if ( ! empty( $settings['caption_source'] ) ) {
            switch ( $settings['caption_source'] ) {
                case 'attachment':
                    $caption = wp_get_attachment_caption( $settings['image']['id'] );
                    break;
                case 'custom':
                    $caption = ! empty( $settings['caption'] ) ? $settings['caption'] : '';
            }
        }
        
        return $caption;
    }
    
    protected function htmlspecialvars_decode( $text ) {
        echo strtr( $text, array_flip( get_html_translation_table( HTML_SPECIALCHARS ) ) );
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
        
        if ( empty( $settings['image']['url'] ) ) {
            return;
        }
        
        $has_caption = $this->has_caption( $settings );
        
        $this->add_render_attribute( 'wrapper', 'class', 'img object-fit' );
        
        if ( ! empty( $settings['shape'] ) ) {
            $this->add_render_attribute( 'wrapper', 'class', 'image-shape-' . $settings['shape'] );
        }
        
        $link = $this->get_link_url( $settings );
        
        if ( $link ) {
            $this->add_render_attribute(
                'link', [
                    'href'                         => $link['url'],
                    'data-elementor-open-lightbox' => $settings['open_lightbox'],
                ]
            );
            
            if ( Plugin::$instance->editor->is_edit_mode() ) {
                $this->add_render_attribute(
                    'link', [
                        'class' => 'clickable'
                    ]
                );
            }
            
            if ( ! empty( $link['is_external'] ) ) {
                $this->add_render_attribute( 'link', 'target', '_blank' );
            }
            
            if ( ! empty( $link['nofollow'] ) ) {
                $this->add_render_attribute( 'link', 'rel', 'nofollow' );
            }
        }
        ?>

        <div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
            <div class="object-fit-cover">
                <?php if ( $has_caption ) : ?>
                    <figure class="wp-caption">
                <?php endif; ?>

                <?php if ( $link ) : ?>
                    <a <?php $this->print_render_attribute_string( 'link' ); ?>>
                <?php endif; ?>

                <?php echo Group_Control_Image_Size::get_attachment_image_html( $settings ); ?>

                <?php if ( $link ) : ?>
                    </a>
                <?php endif; ?>

                <?php if ( $has_caption ) : ?>
                    <figcaption class="widget-image-caption wp-caption-text"><?php echo $this->get_caption( $settings ); ?></figcaption>
                <?php endif; ?>

                <?php if ( $has_caption ) : ?>
                    </figure>
                <?php endif; ?>
            </div>
        </div>
        <?php
    }
    
    protected function _content_template() {
        ?>
        <# if ( settings.image.url ) {
            var image = {
            id: settings.image.id,
            url: settings.image.url,
            size: settings.image_size,
            dimension: settings.image_custom_dimension,
            model: view.getEditModel()
        };

        var image_url = elementor.imagesManager.getImageUrl( image );

        if ( ! image_url ) {
            return;
        }

        var hasCaption = function() {
            if ( ! settings.caption_source || 'none' === settings.caption_source ) {
                return false;
            }
        
            return true;
        }

        var ensureAttachmentData = function( id ) {
            if ( 'undefined' === typeof wp.media.attachment( id ).get( 'caption' ) ) {
                wp.media.attachment( id ).fetch().then( function( data ) {
                    view.render();
                } );
            }
        }

        var getAttachmentCaption = function( id ) {
            if ( ! id ) {
                return '';
            }
        
            ensureAttachmentData( id );
            return wp.media.attachment( id ).get( 'caption' );
        }

        var getCaption = function() {
            if ( ! hasCaption() ) {
                return '';
            }
        
            return 'custom' === settings.caption_source ? settings.caption : getAttachmentCaption( settings.image.id );
        }

        var link_url;

        if ( 'custom' === settings.link_to ) {
            link_url = settings.link.url;
        }

        if ( 'file' === settings.link_to ) {
            link_url = settings.image.url;
        }

        #><div class="img object-fit{{ settings.shape ? ' image-shape-' + settings.shape : '' }}"><#
            #><div class="object-fit-cover"><#
                var imgClass = '';

                if ( '' !== settings.hover_animation ) {
                    imgClass = 'elementor-animation-' + settings.hover_animation;
                }

                if ( hasCaption() ) {
                    #><figure class="wp-caption"><#
                }
                
                if ( link_url ) {
                    #><a class="clickable" data-elementor-open-lightbox="{{ settings.open_lightbox }}" href="{{ link_url }}"><#
                }
                
                #><img src="{{ image_url }}" class="{{ imgClass }}" /><#
                
                if ( link_url ) {
                    #></a><#
                }

                if ( hasCaption() ) {
                    #><figcaption class="widget-image-caption wp-caption-text">{{{ getCaption() }}}</figcaption><#
                }

                if ( hasCaption() ) {
                    #></figure><#
                }
            #></div><#
        #></div><#
        } #>
        <?php
    }
    
    private function get_link_url( $settings ) {
        if ( 'none' === $settings['link_to'] ) {
            return false;
        }

        if ( 'custom' === $settings['link_to'] ) {
            if ( empty( $settings['link']['url'] ) ) {
                return false;
            }
            return $settings['link'];
        }

        return [
            'url' => $settings['image']['url'],
        ];
    }
}
