<?php
//=================================================
// Elementor portfolio gallery widget
//
// Elementor widget that displays portfolio gallery.
//
// @package Erso
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Portfolio_Gallery extends Widget_Base {
    public function get_name() {
        return 'loversy-portfolio-gallery';
    }
    
    public function get_title() {
        return __( 'Portfolio Gallery ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }
    
    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }
    
    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_portfolio_gallery', [
                'label' => __( 'Portfolio Gallery', 'erso' ),
            ]
        );
        
        $this->add_control(
            'slider_navigation', [
                'label'   => __( 'Navigation', 'loversy-core' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_navigation', [
                'label' => __( 'Navigation', 'loversy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_control(
            'slider_navigation_btn_color', [
                'label'     => __( 'Button Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-next, {{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-prev' => 'color: {{VALUE}} !important'
                ]
            ]
        );
        
        $this->add_control(
            'slider_navigation_btn_bg_color', [
                'label'     => __( 'Button Background Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-next, {{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-prev' => 'background-color: {{VALUE}} !important'
                ]
            ]
        );
        
        $this->add_control(
            'slider_navigation_btn_hover_color', [
                'label'     => __( 'Button Hover Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-next:hover, {{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-prev:hover' => 'color: {{VALUE}} !important'
                ]
            ]
        );
        
        $this->add_control(
            'slider_navigation_btn_hover_bg_color', [
                'label'     => __( 'Button Hover Background Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-next:hover, {{WRAPPER}} .adv-swiper-container .adv-2-swiper-button-prev:hover' => 'background-color: {{VALUE}} !important'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
        $images   = get_field( 'adveits_portfolio_images' );
        
        if ( $images ) : ?>
            <div class="adv-slider">
                <div class="adv-swiper-container">
                    <div class="adv-swiper-wrapper">
                        <?php foreach ( $images as $image ) : ?>
                            <?php if ( $image['adveits_portfolio_image']['url'] ) : ?>
                                <div class="adv-swiper-slide">
                                    <div class="img object-fit">
                                        <div class="object-fit-cover">
                                            <img src="<?php echo esc_url( $image['adveits_portfolio_image']['sizes']['large'] ); ?>" alt="<?php the_title_attribute(); ?>">
                                        </div>
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php endforeach; ?>
                    </div>
                    
                    <?php if ( $settings['slider_navigation'] == 'yes' ) : ?>
                        <div class="adv-2-swiper-button-next adv-swiper-button-white">
                            <i class="fas fa-long-arrow-alt-right"></i>
                        </div>

                        <div class="adv-2-swiper-button-prev adv-swiper-button-white">
                            <i class="fas fa-long-arrow-alt-left"></i>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        <?php endif;
    }
    
    protected function _content_template() {
    }
}
