<?php
//=================================================
// Elementor portfolio pagination widget
//
// Elementor widget that displays portfolio pagination.
//
// @package Erso
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Portfolio_Pagination extends Widget_Base {
    public function get_name() {
        return 'loversy-portfolio-pagination';
    }
    
    public function get_title() {
        return __( 'Portfolio Pagination ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }
    
    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }
    
    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_portfolio_pagination', [
                'label' => __( 'Portfolio Pagination', 'erso' ),
            ]
        );
        
        $this->add_control(
            'portfolio_pagination_text', [
                'label'   => __( 'Text', 'loversy-core' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
    
        $this->add_control(
            'portfolio_pagination_title', [
                'label'   => __( 'Title', 'loversy-core' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
    
        $this->add_control(
            'portfolio_pagination_icon', [
                'label'   => __( 'Icon', 'loversy-core' ),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_portfolio_pagination', [
                'label' => __( 'Portfolio Pagination', 'loversy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
    
        $this->add_control(
            'heading_text', [
                'label'     => __( 'Text', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'portfolio_pagination_text_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .portfolio-pagination .link .link-text' => 'color: {{VALUE}} !important'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'portfolio_pagination_text_typography',
                'selector' => '{{WRAPPER}} .portfolio-pagination .link .link-text',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
    
        $this->add_control(
            'heading_title', [
                'label'     => __( 'Title', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'portfolio_pagination_title_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .portfolio-pagination .link .link-title' => 'color: {{VALUE}} !important'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'portfolio_pagination_title_typography',
                'selector' => '{{WRAPPER}} .portfolio-pagination .link .link-title',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
    
        $this->add_control(
            'heading_icon', [
                'label'     => __( 'Icon', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'portfolio_pagination_icon_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .portfolio-pagination .link [class*=fa-]' => 'color: {{VALUE}} !important'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings   = $this->get_settings_for_display();
        $current_id = get_the_ID();
        $prev_post  = get_previous_post();
        $next_post  = get_next_post();
        
        $args = array(
            'post_type'      => 'adveits_portfolio',
            'posts_per_page' => -1
        );
        
        $posts       = get_posts( $args );
        $posts_count = count( $posts );
        $last_post   = end( $posts );
        $first_post  = $posts[0];
        
        $first_id = $posts[0]->ID;
        $last_id  = $last_post->ID;
        
        $prev_post_id    = '';
        $prev_post_title = '';
        $next_post_id    = '';
        $next_post_title = '';
        
        if ( $posts_count > 1 ) {
            if ( $current_id == $first_id ) {
                $prev_post_id    = $prev_post->ID;
                $prev_post_title = $prev_post->post_title;
            } else if ( $current_id == $last_id ) {
                $prev_post_id    = $first_post->ID;
                $prev_post_title = $first_post->post_title;
            } else {
                $prev_post_id    = $prev_post->ID;
                $prev_post_title = $prev_post->post_title;
            }
            
            if ( $current_id != $first_id ) {
                $next_post_id    = $next_post->ID;
                $next_post_title = $next_post->post_title;
            } else {
                $next_post_id    = $last_post->ID;
                $next_post_title = $last_post->post_title;
            }
        } ?>
        
        <?php if ( $prev_post_title || $next_post_title ) : ?>
            <div class="portfolio-pagination">
                <div class="row justify-content-between gutter-width-md with-pb-lg">
                    <div class="col-sm-6 col-md-6 col-lg-6 col-xl-6">
                        <?php if ( $prev_post_title ) : ?>
                            <a class="d-flex justify-content-start link previous-link" href="<?php echo esc_url( get_permalink( $prev_post_id ) ); ?>">
                                <div class="d-flex align-items-center justify-content-start">
                                    <?php if ( $settings['portfolio_pagination_icon'] == 'yes' ) : ?>
                                        <div class="left">
                                            <p><i class="fas fa-long-arrow-alt-left"></i></p>
                                        </div>
                                    <?php endif; ?>
                                
                                    <?php if ( $settings['portfolio_pagination_text'] == 'yes' || $settings['portfolio_pagination_title'] == 'yes' ) : ?>
                                        <div class="right">
                                            <?php if ( $settings['portfolio_pagination_text'] == 'yes' ) : ?>
                                                <p class="link-text after"><?php esc_html_e( 'Previous project', 'loversy' ); ?></p>
                                            <?php endif; ?>
                                        
                                            <?php if ( $settings['portfolio_pagination_title'] == 'yes' ) : ?>
                                                <h4 class="link-title"><?php echo esc_html( $prev_post_title ); ?></h4>
                                            <?php endif; ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </a>
                        <?php endif; ?>
                    </div>

                    <div class="col-sm-6 col-md-6 col-lg-6 col-xl-6">
                        <?php if ( $next_post_title ) : ?>
                            <a class="d-flex justify-content-end link next-link" href="<?php echo esc_url( get_permalink( $next_post_id ) ); ?>">
                                <div class="d-flex align-items-center justify-content-end">
                                    <?php if ( $settings['portfolio_pagination_text'] == 'yes' || $settings['portfolio_pagination_title'] == 'yes' ) : ?>
                                        <div class="left">
                                            <?php if ( $settings['portfolio_pagination_text'] == 'yes' ) : ?>
                                                <p class="link-text after"><?php esc_html_e( 'Next project', 'loversy' ); ?></p>
                                            <?php endif; ?>
                                        
                                            <?php if ( $settings['portfolio_pagination_title'] == 'yes' ) : ?>
                                                <h4 class="link-title"><?php echo esc_html( $next_post_title ); ?></h4>
                                            <?php endif; ?>
                                        </div>
                                    <?php endif; ?>
                                
                                    <?php if ( $settings['portfolio_pagination_icon'] == 'yes' ) : ?>
                                        <div class="right">
                                            <p><i class="fas fa-long-arrow-alt-right"></i></p>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php
    }
    
    protected function _content_template() {
    }
}
