<?php
//=================================================
// Elementor portfolio project info widget
//
// Elementor widget that displays portfolio project info.
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Core_Portfolio_Project_Info extends Widget_Base {
    public function get_name() {
        return 'loversy-portfolio-project-info';
    }
    
    public function get_title() {
        return __( 'Portfolio Project Info ( Loversy )', 'loversy-core' );
    }
    
    public function get_icon() {
        return 'icon-adv-adveits';
    }
    
    public function get_categories() {
        return [
            'basic',
            'loversy-elements'
        ];
    }
    
    public function get_keywords() {
        return [
            'adveits'
        ];
    }
    
    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
        
        $this->start_controls_section(
            'section_content_portfolio_project_info', [
                'label' => __( 'Portfolio Project Info', 'loversy-core' )
            ]
        );
    
        $repeater = new Repeater();
    
        $repeater->add_control(
            'item_image', [
                'label'   => __( 'Image', 'loversy-core' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src()
                ]
            ]
        );
    
        $repeater->add_control(
            'item_title', [
                'label'       => __( 'Title', 'loversy-core' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true,
                ],
                'label_block' => true,
                'default'     => __( 'Title', 'loversy-core' ),
                'placeholder' => __( 'Enter your title', 'loversy-core' )
            ]
        );
        
        $repeater->add_control(
            'item_description', [
                'label'       => __( 'Description', 'loversy-core' ),
                'type'        => Controls_Manager::TEXTAREA,
                'dynamic'     => [
                    'active' => true,
                ],
                'label_block' => true,
                'default'     => __( 'Lorem ipsum dolor', 'loversy-core' ),
                'separator'   => 'before'
            ]
        );
    
        $this->add_control(
            'items', [
                'label'       => __( 'Items', 'loversy-core' ),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'default'     => [
                    [
                        'item_title' => __( 'Item #1', 'loversy-core' )
                    ],
                    [
                        'item_title' => __( 'Item #2', 'loversy-core' )
                    ],
                    [
                        'item_title' => __( 'Item #3', 'loversy-core' )
                    ],
                    [
                        'item_title' => __( 'Item #4', 'loversy-core' )
                    ]
                ],
                'title_field' => '{{{ item_title }}}'
            ]
        );
    
        $this->add_control(
            'title_size', [
                'label'   => __( 'Title HTML Tag', 'loversy-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'h2' => 'H2',
                    'h3' => 'H3',
                    'h4' => 'H4',
                    'h5' => 'H5',
                    'h6' => 'H6',
                ],
                'default'   => 'h5',
                'separator' => 'before'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_portfolio_project_info', [
                'label' => __( 'Portfolio Project info', 'loversy-core' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_responsive_control(
            'portfolio_project_info_spacing', [
                'label'      => __( 'Spacing', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
    
        $this->add_responsive_control(
            'portfolio_project_info_content_padding', [
                'label'      => __( 'Content Padding', 'loversy-core' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    '%',
                    'em'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .project-info-item-description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
    
        $this->add_control(
            'portfolio_project_info_bg_color', [
                'label'     => __( 'Background Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content' => 'background-color: {{VALUE}} !important'
                ]
            ]
        );
    
        $this->add_control(
            'heading_image', [
                'label'     => __( 'Image', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'item_image_opacity', [
                'label'     => __( 'Opacity', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'max'  => 1,
                        'min'  => 0.10,
                        'step' => 0.01
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .img.object-fit img' => 'opacity: {{SIZE}};'
                ]
            ]
        );
    
        $this->add_group_control(
            Group_Control_Css_Filter::get_type(), [
                'name'     => 'item_image_css_filters',
                'selector' => '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .img.object-fit img'
            ]
        );
        
        $this->add_control(
            'heading_title', [
                'label'     => __( 'Title', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        
        $this->add_control(
            'item_title_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .project-info-item-description .project-info-title' => 'color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'item_title_typography',
                'selector' => '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .project-info-item-description .project-info-title',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
        
        $this->add_control(
            'heading_description', [
                'label'     => __( 'Description', 'loversy-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        
        $this->add_control(
            'item_description_color', [
                'label'     => __( 'Color', 'loversy-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .project-info-item-description .project-info-description' => 'color: {{VALUE}}'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'item_description_typography',
                'selector' => '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .project-info-item-description .project-info-description',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
        
        $this->add_control(
            'item_description_top_space', [
                'label'     => __( 'Spacing', 'loversy-core' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => $space_lg
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .project-info .project-info-items .project-info-item .project-info-item-content .project-info-description' => 'padding-top: {{SIZE}}{{UNIT}} !important'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
        
        $this->add_render_attribute( 'project-info', 'class', 'project-info' );
        ?>
        <?php if ( $settings['items'] ): ?>
            <div <?php $this->print_render_attribute_string( 'project-info' ); ?>>
                <div class="project-info-items">
                    <?php foreach ( $settings['items'] as $index => $item ) : ?>
                        <?php
                        $this->add_render_attribute( $this->get_repeater_setting_key( 'item_title', 'items', $index ), 'class', 'project-info-title after' );
                        $this->add_inline_editing_attributes( $this->get_repeater_setting_key( 'item_title', 'items', $index ), 'none' );
                    
                        $this->add_render_attribute( $this->get_repeater_setting_key( 'item_description', 'items', $index ), 'class', 'project-info-description' );
                        $this->add_inline_editing_attributes( $this->get_repeater_setting_key( 'item_description', 'items', $index ), 'none' );
                        ?>
                    
                        <div class="project-info-item">
                            <div class="project-info-item-content">
                                <?php if ( $item['item_image']['url'] ) : ?>
                                    <div class="img object-fit">
                                        <div class="object-fit-cover">
                                            <?php $image_array = wp_get_attachment_image_src( $item['item_image']['id'], 'medium_large' ); ?>
                
                                            <?php if ( is_array( $image_array ) ) : ?>
                                                <?php $image_medium_large = wp_get_attachment_image_src( $item['item_image']['id'], 'medium_large' )[0]; ?>

                                                <img src="<?php echo $image_medium_large; ?>" alt="<?php echo $item['item_title']; ?>">
                                            <?php else : ?>
                                                <img src="<?php echo $item['item_image']['url']; ?>" alt="<?php echo $item['item_title']; ?>">
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                <?php endif; ?>

                                <div class="project-info-item-description">
                                    <?php if ( $item['item_title'] ) : ?>
                                        <<?php echo $settings['title_size']; ?> <?php $this->print_render_attribute_string( $this->get_repeater_setting_key( 'item_title', 'items', $index ) ); ?>><?php echo $item['item_title']; ?></<?php echo $settings['title_size']; ?>>
                                    <?php endif; ?>
    
                                    <?php if ( $item['item_description'] ) : ?>
                                        <p <?php $this->print_render_attribute_string( $this->get_repeater_setting_key( 'item_description', 'items', $index ) ); ?>><?php echo $item['item_description']; ?></p>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
        <?php
    }
    
    protected function _content_template() { ?>
        <#
        view.addRenderAttribute( 'project-info', 'class', 'project-info' );
        #>
        
        <# if ( settings.items ) { #>
            <div {{{ view.getRenderAttributeString( 'project-info' ) }}}>
                <div class="project-info-items">
                    <# _.each( settings.items, function( item, index ) { #>
                        <#
                        view.addRenderAttribute( view.getRepeaterSettingKey( 'item_title', 'items', index ), 'class', 'project-info-title after' );
                        view.addInlineEditingAttributes( view.getRepeaterSettingKey( 'item_title', 'items', index ), 'none' );
    
                        view.addRenderAttribute( view.getRepeaterSettingKey( 'item_description', 'items', index ), 'class', 'project-info-description' );
                        view.addInlineEditingAttributes( view.getRepeaterSettingKey( 'item_description', 'items', index ), 'none' );
                        #>
    
                        <div class="project-info-item">
                            <div class="project-info-item-content">
                                <# if ( item.item_image.url ) { #>
                                    <div class="img object-fit">
                                        <div class="object-fit-cover">
                                            <img src="{{ item.item_image.url }}" alt="{{ item.item_title }}">
                                        </div>
                                    </div>
                                <# } #>

                                <div class="project-info-item-description">
                                    <# if ( item.item_title ) { #>
                                        <{{ settings.title_size }} {{{ view.getRenderAttributeString( view.getRepeaterSettingKey( 'item_title', 'items', index ) ) }}}>{{{ item.item_title }}}<{{{ '/' + settings.title_size }}}>
                                    <# } #>

                                    <# if ( item.item_description ) { #>
                                        <p {{{ view.getRenderAttributeString( view.getRepeaterSettingKey( 'item_description', 'items', index ) ) }}}>{{{ item.item_description }}}</p>
                                    <# } #>
                                </div>
                            </div>
                        </div>
                    <# } ); #>
                </div>
            </div>
        <# } #>
        <?php
    }
}
