<?php
//=================================================
// Widget Recent Posts
//
// @package LoversyCore
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

class Loversy_Widget_Recent_Posts extends WP_Widget {
    function __construct() {
        $widget_ops = array(
            'classname'   => 'loversy_widget_recent_entries',
            'description' => __( 'The loversy theme most recent posts on your site', 'loversy-core' )
        );
        
        parent::__construct( 'loversy-recent-posts', __( 'Recent Posts ( Loversy )', 'loversy-core' ), $widget_ops );
        
        $this->alt_option_name = 'loversy_widget_recent_entries';
        
        add_action(
            'save_post', array(
                $this,
                'flush_widget_cache'
            )
        );
        
        add_action(
            'deleted_post', array(
                $this,
                'flush_widget_cache'
            )
        );
        
        add_action(
            'switch_theme', array(
                $this,
                'flush_widget_cache'
            )
        );
    }
    
    function widget( $args, $instance ) {
        $cache = wp_cache_get( 'loversy_widget_recent_posts', 'widget' );
        
        if ( ! is_array( $cache ) )
            $cache = array();
        
        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;
        
        if ( isset( $cache[$args['widget_id']] ) ) {
            echo $cache[$args['widget_id']];
            
            return;
        }
        
        ob_start();
        extract( $args );
        
        $title  = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'loversy-core' );
        $title  = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        
        if ( ! $number )
            $number = 10;
        $show_date      = isset( $instance['show_date'] ) ? $instance['show_date'] : false;
        $show_thumbnail = isset ( $instance['thumbnail'] ) ? $instance['thumbnail'] : false;
        
        $r = new WP_Query(
            apply_filters(
                'widget_posts_args', array(
                    'posts_per_page'      => $number,
                    'no_found_rows'       => true,
                    'post_status'         => 'publish',
                    'ignore_sticky_posts' => true
                )
            )
        );
        
        if ( $r->have_posts() ) : ?>
            <?php echo $before_widget; ?>
            
            <?php if ( $title )
                echo $before_title . $title . $after_title; ?>
            <ul class="list-unstyled items">
                <?php while ( $r->have_posts() ) : $r->the_post(); ?>
                    <li class="item">
                        <div class="row gutter-width-xs">
                            <?php if ( $show_thumbnail ) : ?>
                                <div class="col-3">
                                    <?php if ( has_post_thumbnail() ): ?>
                                        <a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>">
                                            <div class="img object-fit overflow-hidden">
                                                <div class="object-fit-cover transform-scale-h">
                                                    <img alt="<?php echo esc_attr( get_the_title() ); ?>" src="<?php the_post_thumbnail_url() ?>">
                                                </div>
                                            </div>
                                        </a>
                                    <?php endif; ?>
                                </div>
                            <?php endif; ?>
                            
                            <div class="col-9 align-self-center">
                                <p class="item-t-head">
                                    <a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a>
                                </p>
                                
                                <?php if ( $show_date ) : ?>
                                    <p class="item-date"><?php echo get_the_date(); ?></p>
                                <?php endif; ?>
                            </div>
                        </div>
                    </li>
                <?php endwhile; ?>
            </ul>
            
            <?php echo $after_widget; ?>
            
            <?php wp_reset_postdata();
        endif;
        
        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set( 'loversy_widget_recent_posts', $cache, 'widget' );
    }
    
    function update( $new_instance, $old_instance ) {
        $instance              = $old_instance;
        $instance['title']     = strip_tags( $new_instance['title'] );
        $instance['number']    = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];
        $instance['thumbnail'] = (bool) $new_instance['thumbnail'];
        $this->flush_widget_cache();
        
        $alloptions = wp_cache_get( 'alloptions', 'options' );
        
        if ( isset( $alloptions['loversy_widget_recent_entries'] ) )
            delete_option( 'loversy_widget_recent_entries' );
        
        return $instance;
    }
    
    function flush_widget_cache() {
        wp_cache_delete( 'loversy_widget_recent_posts', 'widget' );
    }
    
    function form( $instance ) {
        $title          = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number         = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date      = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
        $show_thumbnail = isset( $instance['thumbnail'] ) ? (bool) $instance['thumbnail'] : false;
        ?>

        <p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'loversy-core' ); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>"/>
        </p>

        <p>
            <label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'loversy-core' ); ?></label>
            <input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3"/>
        </p>

        <p>
            <input class="checkbox" type="checkbox" <?php checked( $show_thumbnail ); ?> id="<?php echo $this->get_field_id( 'thumbnail' ); ?>" name="<?php echo $this->get_field_name( 'thumbnail' ); ?>"/>
            <label for="<?php echo $this->get_field_id( 'thumbnail' ); ?>"><?php _e( 'Display thumbnail?', 'loversy-core' ); ?></label>
        </p>
        
        <p>
            <input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>"/>
            <label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?', 'loversy-core' ); ?></label>
        </p>
        <?php
    }
}
