<?php
//=================================================
// The template for displaying comments
//
// This is the template that displays the area of the page that contains both the current comments
// and the comment form.
// 
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

if ( post_password_required() ) {
    return;
}

$single_post_page_show_comments     = get_theme_mod( 'single_post_page_show_comments', true );
$single_post_page_show_comment_form = get_theme_mod( 'single_post_page_show_comment_form', true );
?>

<?php if ( $single_post_page_show_comments == true || $single_post_page_show_comment_form == true ) : ?>
    <div id="comments" class="comments-area<?php if ( $single_post_page_show_comments == true ) : ?> spacer m-top-xl<?php endif; ?>">
        <?php if ( $single_post_page_show_comments == true ) : ?>
            <?php if ( have_comments() ) : ?>
                <?php $comment_count = get_comments_number(); ?>

                <div class="comment-title">
                    <h4>
                        <?php echo esc_html( sprintf( _nx( '1 Comment', 'Comments (%s)', $comment_count, 'number of comments', 'loversy' ), number_format_i18n( $comment_count ) ) ); ?>
                    </h4>
                </div>

                <ul class="comment-list list-unstyled style-default">
                    <?php wp_list_comments(
                        array(
                            'style'       => 'li',
                            'max_depth'   => 5,
                            'type'        => 'all',
                            'callback'    => 'loversy_comments',
                            'avatar_size' => 100
                        )
                    ); ?>
                </ul>
                
                <?php loversy_comments_load_more(); ?>
                
                <?php if ( ! comments_open() ) : ?>
                    <div class="block spacer m-top-xl">
                        <p><?php esc_html_e( 'Comments are closed.', 'loversy' ); ?></p>
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        <?php endif; ?>
        
        <?php if ( $single_post_page_show_comment_form == true ) : ?>
            <?php
            $allowed = array(
                'span' => array(
                    'class' => true
                )
            );
            
            $comments_args = array(
                'class_submit'         => 'btn btn-outline-primary text-uppercase',
                'title_reply_before'   => '<h4 id="reply-title" class="comment-reply-title">',
                'title_reply_after'    => '</h4>',
                'title_reply'          => wp_kses( __( 'Leave a reply', 'loversy' ), $allowed ),
                'title_reply_to'       => wp_kses( __( 'Leave a reply to %s', 'loversy' ), $allowed ),
                'comment_field'        => '<div class="form-group form-group_40"><textarea id="comment" class="form-control form-control-lg" name="comment" cols="45" rows="8" placeholder="' . esc_attr__( 'Comment *', 'loversy' ) . '" aria-required="true">' . '</textarea></div>',
                'fields'               => apply_filters(
                    'comment_form_default_fields', array(
                        'author'  => '<div class="form-group form-group_40"><input id="author" class="form-control form-control-lg" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" placeholder="' . esc_attr__( 'Name *', 'loversy' ) . '" aria-required="true" /></div>',
                        'email'   => '<div class="form-group form-group_40"><input id="email" class="form-control form-control-lg" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" placeholder="' . esc_attr__( 'Email *', 'loversy' ) . '" aria-required="true" /></div>',
                        'url'     => '<div class="form-group form-group_40"><input id="url" class="form-control form-control-lg" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" placeholder="' . esc_attr__( 'Website', 'loversy' ) . '"></div>',
                        'cookies' => '<div class="form-group form-group_40"><p class="comment-form-cookies-consent custom-control custom-checkbox before"><input id="wp-comment-cookies-consent" class="custom-control-input" name="wp-comment-cookies-consent" type="checkbox" value="yes"><label class="custom-control-label" for="wp-comment-cookies-consent">' . esc_html__( 'Save my name, email, and website in this browser for the next time I comment.', 'loversy' ) . '</label></p></div>'
                    )
                ),
                'logged_in_as'         => '<div class="form-group form-group_40"><p class="logged-in-as">' . sprintf( __( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>', 'loversy' ), admin_url( 'profile.php' ), $user_identity, wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post->ID ) ) ) ) . '</p></div>',
                'must_log_in'          => '<div class="form-group form-group_40"><p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a comment.', 'loversy' ), wp_login_url( apply_filters( 'the_permalink', get_permalink( $post->ID ) ) ) ) . '</p></div>',
                'comment_notes_before' => '<div class="form-group form-group_40"><p class="comment-notes">' . sprintf( esc_html__( 'Your email address will not be published. Required fields are marked %s', 'loversy' ), '<span class="required">*</span>' ) . '</p></div>',
                'submit_field'         => '<div class="form-submit">%1$s %2$s</div>'
            );
            
            if ( comments_open() ) {
                echo '<div class="block spacer m-top-xl test">';
            }
            
            comment_form( $comments_args );
            
            if ( comments_open() ) {
                echo '</div>';
            }
            ?>
        <?php endif; ?>
    </div><!-- #comments -->
<?php endif; ?>
