<?php
//=================================================
// The template for displaying the footer
//
// Contains the closing of the #site div and all content after.
// 
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

$logo_primary           = get_theme_mod( 'custom_logo' );
$footer_copyright       = get_theme_mod( 'footer_copyright' );
$footer_action_repeater = get_theme_mod( 'footer_action_repeater' );
$search                 = get_theme_mod( 'header_search', true );
$header_menu_image      = get_theme_mod( 'header_menu_image' );

if ( $logo_primary ) {
    $logo_primary = wp_get_attachment_image_src( $logo_primary, 'loversy-logo' );
}

if ( $header_menu_image ) {
    $header_menu_image = wp_get_attachment_image_src( $header_menu_image, 'medium_large' );
}

$allowed = array(
    'a' => array(
        'target' => true,
        'href'   => true,
    )
);
?>

</main><!-- .site-main -->

<footer id="footer" class="site-footer">
    <div class="wrapper">
        <div class="footer">
            <div class="d-flex flex-column flex-lg-row flex-xl-row justify-content-between">
                <div class="align-self-center">
                    <div class="copyright">
                        <p><?php echo ! empty( $footer_copyright ) ? wp_kses( $footer_copyright, 'loversy-global-escape' ) : wp_kses( __( '&copy; 2020 Wedding Photography Theme by <a target="_blank" href="https://www.adveits.com">Adveits</a>', 'loversy' ), $allowed ); ?></p>
                    </div>
                </div>

                <div class="align-self-center">
                    <?php if ( $footer_action_repeater ) : ?>
                        <nav class="menu-secondary">
                            <ul class="nav">
                                <?php foreach ( $footer_action_repeater as $item ) : ?>
                                    <li class="nav-item">
                                        <?php
                                        $item_title = $item['item_title'];
                                        $item_text  = $item['item_text'];
                                        $item_link  = $item['item_link'];
                                        ?>
                                        <a title="<?php echo esc_attr( $item_title ); ?>" href="<?php echo esc_url( $item_link ); ?>"><?php echo wp_kses( $item_text, 'loversy-theme-typography' ); ?></a>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </nav>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</footer>

<div id="modals">
    <div class="modal fade" id="menu-modal" tabindex="-1" role="dialog" aria-labelledby="menu-modal" aria-hidden="true">
        <div class="modal-dialog modal-full" role="document">
            <div class="wrapper">
                <div class="modal-content">
                    <div class="modal-header modal-header-top">
                        <a title="<?php bloginfo( 'name' ); ?>" class="logo logo-primary transform-scale-h" href="<?php echo esc_url( home_url() ); ?>">
                            <?php if ( $logo_primary ) : ?>
                                <img src="<?php echo esc_url( $logo_primary[0] ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
                            <?php else : ?>
                                <img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/img/logo/logo.svg" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
                            <?php endif; ?>
                        </a>

                        <button type="button" class="close btn btn-link border-0 min-w-auto" data-dismiss="modal" aria-label="Close">
                                <span class="adveits-i adv-close">
                                    <span></span>
                                    <span></span>
                                </span>
                        </button>
                    </div>

                    <div class="modal-body modal-body-centered">
                        <div class="d-flex justify-content-center w-100">
                            <div class="menu-img">
                                <?php if ( $header_menu_image ) : ?>
                                    <img src="<?php echo esc_url( $header_menu_image[0] ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
                                <?php else : ?>
                                    <img src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/img/menu/menu-img.png" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
                                <?php endif; ?>
                            </div>

                            <div class="animated fadeindown">
                                <?php loversy_menu_primary(); ?>
                                
                                <?php if ( true == $search ) : ?>
                                    <div class="search-toggle">
                                        <button type="button" class="btn btn-link btn-line p-0 border-0 min-w-auto text-uppercase" data-toggle="modal" data-target="#search-modal"><?php esc_html_e( 'Search', 'loversy' ); ?></button>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div><!-- #menu-modal -->
    
    <?php if ( true == $search ) : ?>
        <div class="modal fade" id="search-modal" tabindex="-1" role="dialog" aria-labelledby="search-modal" aria-hidden="true">
            <div class="modal-dialog modal-full" role="document">
                <div class="wrapper">
                    <div class="modal-content">
                        <div class="modal-header modal-header-top">
                            <button type="button" class="close btn btn-link border-0 min-w-auto" data-dismiss="modal" aria-label="Close">
                                    <span class="adveits-i adv-close">
                                        <span></span>
                                        <span></span>
                                    </span>
                            </button>
                        </div>

                        <div class="modal-body modal-body-centered">
                            <?php get_search_form(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div><!-- #search-modal -->
    <?php endif; ?>
</div><!-- #modals -->

<?php wp_footer(); ?>

</body>
</html>
