<?php
//=================================================
// Loversy functions and definitions
// 
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

define( 'LOVERSY_VERSION', time() );
define( 'LOVERSY_URL', get_template_directory_uri() );

//=================================================
// Register scripts 
//=================================================
function loversy_scripts() {
    global $wp_query, $cpage, $parent_post_id;
    
    // Style
    wp_enqueue_style( 'loversy-custom-style', get_stylesheet_uri() );
    wp_enqueue_style( 'loversy-wordpress-style', LOVERSY_URL . '/assets/css/wordpress-style.min.css', array(), LOVERSY_VERSION );
    wp_enqueue_style( 'loversy-main-style', LOVERSY_URL . '/assets/css/style.min.css', array(), LOVERSY_VERSION );
    
    // Script
    wp_enqueue_script( 'loversy-main-script', LOVERSY_URL . '/assets/js/main.min.js', array(), LOVERSY_VERSION, true );
    
    // Comments
    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
    
    // Load more
    wp_register_script( 'loversy-load-more-script', LOVERSY_URL . '/assets/js/ajax-load-more.min.js', array( 'jquery' ), LOVERSY_VERSION, true );
    
    wp_localize_script(
        'loversy-load-more-script', 'loversy_loadmore_params', array(
            'ajaxurl'            => esc_url( site_url() . '/wp-admin/admin-ajax.php' ),
            'posts'              => json_encode( $wp_query->query_vars ),
            'current_page'       => $wp_query->query_vars['paged'] ? $wp_query->query_vars['paged'] : 1,
            'max_page'           => $wp_query->max_num_pages,
            'loading_text'       => esc_html__( 'Loading...', 'loversy' ),
            'load_more_text'     => esc_html__( 'Load more', 'loversy' ),
            'more_comments_text' => esc_html__( 'More comments', 'loversy' )
        )
    );
    
    wp_enqueue_script( 'loversy-load-more-script' );
}

add_action( 'wp_enqueue_scripts', 'loversy_scripts' );

//=================================================
// Setup
//=================================================
if ( ! function_exists( 'loversy_setup' ) ) {
    function loversy_setup() {
        // Languages
        load_theme_textdomain( 'loversy', get_template_directory() . '/languages' );
        
        // Theme support
        add_theme_support( 'automatic-feed-links' );
        
        add_theme_support( 'title-tag' );
        
        add_theme_support( 'post-thumbnails' );
        
        add_theme_support(
            'html5', array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption'
            )
        );
        
        add_theme_support( 'customize-selective-refresh-widgets' );
        
        add_theme_support(
            'custom-logo', array(
                'height'     => 100,
                'width'      => 400,
                'flex-width' => true
            )
        );
        
        // Menu
        register_nav_menus(
            array(
                'menu-1' => esc_html__( 'Primary', 'loversy' )
            )
        );
    }
}

add_action( 'after_setup_theme', 'loversy_setup' );

//=================================================
// Set the content width in pixels, based on the theme's design and stylesheet
//=================================================
function loversy_content_width() {
    $GLOBALS['content_width'] = apply_filters( 'loversy_content_width', 1050 );
}

add_action( 'after_setup_theme', 'loversy_content_width', 0 );

//=================================================
// Register widget area
//=================================================
function loversy_widgets_init() {
    register_sidebar(
        array(
            'name'          => esc_html__( 'Sidebar', 'loversy' ),
            'description'   => esc_html__( 'Add widgets here.', 'loversy' ),
            'id'            => 'sidebar-1',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h5 class="widget-title">',
            'after_title'   => '</h5>'
        )
    );
}

add_action( 'widgets_init', 'loversy_widgets_init' );

//=================================================
// Specifying the various image sizes for theme
//=================================================
if ( function_exists( 'add_image_size' ) ) {
    add_image_size( 'loversy-logo', 220, 62 );
}

//=================================================
// Required files
//=================================================
//=============================
// Customizer
//=============================
require_once get_template_directory() . '/inc/admin/customizer/customizer.php';

//=============================
// Elementor
//=============================
require_once get_template_directory() . '/inc/admin/elementor/elementor.php';

//=============================
// Gutenberg
//=============================
require_once get_template_directory() . '/inc/admin/gutenberg/gutenberg.php';

//=============================
// Welcome
//=============================
require_once get_template_directory() . '/inc/admin/welcome/welcome.php';

//=============================
// Template callback
//=============================
require_once get_template_directory() . '/inc/template/template-callback.php';

//=============================
// Template functions
//=============================
require_once get_template_directory() . '/inc/template/template-functions.php';

//=============================
// Template tags
//=============================
require_once get_template_directory() . '/inc/template/template-tags.php';

//=============================
// WPCF7
//=============================
require_once get_template_directory() . '/inc/template/plugins/wpcf7/wpcf7.php';
