<?php
//=================================================
// The header for our theme
//
// This is the template that displays all of the <head> section and everything up until <main id="main">
// 
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================
?>
<!doctype html>
<html <?php language_attributes(); ?>>
    <head>
        <meta charset="<?php bloginfo( 'charset' ); ?>">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <link rel="profile" href="https://gmpg.org/xfn/11">
        
        <?php if ( ! has_site_icon() ) : ?>
            <link rel="icon" href="<?php echo get_stylesheet_directory_uri(); ?>/assets/img/favicon/favicon-16x16.ico">
        <?php endif; ?>
        
        <?php loversy_logo_container_width(); ?>
    
        <?php wp_head(); ?>
    </head>

    <body <?php body_class(); ?>>
        <?php wp_body_open(); ?>
        <?php
        // Logo
        $logo_primary = get_theme_mod( 'custom_logo' );
        
        if ( $logo_primary ) {
            $logo_primary = wp_get_attachment_image_src( $logo_primary, 'loversy-logo' );
        }
        
        // Loading
        $window_overlay = get_theme_mod( 'window_overlay', true );
        ?>
        
        <?php if ( ! is_customize_preview() && true == $window_overlay ) : ?>
            <div class="loading">
                <div class="wrapper h-100">
                    <div class="d-flex justify-content-center align-items-center h-100">
                        <div class="loading-content">
                            <div class="logo logo-secondary">
                                <?php if ( $logo_primary ) : ?>
                                    <img class="animated zoomin" src="<?php echo esc_url( $logo_primary[0] ); ?>" alt="<?php bloginfo( 'name' ); ?>">
                                <?php else : ?>
                                    <img class="animated zoomin" src="<?php echo get_template_directory_uri(); ?>/assets/img/logo/logo.svg" alt="<?php bloginfo( 'name' ); ?>">
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div><!-- .loading -->
        <?php endif; ?>

        <header id="header" class="site-header">
            <div class="wrapper">
                <div class="header-content d-flex justify-content-between">
                    <div class="header-logo">
                        <a class="logo logo-primary transform-scale-h" title="<?php bloginfo( 'name' ); ?>" href="<?php echo esc_url( home_url() ); ?>">
                            <?php if ( $logo_primary ) : ?>
                                <img src="<?php echo esc_url( $logo_primary[0] ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
                            <?php else : ?>
                                <img src="<?php echo get_template_directory_uri(); ?>/assets/img/logo/logo.svg" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
                            <?php endif; ?>
                        </a>
                    </div>

                    <div class="header-menu">
                        <div class="menu-toggle no-space">
                            <button type="button" class="btn btn-link border-0 p-0 min-w-auto" data-toggle="modal" data-target="#menu-modal">
                                <span class="adveits-i adv-hamburger">
                                    <span></span>
                                    <span></span>
                                </span>
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </header>

        <main id="main" class="<?php loversy_main(); ?>">
        