<?php
//=================================================
// This file adds a custom section in the customizer that recommends the installation of the Kirki plugin.
// It can be used as-is in themes (drop-in).
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

if ( ! function_exists( 'kirki_installer_register' ) ) {
    function kirki_installer_register( $wp_customize ) {
        if ( class_exists( 'Kirki' ) ) {
            return;
        }
        
        if ( class_exists( 'WP_Customize_Section' ) && ! class_exists( 'Kirki_Installer_Section' ) ) {
            class Kirki_Installer_Section extends WP_Customize_Section {
                public $type = 'kirki_installer';
                public $plugin_install_url;
                
                protected function render() {
                    if ( $this->is_dismissed() ) {
                        return;
                    }
                    
                    $plugins   = get_plugins();
                    $installed = false;
                    
                    foreach ( $plugins as $plugin ) {
                        if ( 'Kirki' === $plugin['Name'] || 'Kirki Toolkit' === $plugin['Name'] || 'Kirki Customizer Framework' === $plugin['Name'] ) {
                            $installed = true;
                        }
                    }
                    
                    $plugin_install_url = $this->get_plugin_install_url();
                    $classes            = 'cannot-expand accordion-section control-section control-section-themes control-section-' . $this->type;
                    ?>

                    <li id="accordion-section-<?php echo esc_attr( $this->id ); ?>" class="<?php echo esc_attr( $classes ); ?>" style="border-top:none;border-bottom:1px solid #ddd;padding:7px 14px 16px 14px;text-align:right;">
                        <?php if ( ! $installed ) : ?>
                            <?php $this->install_button(); ?>
                        <?php else : ?>
                            <?php $this->activate_button(); ?>
                        <?php endif; ?>
                        
                        <?php $this->dismiss_button(); ?>
                    </li>
                    <?php
                }
                
                public static function is_dismissed() {
                    $user_id   = get_current_user_id();
                    $user_meta = get_user_meta( $user_id, 'dismiss-kirki-recommendation', true );
                    
                    return ( true === $user_meta || '1' === $user_meta || 1 === $user_meta );
                }
                
                protected function install_button() {
                    ?>
                    <p style="text-align:left;margin-top:0;">
                        <?php esc_html_e( 'Please install the Kirki Customizer Framework plugin to take full advantage of this theme\'s customizer capabilities', 'loversy' ); ?>
                    </p>
                    <a class="install-now button-primary button" data-slug="kirki" href="<?php echo esc_url_raw( self_admin_url( 'themes.php?page=welcome_to_loversy_theme&kirki=yes#install-plugins' ) ); ?>" aria-label="<?php esc_attr_e( 'Install Kirki Customizer Framework now', 'loversy' ); ?>" data-name="Kirki Customizer Framework">
                        <?php esc_html_e( 'Install Now', 'loversy' ); ?>
                    </a>
                    <?php
                }
                
                protected function activate_button() {
                    ?>
                    <p style="text-align:left;margin-top:0;">
                        <?php esc_html_e( 'You have installed Kirki Customizer Framework. Activate it to take advantage of this theme\'s features in the customizer.', 'loversy' ); ?>
                    </p>
                    <a class="activate-now button-primary button" data-slug="kirki" href="<?php echo esc_url_raw( self_admin_url( 'themes.php?page=welcome_to_loversy_theme&kirki=yes#install-plugins' ) ); ?>" aria-label="<?php esc_attr_e( 'Activate Kirki Customizer Framework now', 'loversy' ); ?>" data-name="Kirki Customizer Framework">
                        <?php esc_html_e( 'Activate Now', 'loversy' ); ?>
                    </a>
                    <?php
                }
                
                protected function dismiss_button() {
                    $ajax_nonce   = wp_create_nonce( 'dismiss-kirki-recommendation' );
                    $show_confirm = true;
                    ?>

                    <a class="kirki-installer-dismiss button-secondary button" data-slug="kirki" href="#" aria-label="<?php esc_attr_e( 'Don\'t show this again', 'loversy' ); ?>" data-name="<?php esc_attr_e( 'Dismiss', 'loversy' ); ?>">
                        <?php esc_html_e( 'Don\'t show this again', 'loversy' ); ?>
                    </a>

                    <script type="text/javascript">
                        jQuery( document ).ready( function() {
                            jQuery( '.kirki-installer-dismiss' ).on( 'click', function( event ) {
                                event.preventDefault();
                                <?php if ( $show_confirm ) : ?>
                                if ( ! confirm( '<?php esc_html_e( 'Are you sure? Dismissing this message will hide the installation recommendation and you will have to manually install and activate the plugin in the future.', 'loversy' ); ?>' ) ) {
                                    return;
                                }
                                <?php endif; ?>
                                jQuery.post( ajaxurl, {
                                    action: 'kirki_installer_dismiss',
                                    security: '<?php echo esc_html( $ajax_nonce ); ?>',
                                }, function( response ) {
                                    jQuery( '#accordion-section-kirki_installer' ).remove();
                                } );
                            } );
                        } );
                    </script>
                    <?php
                }
                
                private function get_plugin_install_url() {
                    if ( ! $this->plugin_install_url ) {
                        $this->plugin_install_url = add_query_arg(
                            array(
                                'action' => 'install-plugin',
                                'plugin' => 'kirki',
                            ), self_admin_url( 'update.php' )
                        );
                        $this->plugin_install_url = wp_nonce_url( $this->plugin_install_url, 'install-plugin_kirki' );
                    }
                    
                    return $this->plugin_install_url;
                }
            }
        }
        
        if ( is_callable(
                array(
                    'Kirki_Installer_Section',
                    'is_dismissed'
                )
            ) && Kirki_Installer_Section::is_dismissed() ) {
            return;
        }
        
        $wp_customize->add_section(
            new Kirki_Installer_Section(
                $wp_customize, 'kirki_installer', array(
                    'title'      => '',
                    'capability' => 'install_plugins',
                    'priority'   => 0,
                )
            )
        );
        
        $wp_customize->add_setting(
            'kirki_installer_setting', array(
                'sanitize_callback' => '__return_true',
            )
        );
        
        $wp_customize->add_control(
            'kirki_installer_control', array(
                'section'  => 'kirki_installer',
                'settings' => 'kirki_installer_setting',
            )
        );
    }
}

add_action( 'customize_register', 'kirki_installer_register', 999 );

if ( ! function_exists( 'kirki_installer_dismiss' ) ) {
    function kirki_installer_dismiss() {
        check_ajax_referer( 'dismiss-kirki-recommendation', 'security' );
        $user_id = get_current_user_id();
        
        if ( update_user_meta( $user_id, 'dismiss-kirki-recommendation', true ) ) {
            echo 'success! :)';
            
            wp_die();
        }
        
        echo 'failed :(';
        
        wp_die();
    }
}

add_action( 'wp_ajax_kirki_installer_dismiss', 'kirki_installer_dismiss' );
