<?php
//=================================================
// Loversy theme customizer
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

include_once get_theme_file_path( 'inc/admin/customizer/classes/class-kirki-installer-section.php' );

//=================================================
// Customize register
//=================================================
function loversy_customize_register( $wp_customize ) {
    // Remove sections
    $wp_customize->remove_section( 'background_image' );
    $wp_customize->remove_section( 'header_image' );
    $wp_customize->remove_section( 'colors' );
    
    // Remove settings
    $wp_customize->remove_setting( 'background_image' );
    $wp_customize->remove_setting( 'background_image_thumb' );
    $wp_customize->remove_setting( 'header_image' );
    $wp_customize->remove_setting( 'header_image_data' );
    
    // Remove controls
    $wp_customize->remove_control( 'display_header_text' );
    
    // Add partial
    if ( isset( $wp_customize->selective_refresh ) ) {
        // Header
        $wp_customize->selective_refresh->add_partial(
            'custom_logo', array(
                'selector' => '.site-header .wrapper'
            )
        );
        
        // Footer
        $wp_customize->selective_refresh->add_partial(
            'footer_copyright', array(
                'selector' => '.site-footer .wrapper'
            )
        );
    }
}

add_action( 'customize_register', 'loversy_customize_register' );

//=================================================
// Register and enqueue a custom stylesheet in the WordPress customizer
//=================================================
function loversy_wpdocs_enqueue_custom_admin_style() {
    wp_enqueue_style( 'loversy-admin-customizer', LOVERSY_URL . '/inc/admin/customizer/assets/css/admin-customizer.css', array(), LOVERSY_VERSION );
}

add_action( 'admin_enqueue_scripts', 'loversy_wpdocs_enqueue_custom_admin_style' );

//=================================================
// Kirki install
//=================================================
if ( class_exists( 'Kirki' ) ) {
    $config_id        = 'loversy_theme';
    $menu_url         = admin_url( 'customize.php?autofocus[panel]=nav_menus' );
    $options_disc_url = admin_url( 'options-discussion.php' );
    $permalinks       = admin_url( 'options-permalink.php' );
    
    //========================================
    // Add the theme configuration
    //========================================
    Kirki::add_config(
        $config_id, array(
            'option_type' => 'theme_mod',
            'capability'  => 'edit_theme_options'
        )
    );
    
    //========================================
    // Loversy Options
    //========================================
    // Add panel
    Kirki::add_panel(
        'panel_loversy_options', array(
            'title'    => __( 'Loversy options', 'loversy' ),
            'priority' => 1
        )
    );
    
    //=============================
    // Header
    //=============================
    // Add section
    Kirki::add_section(
        'section_header', array(
            'title'    => __( 'Header', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 1
        )
    );
    
    // Logo
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'logo_title',
            'section'  => 'section_header',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Logo', 'loversy' ) . '</div>'
        )
    );
    
    // Logo primary
    Kirki::add_field(
        $config_id, array(
            'type'     => 'image',
            'settings' => 'custom_logo',
            'label'    => esc_html__( 'Logo', 'loversy' ),
            'section'  => 'section_header',
            'default'  => '',
            'choices'  => array(
                'save_as' => 'id'
            )
        )
    );
    
    // Logo container width
    Kirki::add_field(
        $config_id, array(
            'type'     => 'slider',
            'settings' => 'logo_container_width',
            'label'    => esc_html__( 'Logo container width', 'loversy' ),
            'section'  => 'section_header',
            'default'  => 104,
            'choices'  => array(
                'min'  => 60,
                'max'  => 200,
                'step' => 1
            )
        )
    );
    
    // Menu
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'header_menu_title',
            'section'  => 'section_header',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Menu', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'        => 'custom',
            'settings'    => 'header_menu',
            'label'       => esc_html__( 'Menu primary', 'loversy' ),
            'description' => wp_kses_post( 'If you want to change header menu you can do it in Menu section.', 'loversy' ),
            'section'     => 'section_header',
            'default'     => '<a class="button" target="_blank" href="' . esc_url( wp_nonce_url( $menu_url ) ) . '">' . esc_html__( 'Edit menu', 'loversy' ) . '</a>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'     => 'image',
            'settings' => 'header_menu_image',
            'label'    => esc_html__( 'Menu image', 'loversy' ),
            'section'  => 'section_header',
            'default'  => '',
            'choices'  => array(
                'save_as' => 'id'
            )
        )
    );
    
    // Search
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'search_title',
            'section'  => 'section_header',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Search', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'     => 'checkbox',
            'settings' => 'header_search',
            'label'    => esc_html__( 'Show search', 'loversy' ),
            'section'  => 'section_header',
            'default'  => true
        )
    );
    
    // Languages
    if ( function_exists( 'pll__' ) ) {
        // Languages title
        Kirki::add_field(
            $config_id, array(
                'type'     => 'custom',
                'settings' => 'languages_title',
                'section'  => 'section_header',
                'default'  => '<div class="options-title-divider">' . esc_html__( 'Languages', 'loversy' ) . '</div>'
            )
        );
        
        // Languages checkbox
        Kirki::add_field(
            $config_id, array(
                'type'     => 'checkbox',
                'settings' => 'header_languages',
                'label'    => esc_html__( 'Show languages', 'loversy' ),
                'section'  => 'section_header',
                'default'  => true
            )
        );
    }
    
    //=============================
    // Footer
    //=============================
    // Add section
    Kirki::add_section(
        'section_footer', array(
            'title'    => esc_html__( 'Footer', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 2
        )
    );
    
    // Copyright
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'copyright_title',
            'section'  => 'section_footer',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Copyright', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'     => 'textarea',
            'settings' => 'footer_copyright',
            'label'    => esc_html__( 'Text', 'loversy' ),
            'section'  => 'section_footer',
            'default'  => wp_kses_post( '&copy; 2020 Wedding Photography Theme by <a target="_blank" href="https://www.adveits.com">Adveits</a>', 'loversy' )
        )
    );
    
    // External links
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'footer_action',
            'section'  => 'section_footer',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'External links', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'         => 'repeater',
            'label'        => esc_html__( 'External links list', 'loversy' ),
            'section'      => 'section_footer',
            'row_label'    => array(
                'type'  => 'field',
                'value' => esc_html__( 'Item', 'loversy' ),
                'field' => 'item_title',
            ),
            'button_label' => esc_html__( 'Add new', 'loversy' ),
            'settings'     => 'footer_action_repeater',
            'fields'       => array(
                'item_title' => array(
                    'type'  => 'text',
                    'label' => esc_html__( 'Title', 'loversy' )
                ),
                'item_text'  => array(
                    'type'  => 'textarea',
                    'label' => esc_html__( 'Text', 'loversy' )
                ),
                'item_link'  => array(
                    'type'    => 'text',
                    'label'   => esc_html__( 'Link', 'loversy' ),
                    'default' => '#'
                )
            
            )
        )
    );
    
    //=============================
    // Breadcrumb
    //=============================
    // Add section
    Kirki::add_section(
        'section_breadcrumb', array(
            'title'    => esc_html__( 'Breadcrumb', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 2.08
        )
    );
    
    // Breadcrumb title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'breadcrumb_title',
            'section'  => 'section_breadcrumb',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Default', 'loversy' ) . '</div>'
        )
    );
    
    // Breadcrumb type
    Kirki::add_field(
        $config_id, array(
            'type'        => 'select',
            'settings'    => 'breadcrumb_type',
            'label'       => esc_html__( 'Breadcrumb type', 'loversy' ),
            'section'     => 'section_breadcrumb',
            'default'     => 'default',
            'placeholder' => esc_html__( 'Select an option', 'loversy' ),
            'multiple'    => 1,
            'choices'     => array(
                'default'   => esc_html__( 'Default', 'loversy' ),
                'yoast_seo' => esc_html__( 'Yoast SEO', 'loversy' )
            )
        )
    );
    
    // Breadcrumb show on page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'breadcrumb_show_on_page_title',
            'section'  => 'section_breadcrumb',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Page', 'loversy' ) . '</div>'
        )
    );
    
    // Breadcrumb show on page
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'breadcrumb_show_on_page',
            'label'    => esc_html__( 'Show on page', 'loversy' ),
            'section'  => 'section_breadcrumb',
            'default'  => '0',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Breadcrumb show on home page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'breadcrumb_show_on_home_page_title',
            'section'  => 'section_breadcrumb',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Home page', 'loversy' ) . '</div>'
        )
    );
    
    // Breadcrumb show on home page
    Kirki::add_field(
        $config_id, array(
            'type'        => 'switch',
            'settings'    => 'breadcrumb_show_on_home_page',
            'label'       => esc_html__( 'Show on home page', 'loversy' ),
            'description' => esc_html__( 'Blog page when it is in home page.', 'loversy' ),
            'section'     => 'section_breadcrumb',
            'default'     => '1',
            'choices'     => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Breadcrumb show on archive page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'breadcrumb_show_on_archive_page_title',
            'section'  => 'section_breadcrumb',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Archive page', 'loversy' ) . '</div>'
        )
    );
    
    // Breadcrumb show on archive page
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'breadcrumb_show_on_archive_page',
            'label'    => esc_html__( 'Show on archive page', 'loversy' ),
            'section'  => 'section_breadcrumb',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Breadcrumb show on single post page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'breadcrumb_show_on_single_post_page_title',
            'section'  => 'section_breadcrumb',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Single post page', 'loversy' ) . '</div>'
        )
    );
    
    // Breadcrumb show on single post page
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'breadcrumb_show_on_single_post_page',
            'label'    => esc_html__( 'Show on single post page', 'loversy' ),
            'section'  => 'section_breadcrumb',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    //=============================
    // Window overlay ( Loading )
    //=============================
    // Add section
    Kirki::add_section(
        'section_window_overlay', array(
            'title'    => esc_html__( 'Window overlay ( Loading )', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 2.09
        )
    );
    
    // Window overlay title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'window_overlay_title',
            'section'  => 'section_window_overlay',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Default', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'     => 'checkbox',
            'settings' => 'window_overlay',
            'label'    => esc_html__( 'Show on all pages', 'loversy' ),
            'section'  => 'section_window_overlay',
            'default'  => true
        )
    );
    
    //=============================
    // Background
    //=============================
    // Add section
    Kirki::add_section(
        'section_background', array(
            'title'    => esc_html__( 'Background', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 2.2
        )
    );
    
    // Background default title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'background_default_title',
            'section'  => 'section_background',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Default', 'loversy' ) . '</div>'
        )
    );
    
    // Background variations
    Kirki::add_field(
        $config_id, array(
            'type'        => 'select',
            'settings'    => 'background_variations',
            'label'       => esc_html__( 'Body background image', 'loversy' ),
            'section'     => 'section_background',
            'default'     => 'option-none',
            'placeholder' => esc_html__( 'Select an option', 'loversy' ),
            'priority'    => 10,
            'multiple'    => 1,
            'choices'     => array(
                'option-none' => esc_html__( 'None', 'loversy' )
            )
        )
    );
    
    //=============================
    // Colors
    //=============================
    // Add section
    Kirki::add_section(
        'section_colors', array(
            'title'    => esc_html__( 'Colors', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 3
        )
    );
    
    //=====================
    // Body
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'body_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Body', 'loversy' ) . '</div>'
        )
    );
    
    // Body text primary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_text_primary_color',
            'label'     => esc_html__( 'Body text primary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#706e67',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'body, caption, .figure-caption, .form-control-plaintext, .list-group-item-action:active, .table, .table-hover tbody tr:hover, .widget-area .widget a, .widget-area .widget .dropdown-icon, [class*=\'widget-container\'] .widget a, [class*=\'widget-container\'] .widget .dropdown-icon, .widget-area .widget.widget_recent_comments ul li.recentcomments > a, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments > a, #comments #respond .comment-form .comment-form-cookies-consent label, .contacts-item .contacts-item-content .contacts-item-description a, .portfolio-pagination .link .link-text',
                    'property' => 'color',
                    'exclude'  => array( '#706e67' )
                ),
                array(
                    'element'  => '.custom-control-label::before',
                    'property' => 'border-color',
                    'exclude'  => array( '#706e67' )
                ),
                array(
                    'element'  => '.custom-switch .custom-control-label::after',
                    'property' => 'background-color',
                    'exclude'  => array( '#706e67' )
                ),
                array(
                    'element'  => '.text-body',
                    'property' => 'color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#706e67' )
                )
            )
        )
    );
    
    // Body text secondary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_text_secondary_color',
            'label'     => esc_html__( 'Body text secondary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.text-secondary',
                    'property' => 'color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Body text tertiary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_text_tertiary_color',
            'label'     => esc_html__( 'Body text tertiary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#ffffff',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.bg-dark h1, .bg-dark h2, .bg-dark h3, .bg-dark h4, .bg-dark h5, .bg-dark h6, .bg-dark a, .bg-dark p, .contact-me .contact-me-img-and-title .contact-me-title, .service-item .service-item-title',
                    'property' => 'color',
                    'exclude'  => array( '#ffffff' )
                ),
                array(
                    'element'  => '.bd-placeholder-img text',
                    'property' => 'fill',
                    'exclude'  => array( '#ffffff' )
                )
            )
        )
    );
    
    // Body headline color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_headline_color',
            'label'     => esc_html__( 'Body headline color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'h1:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), .h1:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), h2:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), .h2:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), h3:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), .h3:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), h4:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), .h4:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), h5:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), .h5:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), h6:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), .h6:not([class*=\'-title\']):not([class*=\'__title\']):not([class*=\'-heading\']):not([class*=\'__heading\']):not([class*=\'-header\']):not([class*=\'-t-head\']), h1 a, .h1 a, h2 a, .h2 a, h3 a, .h3 a, h4 a, .h4 a, h5 a, .h5 a, h6 a, .h6 a, table:not(.table-dark) th, [class*="calendar"]:not(.table-dark) th, .widget-area .widget.widget_recent_comments ul li.recentcomments, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments, .widget-area .widget.widget_recent_comments ul li.recentcomments .comment-author-link a, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments .comment-author-link a, .widget-area .widget.widget_rss .rsswidget, .footer-widget-area .widget.widget_rss .rsswidget, [class*=\'widget-container\'] .widget.widget_rss .rsswidget, .widget-area .widget.widget_rss cite, .footer-widget-area .widget.widget_rss cite, [class*=\'widget-container\'] .widget.widget_rss cite, #comments #respond .comment-reply-title, .contacts-item .contacts-item-content .contacts-item-title, .project-info .project-info-items .project-info-item .project-info-item-content .project-info-item-description .project-info-title',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Body links color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_links_color',
            'label'     => esc_html__( 'Body links color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'a, .btn-link, [class*=\'-block-search\'] [class*=\'-block-search__button\'], [class*=\'-password-form\'] input[type="submit"], .close, .close:hover, .page-link, [class*="calendar"] tfoot a, .btn.btn-link, [class*=\'-block-search\'] [class*=\'-block-search__button\'], [class*=\'-password-form\'] input[type="submit"], .widget-area .tagcloud .btn-link.tag-cloud-link, .widget-area .tagcloud [class*=\'-block-search\'] .tag-cloud-link[class*=\'-block-search__button\'], [class*=\'-block-search\'] .widget-area .tagcloud .tag-cloud-link[class*=\'-block-search__button\'], .widget-area .tagcloud [class*=\'-password-form\'] input.tag-cloud-link[type="submit"], [class*=\'-password-form\'] .widget-area .tagcloud input.tag-cloud-link[type="submit"], [class*=\'widget-container\'] .tagcloud .btn-link.tag-cloud-link, [class*=\'widget-container\'] .tagcloud [class*=\'-block-search\'] .tag-cloud-link[class*=\'-block-search__button\'], [class*=\'-block-search\'] [class*=\'widget-container\'] .tagcloud .tag-cloud-link[class*=\'-block-search__button\'], [class*=\'widget-container\'] .tagcloud [class*=\'-password-form\'] input.tag-cloud-link[type="submit"], [class*=\'-password-form\'] [class*=\'widget-container\'] .tagcloud input.tag-cloud-link[type="submit"], #single .single-content .description [class*=\'tag-cloud\'] .btn-link.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] .tag-cloud-link[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link[class*=\'-block-search__button\'], #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-password-form\'] input.tag-cloud-link[type="submit"], [class*=\'-password-form\'] #single .single-content .description [class*=\'tag-cloud\'] input.tag-cloud-link[type="submit"], #single .single-content .tags p a.btn-link, #single .single-content .tags p [class*=\'-block-search\'] a[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .tags p a[class*=\'-block-search__button\'], .card-post .card-body .card-title a, .widget-area .widget.widget_calendar .calendar_wrap a, [class*=\'widget-container\'] .widget.widget_calendar .calendar_wrap a',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.adveits-i.adv-hamburger span, .adveits-i.adv-close span, .btn.btn-line:after, [class*=\'-block-search\'] .btn-line[class*=\'-block-search__button\']:after, [class*=\'-password-form\'] input.btn-line[type="submit"]:after, .widget-area .tagcloud .btn-line.tag-cloud-link:after, [class*=\'widget-container\'] .tagcloud .btn-line.tag-cloud-link:after, #single .single-content .description [class*=\'tag-cloud\'] .btn-line.tag-cloud-link:after, #single .single-content .tags p a.btn-line:after, .pagination .page-item .page-link:hover, .pagination .post-page-numbers .page-link:hover, .pagination .page-item.current .page-link, .pagination .page-item.active .page-link, .pagination .post-page-numbers.current .page-link, .pagination .post-page-numbers.active .page-link',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Body links hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_links_hover_color',
            'label'     => esc_html__( 'Body links hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'a:hover, .btn-link:hover, [class*=\'-block-search\'] :hover[class*=\'-block-search__button\'], [class*=\'-password-form\'] input:hover[type="submit"], .page-link:hover, .close:hover, [class*="calendar"] tfoot a:hover, .btn.btn-link:hover, [class*=\'-block-search\'] :hover[class*=\'-block-search__button\'], [class*=\'-password-form\'] input:hover[type="submit"], .widget-area .tagcloud .btn-link.tag-cloud-link:hover, [class*=\'widget-container\'] .tagcloud .btn-link.tag-cloud-link:hover, #single .single-content .description [class*=\'tag-cloud\'] .btn-link.tag-cloud-link:hover, #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] .tag-cloud-link:hover[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:hover[class*=\'-block-search__button\'], #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-password-form\'] input.tag-cloud-link:hover[type="submit"], [class*=\'-password-form\'] #single .single-content .description [class*=\'tag-cloud\'] input.tag-cloud-link:hover[type="submit"], #single .single-content .tags p a.btn-link:hover, #single .single-content .tags p [class*=\'-block-search\'] a:hover[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .tags p a:hover[class*=\'-block-search__button\'], .card .card-meta p a:hover, .card-post .card-body .card-title a:hover, .widget-area .widget a:hover, .widget-area .widget .dropdown-icon:hover, [class*=\'widget-container\'] .widget a:hover, [class*=\'widget-container\'] .widget .dropdown-icon:hover, .widget-area .widget.widget_calendar .calendar_wrap a:hover, [class*=\'widget-container\'] .widget.widget_calendar .calendar_wrap a:hover, .widget-area .widget.widget_recent_comments ul li.recentcomments > a:hover, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments > a:hover, .widget-area .widget.widget_recent_comments ul li.recentcomments .comment-author-link a:hover, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments .comment-author-link a:hover, .widget-area .widget nav[class*="menu"] > ul li > .dropdown-custom-icon > .dropdown-icon:hover, .footer-widget-area .widget nav[class*="menu"] > ul li > .dropdown-custom-icon > .dropdown-icon:hover, [class*=\'widget-container\'] .widget nav[class*="menu"] > ul li > .dropdown-custom-icon > .dropdown-icon:hover, .widget-area .widget nav[class*="menu"] > ul li.hover-class > a, .widget-area .widget nav[class*="menu"] > ul li.hover-class > .dropdown-toggle .dropdown-icon, .widget-area .widget nav[class*="menu"] > ul li.show > a, .widget-area .widget nav[class*="menu"] > ul li.show > .dropdown-toggle .dropdown-icon, .footer-widget-area .widget nav[class*="menu"] > ul li.hover-class > a, .footer-widget-area .widget nav[class*="menu"] > ul li.hover-class > .dropdown-toggle .dropdown-icon, .footer-widget-area .widget nav[class*="menu"] > ul li.show > a, .footer-widget-area .widget nav[class*="menu"] > ul li.show > .dropdown-toggle .dropdown-icon, [class*=\'widget-container\'] .widget nav[class*="menu"] > ul li.hover-class > a, [class*=\'widget-container\'] .widget nav[class*="menu"] > ul li.hover-class > .dropdown-toggle .dropdown-icon, [class*=\'widget-container\'] .widget nav[class*="menu"] > ul li.show > a, [class*=\'widget-container\'] .widget nav[class*="menu"] > ul li.show > .dropdown-toggle .dropdown-icon, .widget-area .widget.widget_rss a:hover, .footer-widget-area .widget.widget_rss a:hover, [class*=\'widget-container\'] .widget.widget_rss a:hover, #single .single-content .meta p span a:hover, .contacts-item .contacts-item-content .contacts-item-description a:hover',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                ),
                array(
                    'element'  => 'a.text-secondary:hover',
                    'property' => 'color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#8d9893' )
                ),
                array(
                    'element'  => '.close:hover .adveits-i.adv-close span, .adveits-i.adv-hamburger:hover span, .adveits-i.adv-close:hover span, .btn.btn-line:hover:after, [class*=\'-block-search\'] .btn-line[class*=\'-block-search__button\']:hover:after, [class*=\'-password-form\'] input.btn-line[type="submit"]:hover:after, .widget-area .tagcloud .btn-line.tag-cloud-link:hover:after, [class*=\'widget-container\'] .tagcloud .btn-line.tag-cloud-link:hover:after, #single .single-content .description [class*=\'tag-cloud\'] .btn-line.tag-cloud-link:hover:after, #single .single-content .tags p a.btn-line:hover:after',
                    'property' => 'background-color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    // Body background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_background_color',
            'label'     => esc_html__( 'Body background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f3f2f1',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.list-group-item, .list-group-item.disabled, .list-group-item:disabled, .page-link, body, .loading, .browser, .contact-me .contact-me-content .contact-me-content-2, .bd-example',
                    'property' => 'background-color',
                    'exclude'  => array( '#f3f2f1' )
                )
            )
        )
    );
    
    // Body main element primary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_main_element_primary_color',
            'label'     => esc_html__( 'Body main element primary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.btn-primary, .widget-area .tagcloud .tag-cloud-link, [class*=\'widget-container\'] .tagcloud .tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link, #single .single-content .tags p a, .btn-primary.disabled, .widget-area .tagcloud .disabled.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .disabled.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .disabled.tag-cloud-link, #single .single-content .tags p a.disabled, .btn-primary:disabled, .widget-area .tagcloud .tag-cloud-link:disabled, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:disabled, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:disabled, #single .single-content .tags p a:disabled, .btn-outline-primary:hover, .btn-outline-primary:not(:disabled):not(.disabled):active, .btn-outline-primary:not(:disabled):not(.disabled).active, .show > .btn-outline-primary.dropdown-toggle, .custom-control-input:not(:disabled):active ~ .custom-control-label::before, .list-group-item.active, .page-item.active .page-link, .nav-pills .nav-link.active, .nav-pills .show > .nav-link, .badge-primary',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.btn-primary, .widget-area .tagcloud .tag-cloud-link, [class*=\'widget-container\'] .tagcloud .tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link, #single .single-content .tags p a, .btn-primary.disabled, .widget-area .tagcloud .disabled.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .disabled.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .disabled.tag-cloud-link, #single .single-content .tags p a.disabled, .btn-primary:disabled, .widget-area .tagcloud .tag-cloud-link:disabled, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:disabled, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:disabled, #single .single-content .tags p a:disabled, .btn-outline-primary, .btn-outline-primary:hover, .btn-outline-primary:not(:disabled):not(.disabled):active, .btn-outline-primary:not(:disabled):not(.disabled).active, .show > .btn-outline-primary.dropdown-toggle, .custom-control-input:not(:disabled):active ~ .custom-control-label::before, .list-group-item.active, .page-item.active .page-link',
                    'property' => 'border-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.btn-outline-primary, .btn-outline-primary.disabled, .btn-outline-primary:disabled, blockquote, .blockquote, ul li:before, .card .card-meta p, .card .card-meta p a, .widget-area .widget.widget_rss .rss-date, .footer-widget-area .widget.widget_rss .rss-date, [class*=\'widget-container\'] .widget.widget_rss .rss-date, #comments .comment-list .comment .comment-wrapper .comment-details .comment-content .comment-content-right .comment-time p, #comments .comment-list .trackback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-time p, #comments .comment-list .pingback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-time p, #single .single-content .meta p',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-control-input:checked ~ .custom-control-label::before',
                    'property' => 'border-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-control-input:checked ~ .custom-control-label::before',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-checkbox .custom-control-input:indeterminate ~ .custom-control-label::before',
                    'property' => 'border-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-checkbox .custom-control-input:indeterminate ~ .custom-control-label::before',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-range::-webkit-slider-thumb',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-range::-moz-range-thumb',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.custom-range::-ms-thumb',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.bg-primary',
                    'property' => 'background-color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.border-primary',
                    'property' => 'border-color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.text-primary',
                    'property' => 'color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '::-moz-selection',
                    'property' => 'background',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '::selection',
                    'property' => 'background',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'       => 'blockquote, .blockquote',
                    'property'      => 'border-left',
                    'value_pattern' => '2px solid $',
                    'exclude'       => array( '#274035' )
                ),
                array(
                    'element'  => '.bd-placeholder-img',
                    'property' => 'fill',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.btn-primary:hover, .widget-area .tagcloud .tag-cloud-link:hover, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:hover, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:hover, #single .single-content .tags p a:hover, .btn-primary:focus, .widget-area .tagcloud .tag-cloud-link:focus, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:focus, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:focus, #single .single-content .tags p a:focus, .btn-primary.focus, .widget-area .tagcloud .focus.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .focus.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .focus.tag-cloud-link, #single .single-content .tags p a.focus, .btn-primary:not(:disabled):not(.disabled):active, .widget-area .tagcloud .tag-cloud-link:not(:disabled):not(.disabled):active, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:not(:disabled):not(.disabled):active, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:not(:disabled):not(.disabled):active, #single .single-content .tags p a:not(:disabled):not(.disabled):active, .btn-primary:not(:disabled):not(.disabled).active, .widget-area .tagcloud .tag-cloud-link:not(:disabled):not(.disabled).active, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:not(:disabled):not(.disabled).active, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:not(:disabled):not(.disabled).active, #single .single-content .tags p a:not(:disabled):not(.disabled).active, .show > .btn-primary.dropdown-toggle, .widget-area .tagcloud .show > .dropdown-toggle.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .show > .dropdown-toggle.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .show > .dropdown-toggle.tag-cloud-link, #single .single-content .tags p .show > a.dropdown-toggle',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => 'a.bg-primary:hover, a.bg-primary:focus, button.bg-primary:hover, button.bg-primary:focus',
                    'property' => 'background-color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.btn-primary:hover, .widget-area .tagcloud .tag-cloud-link:hover, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:hover, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:hover, #single .single-content .tags p a:hover, .btn-primary:focus, .widget-area .tagcloud .tag-cloud-link:focus, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:focus, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:focus, #single .single-content .tags p a:focus, .btn-primary.focus, .widget-area .tagcloud .focus.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .focus.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .focus.tag-cloud-link, #single .single-content .tags p a.focus, .btn-primary:not(:disabled):not(.disabled):active, .widget-area .tagcloud .tag-cloud-link:not(:disabled):not(.disabled):active, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:not(:disabled):not(.disabled):active, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:not(:disabled):not(.disabled):active, #single .single-content .tags p a:not(:disabled):not(.disabled):active, .btn-primary:not(:disabled):not(.disabled).active, .widget-area .tagcloud .tag-cloud-link:not(:disabled):not(.disabled).active, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:not(:disabled):not(.disabled).active, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:not(:disabled):not(.disabled).active, #single .single-content .tags p a:not(:disabled):not(.disabled).active, .show > .btn-primary.dropdown-toggle, .widget-area .tagcloud .show > .dropdown-toggle.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .show > .dropdown-toggle.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .show > .dropdown-toggle.tag-cloud-link, #single .single-content .tags p .show > a.dropdown-toggle',
                    'property' => 'border-color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'       => '.btn-primary:hover, .widget-area .tagcloud .tag-cloud-link:hover, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:hover, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:hover, #single .single-content .tags p a:hover, .btn-primary:focus, .widget-area .tagcloud .tag-cloud-link:focus, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:focus, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:focus, #single .single-content .tags p a:focus, .btn-primary.focus, .widget-area .tagcloud .focus.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .focus.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .focus.tag-cloud-link, #single .single-content .tags p a.focus, .btn-primary:not(:disabled):not(.disabled):active, .widget-area .tagcloud .tag-cloud-link:not(:disabled):not(.disabled):active, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:not(:disabled):not(.disabled):active, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:not(:disabled):not(.disabled):active, #single .single-content .tags p a:not(:disabled):not(.disabled):active, .btn-primary:not(:disabled):not(.disabled).active, .widget-area .tagcloud .tag-cloud-link:not(:disabled):not(.disabled).active, [class*=\'widget-container\'] .tagcloud .tag-cloud-link:not(:disabled):not(.disabled).active, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link:not(:disabled):not(.disabled).active, #single .single-content .tags p a:not(:disabled):not(.disabled).active, .show > .btn-primary.dropdown-toggle, .widget-area .tagcloud .show > .dropdown-toggle.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .show > .dropdown-toggle.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .show > .dropdown-toggle.tag-cloud-link, #single .single-content .tags p .show > a.dropdown-toggle',
                    'property'      => 'opacity',
                    'value_pattern' => '0.8',
                    'suffix'        => ' !important',
                    'exclude'       => array( '#274035' )
                )
            )
        )
    );
    
    // Body main element secondary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_main_element_secondary_color',
            'label'     => esc_html__( 'Body main element secondary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#000000',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.btn-secondary, .btn-secondary.disabled, .btn-secondary:disabled, .btn-outline-secondary:hover, .btn-outline-secondary:not(:disabled):not(.disabled):active, .btn-outline-secondary:not(:disabled):not(.disabled).active, .show > .btn-outline-secondary.dropdown-toggle, .badge-secondary, .service-item .img-bg-color',
                    'property' => 'background-color',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.btn-secondary, .btn-secondary.disabled, .btn-secondary:disabled, .btn-outline-secondary, .btn-outline-secondary:hover, .btn-outline-secondary:not(:disabled):not(.disabled):active, .btn-outline-secondary:not(:disabled):not(.disabled).active, .show > .btn-outline-secondary.dropdown-toggle',
                    'property' => 'border-color',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.btn-outline-secondary, .btn-outline-secondary.disabled, .btn-outline-secondary:disabled',
                    'property' => 'color',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.bg-secondary',
                    'property' => 'background-color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.border-secondary',
                    'property' => 'border-color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.text-secondary',
                    'property' => 'color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.btn-secondary:hover, .btn-secondary:focus, .btn-secondary.focus, .btn-secondary:not(:disabled):not(.disabled):active, .btn-secondary:not(:disabled):not(.disabled).active, .show > .btn-secondary.dropdown-toggle, .list-group-item-secondary.list-group-item-action.active',
                    'property' => 'background-color',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'  => '.btn-secondary:hover, .btn-secondary:focus, .btn-secondary.focus, .btn-secondary:not(:disabled):not(.disabled):active, .btn-secondary:not(:disabled):not(.disabled).active, .show > .btn-secondary.dropdown-toggle, .list-group-item-secondary.list-group-item-action.active',
                    'property' => 'border-color',
                    'exclude'  => array( '#000000' )
                ),
                array(
                    'element'       => '.btn-secondary:hover, .btn-secondary:focus, .btn-secondary.focus, .btn-secondary:not(:disabled):not(.disabled):active, .btn-secondary:not(:disabled):not(.disabled).active, .show > .btn-secondary.dropdown-toggle, .list-group-item-secondary.list-group-item-action.active',
                    'property'      => 'opacity',
                    'value_pattern' => '0.8',
                    'suffix'        => ' !important',
                    'exclude'       => array( '#000000' )
                )
            )
        )
    );
    
    // Border color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_border_color',
            'label'     => esc_html__( 'Body border color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#e0e0e0',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-divider, .list-group-item, hr, .table th, .table td, .table thead th, .table tbody + tbody, .table-bordered, .table-bordered th, .table-bordered td, .table .thead-light th, table th, table td, [class*="calendar"] th, [class*="calendar"] td, #comments .comment-list, #comments .comment-list .comment, #comments .comment-list .trackback, #comments .comment-list .pingback, #comments .comment-list .comment .children li, #comments .comment-list .trackback .children li, #comments .comment-list .pingback .children li, #single .single-content .tags, .bd-example, .bd-example-border-utils-0 [class^=border], .bd-callout',
                    'property' => 'border-color',
                    'exclude'  => array( '#e0e0e0' )
                ),
                array(
                    'element'  => '.input-group-text, .custom-file-label::after',
                    'property' => 'background-color',
                    'exclude'  => array( '#e0e0e0' )
                ),
                array(
                    'element'  => '.border, .border-top, .border-right, .border-bottom, .border-left',
                    'property' => 'border-color',
                    'suffix'   => ' !important',
                    'exclude'  => array( '#e0e0e0' )
                )
            )
        )
    );
    
    // Body mark background
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'body_mark_background',
            'label'     => esc_html__( 'Body mark background', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#fcf8e3',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'mark, .mark',
                    'property' => 'background-color',
                    'exclude'  => array( '#fcf8e3' )
                )
            )
        )
    );
    
    //=====================
    // Header
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'header_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Header', 'loversy' ) . '</div>'
        )
    );
    
    // Header color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'header_color',
            'label'     => esc_html__( 'Header color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.site-header',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Header background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'header_background_color',
            'label'     => esc_html__( 'Header background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f3f2f1',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.site-header .wrapper',
                    'property' => 'background-color',
                    'exclude'  => array( '#f3f2f1' )
                )
            )
        )
    );
    
    //=====================
    // Footer
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'footer_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Footer', 'loversy' ) . '</div>'
        )
    );
    
    // Footer color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'footer_color',
            'label'     => esc_html__( 'Footer color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.site-footer',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Footer background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'footer_background_color',
            'label'     => esc_html__( 'Footer background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f3f2f1',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.site-footer',
                    'property' => 'background-color',
                    'exclude'  => array( '#f3f2f1' )
                )
            )
        )
    );
    
    //=====================
    // Breadcrumb
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'breadcrumb_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Breadcrumb', 'loversy' ) . '</div>'
        )
    );
    
    // Breadcrumb color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'breadcrumb_color',
            'label'     => esc_html__( 'Breadcrumb color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.breadcrumb-item, .breadcrumb-item > a',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Breadcrumb hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'breadcrumb_hover_color',
            'label'     => esc_html__( 'Breadcrumb hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.breadcrumb-item > a:hover',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    // Breadcrumb active color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'breadcrumb_active_color',
            'label'     => esc_html__( 'Breadcrumb active color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.breadcrumb-item.active',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    // Breadcrumb divider color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'breadcrumb_active_color',
            'label'     => esc_html__( 'Breadcrumb divider color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.breadcrumb-item + .breadcrumb-item::before',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Breadcrumb background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'breadcrumb_background_color',
            'label'     => esc_html__( 'Breadcrumb background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.breadcrumb',
                    'property' => 'background-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    //=====================
    // Menu links
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'menu_links_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Menu', 'loversy' ) . '</div>'
        )
    );
    
    // Menu links color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'menu_links_color',
            'label'     => esc_html__( 'Menu links color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.nav .nav-item > a:not(.disabled):not(.active), .nav:not(.nav-pills) .nav-link:not(.disabled), .nav.nav-pills .nav-link:not(.disabled):not(.active)',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Menu links hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'menu_links_hover_color',
            'label'     => esc_html__( 'Menu links hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.nav .nav-item:hover > a:not(.disabled):not(.active), .nav .nav-item.current-nav-item > .dropdown-icon [class*=\'fa-\'], .nav .nav-item.active > .dropdown-icon [class*=\'fa-\'], .nav:not(.nav-pills) .nav-link:not(.disabled):hover, .nav.nav-pills .nav-link:not(.disabled):not(.active):hover',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    // Menu links active color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'menu_links_active_color',
            'label'     => esc_html__( 'Menu links active color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.nav-tabs .nav-link.active, .nav-tabs .nav-item.show .nav-link, .nav .nav-item.current-nav-item > a:not(.disabled), .nav .nav-item.active > a:not(.disabled), .nav:not(.nav-pills) .nav-link:not(.disabled).active',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    //=====================
    // Menu primary
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'menu_primary_links_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Menu primary', 'loversy' ) . '</div>'
        )
    );
    
    // Menu primary links color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'menu_primary_links_color',
            'label'     => esc_html__( 'Menu primary links color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '#menu-modal nav.menu-primary ul.nav li.nav-item > a, #menu-modal nav.menu-primary ul.nav li.nav-item > .dropdown-custom-icon',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Menu primary links hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'menu_primary_links_hover_color',
            'label'     => esc_html__( 'Menu primary links hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '#menu-modal nav.menu-primary ul.nav li.nav-item:hover > a, #menu-modal nav.menu-primary ul.nav li.nav-item:hover > .dropdown-custom-icon .dropdown-icon',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    // Menu primary links active color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'menu_primary_links_active_color',
            'label'     => esc_html__( 'Menu primary links active color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '#menu-modal nav.menu-primary ul.nav li.nav-item.current-nav-item > a, #menu-modal nav.menu-primary ul.nav li.nav-item.active > a, #menu-modal nav.menu-primary ul.nav li.nav-item.show > a, #menu-modal nav.menu-primary ul.nav li.nav-item.current-nav-item > .dropdown-custom-icon .dropdown-icon, #menu-modal nav.menu-primary ul.nav li.nav-item.active > .dropdown-custom-icon .dropdown-icon, #menu-modal nav.menu-primary ul.nav li.nav-item.show > .dropdown-custom-icon .dropdown-icon, #menu-modal nav.menu-primary ul.nav li.nav-item > .dropdown-custom-icon:hover .dropdown-icon',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    //=====================
    // Dropdown
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'dropdown_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Dropdown', 'loversy' ) . '</div>'
        )
    );
    
    // Dropdown links color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'dropdown_links_color',
            'label'     => esc_html__( 'Dropdown links color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-menu, .dropdown-item, .dropdown-item-text, .dropdown-item a',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Dropdown links hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'dropdown_links_hover_color',
            'label'     => esc_html__( 'Dropdown links hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#ffffff',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-item:hover, .dropdown-item:focus',
                    'property' => 'color',
                    'exclude'  => array( '#ffffff' )
                )
            )
        )
    );
    
    // Dropdown links active color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'dropdown_links_active_color',
            'label'     => esc_html__( 'Dropdown links active color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#ffffff',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-item.active, .dropdown-item:active, .dropdown-submenu.show > .dropdown-custom-icon',
                    'property' => 'color',
                    'exclude'  => array( '#ffffff' )
                )
            )
        )
    );
    
    // Dropdown links background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'dropdown_links_background_color',
            'label'     => esc_html__( 'Dropdown links background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f3f2f1',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-menu',
                    'property' => 'background-color',
                    'exclude'  => array( '#f3f2f1' )
                )
            )
        )
    );
    
    // Dropdown links background hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'dropdown_links_hover_background_color',
            'label'     => esc_html__( 'Dropdown links hover background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-item:hover, .dropdown-item:focus',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Dropdown links background active color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'dropdown_links_active_background_color',
            'label'     => esc_html__( 'Dropdown links active background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.dropdown-item.active, .dropdown-item:active ',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    //=====================
    // Forms
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'forms_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Forms', 'loversy' ) . '</div>'
        )
    );
    
    // Input text color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_text_color',
            'label'     => esc_html__( 'Input text color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#79766f',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.form-control, .form-control:focus, .input-group-text, .custom-select, .custom-file-label, .custom-file-label::after, input, textarea, select',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                ),
                array(
                    'element'  => 'select.form-control:focus::-ms-value, .custom-select:focus::-ms-value',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                ),
                array(
                    'element'       => '.form-control:-moz-focusring, .custom-select:-moz-focusring',
                    'property'      => 'text-shadow',
                    'value_pattern' => '0 0 0 $',
                    'exclude'       => array( '#79766f' )
                )
            )
        )
    );
    
    // Input border focus color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_border_focus_color',
            'label'     => esc_html__( 'Input border focus color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.form-control:focus, .custom-control-input:focus:not(:checked) ~ .custom-control-label::before, .custom-select:focus, .custom-file-input:focus ~ .custom-file-label, input:focus, textarea:focus, select:focus, .contact-form.invalid [class*=\'validates-as-required\']:focus, .wpcf7-form.invalid [class*=\'validates-as-required\']:focus',
                    'property' => 'border-color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Input placeholder color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_placeholder_color',
            'label'     => esc_html__( 'Input placeholder color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#79766f',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.form-control::-webkit-input-placeholder, input[type="email"]::-webkit-input-placeholder, input[type="password"]::-webkit-input-placeholder, input[type="search"]::-webkit-input-placeholder, input[type="tel"]::-webkit-input-placeholder, input[type="text"]::-webkit-input-placeholder, input[type="url"]::-webkit-input-placeholder, input[type="file"]::-webkit-input-placeholder, input[type="date"]::-webkit-input-placeholder, input[type="datetime-local"]::-webkit-input-placeholder, input[type="month"]::-webkit-input-placeholder, input[type="number"]::-webkit-input-placeholder, input[type="range"]::-webkit-input-placeholder, input[type="time"]::-webkit-input-placeholder, input[type="week"]::-webkit-input-placeholder, select::-webkit-input-placeholder, textarea::-webkit-input-placeholder',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                ),
                array(
                    'element'  => '.form-control::-moz-placeholder, input[type="email"]::-moz-placeholder, input[type="password"]::-moz-placeholder, input[type="search"]::-moz-placeholder, input[type="tel"]::-moz-placeholder, input[type="text"]::-moz-placeholder, input[type="url"]::-moz-placeholder, input[type="file"]::-moz-placeholder, input[type="date"]::-moz-placeholder, input[type="datetime-local"]::-moz-placeholder, input[type="month"]::-moz-placeholder, input[type="number"]::-moz-placeholder, input[type="range"]::-moz-placeholder, input[type="time"]::-moz-placeholder, input[type="week"]::-moz-placeholder, select::-moz-placeholder, textarea::-moz-placeholder',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                ),
                array(
                    'element'  => '.form-control::-ms-input-placeholder, input[type="email"]::-ms-input-placeholder, input[type="password"]::-ms-input-placeholder, input[type="search"]::-ms-input-placeholder, input[type="tel"]::-ms-input-placeholder, input[type="text"]::-ms-input-placeholder, input[type="url"]::-ms-input-placeholder, input[type="file"]::-ms-input-placeholder, input[type="date"]::-ms-input-placeholder, input[type="datetime-local"]::-ms-input-placeholder, input[type="month"]::-ms-input-placeholder, input[type="number"]::-ms-input-placeholder, input[type="range"]::-ms-input-placeholder, input[type="time"]::-ms-input-placeholder, input[type="week"]::-ms-input-placeholder, select::-ms-input-placeholder, textarea::-ms-input-placeholder',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                ),
                array(
                    'element'  => '.form-control::placeholder, input[type="email"]::placeholder, input[type="password"]::placeholder, input[type="search"]::placeholder, input[type="tel"]::placeholder, input[type="text"]::placeholder, input[type="url"]::placeholder, input[type="file"]::placeholder, input[type="date"]::placeholder, input[type="datetime-local"]::placeholder, input[type="month"]::placeholder, input[type="number"]::placeholder, input[type="range"]::placeholder, input[type="time"]::placeholder, input[type="week"]::placeholder, select::placeholder, textarea::placeholder',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                )
            )
        )
    );
    
    // Input label color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_label_color',
            'label'     => esc_html__( 'Input label color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'label',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Input background primary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_background_primary_color',
            'label'     => esc_html__( 'Input background primary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'input, textarea, select',
                    'property' => 'background-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    // Input border primary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_border_primary_color',
            'label'     => esc_html__( 'Input border primary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#979797',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'input, textarea, select',
                    'property' => 'border-color',
                    'exclude'  => array( '#979797' )
                )
            )
        )
    );
    
    // Input background secondary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_background_secondary_color',
            'label'     => esc_html__( 'Input background secondary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f9f9f9',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.form-control, .form-control:focus, .was-validated .custom-select:valid, .custom-select.is-valid, .custom-control-label::before, .custom-switch .custom-control-input:checked ~ .custom-control-label::after, .custom-select, .custom-file-label, select[multiple], select.form-control',
                    'property' => 'background-color',
                    'exclude'  => array( '#f9f9f9' )
                ),
                array(
                    'element'  => 'select.form-control:focus::-ms-value, .custom-select:focus::-ms-value',
                    'property' => 'background-color',
                    'exclude'  => array( '#f9f9f9' )
                )
            )
        )
    );
    
    // Input border secondary color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'input_border_secondary_color',
            'label'     => esc_html__( 'Input border secondary color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.form-control, .input-group-text, .custom-select, .custom-file-label',
                    'property' => 'border-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    //=====================
    // Masonry gallery
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'masonry_gallery_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Masonry gallery', 'loversy' ) . '</div>'
        )
    );
    
    // Masonry gallery filter button color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_filter_button_color',
            'label'     => esc_html__( 'Masonry gallery filter button color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'ul.gallery-filter li a.btn.btn-link:not(.active), ul.gallery-filter li [class*=\'-block-search\'] a:not(.active)[class*=\'-block-search__button\'], [class*=\'-block-search\'] ul.gallery-filter li a:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li .widget-area .tagcloud a.btn-link.tag-cloud-link:not(.active), .widget-area .tagcloud ul.gallery-filter li a.btn-link.tag-cloud-link:not(.active), ul.gallery-filter li [class*=\'widget-container\'] .tagcloud a.btn-link.tag-cloud-link:not(.active), [class*=\'widget-container\'] .tagcloud ul.gallery-filter li a.btn-link.tag-cloud-link:not(.active), ul.gallery-filter li #single .single-content .description [class*=\'tag-cloud\'] a.btn-link.tag-cloud-link:not(.active), #single .single-content .description [class*=\'tag-cloud\'] ul.gallery-filter li a.btn-link.tag-cloud-link:not(.active), ul.gallery-filter li #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] a.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] ul.gallery-filter li a.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] a.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] ul.gallery-filter li a.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li #single .single-content .tags p a.btn-link:not(.active), #single .single-content .tags p ul.gallery-filter li a.btn-link:not(.active), ul.gallery-filter li #single .single-content .tags p [class*=\'-block-search\'] a:not(.active)[class*=\'-block-search__button\'], #single .single-content .tags p [class*=\'-block-search\'] ul.gallery-filter li a:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li [class*=\'-block-search\'] #single .single-content .tags p a:not(.active)[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .tags p ul.gallery-filter li a:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li span.btn.btn-link:not(.active), ul.gallery-filter li [class*=\'-block-search\'] span:not(.active)[class*=\'-block-search__button\'], [class*=\'-block-search\'] ul.gallery-filter li span:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li .widget-area .tagcloud span.btn-link.tag-cloud-link:not(.active), .widget-area .tagcloud ul.gallery-filter li span.btn-link.tag-cloud-link:not(.active), ul.gallery-filter li [class*=\'widget-container\'] .tagcloud span.btn-link.tag-cloud-link:not(.active), [class*=\'widget-container\'] .tagcloud ul.gallery-filter li span.btn-link.tag-cloud-link:not(.active), ul.gallery-filter li #single .single-content .description [class*=\'tag-cloud\'] span.btn-link.tag-cloud-link:not(.active), #single .single-content .description [class*=\'tag-cloud\'] ul.gallery-filter li span.btn-link.tag-cloud-link:not(.active), ul.gallery-filter li #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] span.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] ul.gallery-filter li span.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] span.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] ul.gallery-filter li span.tag-cloud-link:not(.active)[class*=\'-block-search__button\'], ul.gallery-filter li span.btn.btn-link:hover, ul.gallery-filter li [class*=\'-block-search\'] span:hover[class*=\'-block-search__button\'], [class*=\'-block-search\'] ul.gallery-filter li span:hover[class*=\'-block-search__button\'], ul.gallery-filter li .widget-area .tagcloud span.btn-link.tag-cloud-link:hover, .widget-area .tagcloud ul.gallery-filter li span.btn-link.tag-cloud-link:hover, ul.gallery-filter li [class*=\'widget-container\'] .tagcloud span.btn-link.tag-cloud-link:hover, [class*=\'widget-container\'] .tagcloud ul.gallery-filter li span.btn-link.tag-cloud-link:hover, ul.gallery-filter li #single .single-content .description [class*=\'tag-cloud\'] span.btn-link.tag-cloud-link:hover, #single .single-content .description [class*=\'tag-cloud\'] ul.gallery-filter li span.btn-link.tag-cloud-link:hover, ul.gallery-filter li #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] span.tag-cloud-link:hover[class*=\'-block-search__button\'], #single .single-content .description [class*=\'tag-cloud\'] [class*=\'-block-search\'] ul.gallery-filter li span.tag-cloud-link:hover[class*=\'-block-search__button\'], ul.gallery-filter li [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] span.tag-cloud-link:hover[class*=\'-block-search__button\'], [class*=\'-block-search\'] #single .single-content .description [class*=\'tag-cloud\'] ul.gallery-filter li span.tag-cloud-link:hover[class*=\'-block-search__button\']',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Masonry gallery filter button hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_filter_button_hover_color',
            'label'     => esc_html__( 'Masonry gallery filter button hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'ul.gallery-filter li a.click.btn-link:not(.active):hover, ul.gallery-filter li [class*=\'-block-search\'] a.click:not(.active):hover[class*=\'-block-search__button\'], [class*=\'-block-search\'] ul.gallery-filter li a.click:not(.active):hover[class*=\'-block-search__button\']',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    // Masonry gallery filter button active color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_filter_button_active_color',
            'label'     => esc_html__( 'Masonry gallery filter button active color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => 'ul.gallery-filter li a.active, ul.gallery-filter li a.active:hover',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => 'ul.gallery-filter li a.active.btn-link:after, ul.gallery-filter li [class*=\'-block-search\'] a.active[class*=\'-block-search__button\']:after, [class*=\'-block-search\'] ul.gallery-filter li a.active[class*=\'-block-search__button\']:after, ul.gallery-filter li a.active:hover.btn-link:after, ul.gallery-filter li [class*=\'-block-search\'] a.active[class*=\'-block-search__button\']:hover:after, [class*=\'-block-search\'] ul.gallery-filter li a.active[class*=\'-block-search__button\']:hover:after',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Masonry gallery item background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_item_background_color',
            'label'     => esc_html__( 'Masonry gallery item background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f9f9f9',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover',
                    'property' => 'background-color',
                    'exclude'  => array( '#f9f9f9' )
                )
            )
        )
    );
    
    // Masonry gallery item title color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_item_title_color',
            'label'     => esc_html__( 'Masonry gallery item title color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover .gallery-item-title',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Masonry gallery item description color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_item_description_color',
            'label'     => esc_html__( 'Masonry gallery item description color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#79766f',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover .gallery-item-description',
                    'property' => 'color',
                    'exclude'  => array( '#79766f' )
                )
            )
        )
    );
    
    // Masonry gallery item button color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_item_btn_color',
            'label'     => esc_html__( 'Masonry gallery item button color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover .gallery-item-btn > *',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                ),
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover .gallery-item-btn > *:after',
                    'property' => 'background-color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    // Masonry gallery item button hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'masonry_gallery_item_btn_hover_color',
            'label'     => esc_html__( 'Masonry gallery item button hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#8d9893',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover .gallery-item-btn > *:hover',
                    'property' => 'color',
                    'exclude'  => array( '#8d9893' )
                ),
                array(
                    'element'  => '.gallery-item-wrapper .gallery-items .gallery-item .gallery-item-content .gallery-hover .gallery-item-btn > *:hover:after',
                    'property' => 'background-color',
                    'exclude'  => array( '#8d9893' )
                )
            )
        )
    );
    
    //=====================
    // Modal
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'modal_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Modal', 'loversy' ) . '</div>'
        )
    );
    
    // Modal background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'modal_background_color',
            'label'     => esc_html__( 'Modal background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f3f2f1',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.modal-backdrop, .modal',
                    'property' => 'background-color',
                    'exclude'  => array( '#f3f2f1' )
                )
            )
        )
    );
    
    // Modal background content color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'modal_background_content_color',
            'label'     => esc_html__( 'Modal background content color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.modal-content',
                    'property' => 'background-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    //=====================
    // Card
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'card_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Card', 'loversy' ) . '</div>'
        )
    );
    
    // Card border color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'card_border_color',
            'label'     => esc_html__( 'Card border color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.card, .card-header, .card-footer',
                    'property' => 'border-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    // Card background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'card_background_color',
            'label'     => esc_html__( 'Card background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.card, .card-header, .card-footer, .card-post',
                    'property' => 'background-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    //=====================
    // Widget
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'widget_colors_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Widget', 'loversy' ) . '</div>'
        )
    );
    
    // Widget background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'widget-background_color',
            'label'     => esc_html__( 'Widget background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#f9f9f9',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.widget-area .widget, [class*=\'widget-container\'] .widget',
                    'property' => 'background',
                    'exclude'  => array( '#f9f9f9' )
                )
            )
        )
    );
    
    // Widget border color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'widget-border_color',
            'label'     => esc_html__( 'Widget border color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.widget-area .widget, [class*=\'widget-container\'] .widget',
                    'property' => 'border-color',
                    'exclude'  => array( '' )
                )
            )
        )
    );
    
    // Widget headline color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'widget-headline_color',
            'label'     => esc_html__( 'Widget headline color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#274035',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.widget-area .widget .widget-title, [class*=\'widget-container\'] .widget .widget-title, .widget-area .widget .widget-title a, [class*=\'widget-container\'] .widget .widget-title a',
                    'property' => 'color',
                    'exclude'  => array( '#274035' )
                )
            )
        )
    );
    
    //=====================
    // Slider
    //=====================
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'slider_color_title',
            'section'  => 'section_colors',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Slider', 'loversy' ) . '</div>'
        )
    );
    
    // Slider button color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'slider_button_color',
            'label'     => esc_html__( 'Slider button color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#ffffff',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.adv-swiper-button-prev, .adv-swiper-button-next, .adv-swiper-container .adv-2-swiper-button-prev, .adv-swiper-container .adv-2-swiper-button-next, .adv-swiper-container .adv-2-swiper-button-prev.adv-swiper-button-disabled:hover, .adv-swiper-container .adv-2-swiper-button-next.adv-swiper-button-disabled:hover',
                    'property' => 'color',
                    'exclude'  => array( '#ffffff' )
                ),
                array(
                    'element'  => '.adv-swiper-pagination-bullet',
                    'property' => 'background-color',
                    'exclude'  => array( '#ffffff' )
                )
            )
        )
    );
    
    // Slider button background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'slider_button_background_color',
            'label'     => esc_html__( 'Slider button background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => 'rgba(0, 0, 0, 0.2)',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.adv-swiper-container .adv-2-swiper-button-prev, .adv-swiper-container .adv-2-swiper-button-next, .adv-swiper-container .adv-2-swiper-button-prev.adv-swiper-button-disabled:hover, .adv-swiper-container .adv-2-swiper-button-next.adv-swiper-button-disabled:hover',
                    'property' => 'background-color',
                    'exclude'  => array( 'rgba(0, 0, 0, 0.2)' )
                )
            )
        )
    );
    
    // Slider button hover color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'slider_button_hover_color',
            'label'     => esc_html__( 'Slider button hover color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => '#ffffff',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.adv-swiper-pagination-bullet:hover, .adv-swiper-pagination-bullet-active, .adv-swiper-pagination-progressbar .adv-swiper-pagination-progressbar-fill, ',
                    'property' => 'background-color',
                    'exclude'  => array( '#ffffff' )
                ),
                array(
                    'element'  => '.adv-swiper-lazy-preloader',
                    'property' => 'border-color',
                    'exclude'  => array( '#ffffff' )
                ),
                array(
                    'element'  => '.adv-swiper-container .adv-2-swiper-button-prev:hover, .adv-swiper-container .adv-2-swiper-button-next:hover',
                    'property' => 'color',
                    'exclude'  => array( '#ffffff' )
                )
            )
        )
    );
    
    // Slider button hover background color
    Kirki::add_field(
        $config_id, array(
            'type'      => 'color',
            'settings'  => 'slider_button_hover_background_color',
            'label'     => esc_html__( 'Slider button hover background color', 'loversy' ),
            'section'   => 'section_colors',
            'transport' => 'refresh',
            'default'   => 'rgba(0, 0, 0, 1)',
            'choices'   => array(
                'alpha' => true
            ),
            'output'    => array(
                array(
                    'element'  => '.adv-swiper-container .adv-2-swiper-button-prev:hover, .adv-swiper-container .adv-2-swiper-button-next:hover',
                    'property' => 'background-color',
                    'exclude'  => array( 'rgba(0, 0, 0, 1)' )
                )
            )
        )
    );
    
    //=============================
    // Typography
    //=============================
    // Add section
    Kirki::add_section(
        'section_typography', array(
            'title'    => esc_html__( 'Typography', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 4
        )
    );
    
    // Headline
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'headline_typography_title',
            'section'  => 'section_typography',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Headline', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'        => 'typography',
            'settings'    => 'headings_typography',
            'label'       => esc_attr__( 'Font', 'loversy' ),
            'description' => esc_attr__( 'This is the font for all H1, H2, H3, H5, H6 titles.', 'loversy' ),
            'section'     => 'section_typography',
            'transport'   => 'refresh',
            'default'     => array(
                'font-family' => 'Playfair Display',
                'variant'     => '700'
            ),
            'output'      => array(
                array(
                    'element'  => '.h1, .h2, .h3, .h4, .h5, .h6, h1, h2, h3, h4, h5, h6, .widget-area .widget .widget-title, [class*=\'widget-container\'] .widget .widget-title, .widget-area .widget.widget_recent_comments ul li.recentcomments, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments, .widget-area .widget.widget_rss .rsswidget, .footer-widget-area .widget.widget_rss .rsswidget, [class*=\'widget-container\'] .widget.widget_rss .rsswidget, #comments .comment-list .comment .comment-wrapper .comment-details .comment-content .comment-content-right .comment-author, #comments .comment-list .trackback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-author, #comments .comment-list .pingback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-author',
                    'property' => 'font-family',
                    'choice'   => 'font-family',
                    'exclude'  => array( 'Playfair Display' )
                ),
                array(
                    'element'  => '.h1, .h2, .h3, .h4, .h5, .h6, h1, h2, h3, h4, h5, h6, .widget-area .widget .widget-title, [class*=\'widget-container\'] .widget .widget-title, .widget-area .widget.widget_recent_comments ul li.recentcomments, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments, .widget-area .widget.widget_rss .rsswidget, .footer-widget-area .widget.widget_rss .rsswidget, [class*=\'widget-container\'] .widget.widget_rss .rsswidget, #comments .comment-list .comment .comment-wrapper .comment-details .comment-content .comment-content-right .comment-author, #comments .comment-list .trackback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-author, #comments .comment-list .pingback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-author',
                    'property' => 'font-weight',
                    'choice'   => 'variant',
                    'exclude'  => array( '700' )
                )
            )
        )
    );
    
    // Base
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'base_typography_title',
            'section'  => 'section_typography',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Base', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'        => 'typography',
            'settings'    => 'base_typography',
            'label'       => esc_attr__( 'Font', 'loversy' ),
            'description' => esc_attr__( 'Base text font.', 'loversy' ),
            'section'     => 'section_typography',
            'transport'   => 'refresh',
            'default'     => array(
                'font-family' => 'Lato',
                'variant'     => 'regular',
            ),
            'output'      => array(
                array(
                    'element'  => 'body, .btn, [class*=\'-block-search\'] [class*=\'-block-search__button\'], [class*=\'-password-form\'] input[type="submit"], .widget-area .tagcloud .tag-cloud-link, [class*=\'widget-container\'] .tagcloud .tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link, #single .single-content .tags p a, strong, b, table th, [class*="calendar"] th, .btn.btn-regular, [class*=\'-block-search\'] .btn-regular[class*=\'-block-search__button\'], [class*=\'-password-form\'] input.btn-regular[type="submit"], .widget-area .tagcloud .tag-cloud-link, [class*=\'widget-container\'] .tagcloud .tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .tag-cloud-link, #single .single-content .tags p a, .btn.btn-bold, [class*=\'-block-search\'] .btn-bold[class*=\'-block-search__button\'], [class*=\'-password-form\'] input.btn-bold[type="submit"], .widget-area .tagcloud .btn-bold.tag-cloud-link, [class*=\'widget-container\'] .tagcloud .btn-bold.tag-cloud-link, #single .single-content .description [class*=\'tag-cloud\'] .btn-bold.tag-cloud-link, #single .single-content .tags p a.btn-bold, .breadcrumb-item + .breadcrumb-item::before, .widget-area .widget.widget_recent_comments ul li.recentcomments > a, [class*=\'widget-container\'] .widget.widget_recent_comments ul li.recentcomments > a, #comments #respond .comment-form .comment-form-cookies-consent label, .bd-placeholder-img text, label, .card .card-meta p, #comments .comment-list .comment .comment-wrapper .comment-details .comment-content .comment-content-right .comment-time p, #comments .comment-list .trackback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-time p, #comments .comment-list .pingback .comment-wrapper .comment-details .comment-content .comment-content-right .comment-time p, #single .single-content .meta p',
                    'property' => 'font-family',
                    'choice'   => 'font-family',
                    'exclude'  => array( 'Lato' )
                ),
                array(
                    'element'  => '.regular, .bold',
                    'property' => 'font-family',
                    'choice'   => 'font-family',
                    'suffix'   => ' !important',
                    'exclude'  => array( 'Lato' )
                ),
                array(
                    'element'  => 'body',
                    'property' => 'font-weight',
                    'choice'   => 'variant',
                    'exclude'  => array( 'regular' )
                )
            )
        )
    );
    
    // Menu primary
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'menu_primary_typography_title',
            'section'  => 'section_typography',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Menu primary', 'loversy' ) . '</div>'
        )
    );
    
    Kirki::add_field(
        $config_id, array(
            'type'      => 'typography',
            'settings'  => 'menu_primary_typography',
            'label'     => esc_attr__( 'Font', 'loversy' ),
            'section'   => 'section_typography',
            'transport' => 'refresh',
            'default'   => array(
                'font-family' => 'Playfair Display',
                'variant'     => '700'
            ),
            'output'    => array(
                array(
                    'element'  => '#menu-modal nav.menu-primary ul.nav li.nav-item a',
                    'property' => 'font-family',
                    'choice'   => 'font-family',
                    'exclude'  => array( 'Playfair Display' )
                ),
                array(
                    'element'  => '#menu-modal nav.menu-primary ul.nav li.nav-item a',
                    'property' => 'font-weight',
                    'choice'   => 'variant',
                    'exclude'  => array( '700' )
                )
            )
        )
    );
    
    //=============================
    // Page
    //=============================
    // Add section
    Kirki::add_section(
        'section_page', array(
            'title'    => __( 'Page', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 5
        )
    );
    
    // Page default title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'page_default_title',
            'section'  => 'section_page',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Default', 'loversy' ) . '</div>'
        )
    );
    
    // Page layout
    Kirki::add_field(
        $config_id, array(
            'type'     => 'radio-image',
            'settings' => 'page_layout',
            'label'    => esc_html__( 'Layout', 'loversy' ),
            'section'  => 'section_page',
            'default'  => 'full',
            'choices'  => array(
                'full' => LOVERSY_URL . '/inc/admin/customizer/assets/img/1c.png'
            )
        )
    );
    
    // Page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'page_title',
            'section'  => 'section_page',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Page', 'loversy' ) . '</div>'
        )
    );
    
    // Page information
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'page_information',
            'label'    => esc_html__( 'Layout', 'loversy' ),
            'section'  => 'section_page',
            'default'  => 'Feature to select a different layout for any page. <br><br><img src="' . LOVERSY_URL . '/inc/admin/customizer/assets/img/page_attributes.jpg' . '" alt="' . esc_html__( 'Page Attributes', 'loversy' ) . '">'
        )
    );
    
    //=============================
    // Blog
    //=============================
    // Add section
    Kirki::add_section(
        'section_blog', array(
            'title'    => __( 'Blog', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 6
        )
    );
    
    // Default title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'default_title',
            'section'  => 'section_blog',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Default', 'loversy' ) . '</div>'
        )
    );
    
    // Blog page title
    Kirki::add_field(
        $config_id, array(
            'type'        => 'text',
            'settings'    => 'blog_page_title',
            'label'       => esc_html__( 'Blog page title', 'loversy' ),
            'description' => esc_html__( 'Set the title of the Blog page when not selected static page.', 'loversy' ),
            'section'     => 'section_blog',
            'default'     => esc_html__( 'Blog', 'loversy' )
        )
    );
    
    // Blog page description
    Kirki::add_field(
        $config_id, array(
            'type'     => 'textarea',
            'settings' => 'blog_page_description',
            'label'    => esc_html__( 'Blog page description', 'loversy' ),
            'section'  => 'section_blog'
        )
    );
    
    // Show post author
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'blog_page_show_post_author',
            'label'    => esc_html__( 'Show post author', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show post comments count
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'blog_page_show_post_comments_count',
            'label'    => esc_html__( 'Show post comments count', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show post category
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'blog_page_show_post_category',
            'label'    => esc_html__( 'Show post category', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show post title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'blog_page_show_post_title',
            'label'    => esc_html__( 'Show post title', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show post excerpt
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'blog_page_show_post_excerpt',
            'label'    => esc_html__( 'Show post excerpt', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show post link
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'blog_page_show_post_link',
            'label'    => esc_html__( 'Show post link', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Blog permalinks
    Kirki::add_field(
        $config_id, array(
            'type'        => 'custom',
            'settings'    => 'blog_permalinks',
            'label'       => esc_html__( 'Blog permalinks', 'loversy' ),
            'description' => esc_html__( 'Set up custom permalinks for the blog category and tags on your site.', 'loversy' ),
            'section'     => 'section_blog',
            'default'     => '<a class="button" target="_blank" href="' . esc_url( wp_nonce_url( $permalinks ) ) . '">' . esc_html__( 'Edit', 'loversy' ) . '</a>'
        )
    );
    
    // Blog shortcode
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'blog_shortcode_title',
            'section'  => 'section_blog',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Shortcode', 'loversy' ) . '</div>'
        )
    );
    
    // Blog shortcode information
    Kirki::add_field(
        $config_id, array(
            'type'        => 'custom',
            'settings'    => 'blog_shortcode_information',
            'section'     => 'section_blog',
            'description' => wp_kses_post(
                'Code: <strong>[display-blog]</strong><br><br>
                 Additional parameters: <br>
                 - <strong>num=""</strong> - number of posts. Default is 3.<br>
                 - <strong>order=""</strong> - order of posts. Default is DESC.<br>
                 - <strong>orderby=""</strong> - orderby of posts. Default is post_date.<br><br>
                 Example: <strong>[display-blog num="3" order="DESC" orderby="post_date"]</strong>', 'loversy'
            )
        )
    );
    
    // Home page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'home_page_title',
            'section'  => 'section_blog',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Home page', 'loversy' ) . '</div>'
        )
    );
    
    // Home page layout
    Kirki::add_field(
        $config_id, array(
            'type'        => 'radio-image',
            'settings'    => 'home_page_layout',
            'label'       => esc_html__( 'Layout', 'loversy' ),
            'description' => esc_html__( 'Set the layout of the Blog page when it is in home page.', 'loversy' ),
            'section'     => 'section_blog',
            'default'     => 'right_sidebar',
            'choices'     => array(
                'full'          => LOVERSY_URL . '/inc/admin/customizer/assets/img/1c.png',
                'left_sidebar'  => LOVERSY_URL . '/inc/admin/customizer/assets/img/2cl.png',
                'right_sidebar' => LOVERSY_URL . '/inc/admin/customizer/assets/img/2cr.png'
            )
        )
    );
    
    // Archive page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'archive_page_title',
            'section'  => 'section_blog',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Archive page', 'loversy' ) . '</div>'
        )
    );
    
    // Archive page layout
    Kirki::add_field(
        $config_id, array(
            'type'     => 'radio-image',
            'settings' => 'archive_page_layout',
            'label'    => esc_html__( 'Layout', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => 'right_sidebar',
            'choices'  => array(
                'full'          => LOVERSY_URL . '/inc/admin/customizer/assets/img/1c.png',
                'left_sidebar'  => LOVERSY_URL . '/inc/admin/customizer/assets/img/2cl.png',
                'right_sidebar' => LOVERSY_URL . '/inc/admin/customizer/assets/img/2cr.png'
            )
        )
    );
    
    // Single post page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'single_post_page_title',
            'section'  => 'section_blog',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Single post page', 'loversy' ) . '</div>'
        )
    );
    
    // Single post page layout
    Kirki::add_field(
        $config_id, array(
            'type'     => 'radio-image',
            'settings' => 'single_post_page_layout',
            'label'    => esc_html__( 'Layout', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => 'right_sidebar',
            'choices'  => array(
                'full'          => LOVERSY_URL . '/inc/admin/customizer/assets/img/1c.png',
                'left_sidebar'  => LOVERSY_URL . '/inc/admin/customizer/assets/img/2cl.png',
                'right_sidebar' => LOVERSY_URL . '/inc/admin/customizer/assets/img/2cr.png'
            )
        )
    );
    
    // Single post page thumbnail variations
    Kirki::add_field(
        $config_id, array(
            'type'        => 'select',
            'settings'    => 'single_post_page_thumbnail_variations',
            'label'       => esc_html__( 'Thumbnail image', 'loversy' ),
            'section'     => 'section_blog',
            'default'     => 'width-object-fit',
            'placeholder' => esc_html__( 'Select an option...', 'loversy' ),
            'priority'    => 10,
            'multiple'    => 1,
            'choices'     => array(
                'default'          => esc_html__( 'Default', 'loversy' ),
                'width-object-fit' => esc_html__( 'Width object fit', 'loversy' )
            )
        )
    );
    
    // Show date
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'single_post_page_show_date',
            'label'    => esc_html__( 'Show date', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '0',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show author
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'single_post_page_show_author',
            'label'    => esc_html__( 'Show author', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show comments count
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'single_post_page_show_comments_count',
            'label'    => esc_html__( 'Show comments count', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show category
    Kirki::add_field(
        $config_id, array(
            'type'     => 'switch',
            'settings' => 'single_post_page_show_category',
            'label'    => esc_html__( 'Show category', 'loversy' ),
            'section'  => 'section_blog',
            'default'  => '1',
            'choices'  => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Comments title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'comments_title',
            'section'  => 'section_blog',
            'default'  => '<div class="options-title-divider">' . esc_html__( 'Comments', 'loversy' ) . '</div>'
        )
    );
    
    // Show comments
    Kirki::add_field(
        $config_id, array(
            'type'        => 'switch',
            'settings'    => 'single_post_page_show_comments',
            'label'       => esc_html__( 'Show comments', 'loversy' ),
            'description' => esc_html__( 'More settings', 'loversy' ) . ' ' . '<a href="' . $options_disc_url . '" target="_blank">' . esc_html__( 'here', 'loversy' ) . '.</a>',
            'section'     => 'section_blog',
            'default'     => '1',
            'choices'     => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    // Show comment form
    Kirki::add_field(
        $config_id, array(
            'type'        => 'switch',
            'settings'    => 'single_post_page_show_comment_form',
            'label'       => esc_html__( 'Show comment form', 'loversy' ),
            'description' => esc_html__( 'More settings', 'loversy' ) . ' ' . '<a href="' . $options_disc_url . '" target="_blank">' . esc_html__( 'here', 'loversy' ) . '.</a>',
            'section'     => 'section_blog',
            'default'     => '1',
            'choices'     => array(
                'on'  => esc_html__( 'On', 'loversy' ),
                'off' => esc_html__( 'Off', 'loversy' )
            )
        )
    );
    
    //=============================
    // 404
    //=============================
    // Add section
    Kirki::add_section(
        'section_404', array(
            'title'    => __( '404', 'loversy' ),
            'panel'    => 'panel_loversy_options',
            'priority' => 7
        )
    );
    
    // 404 page title
    Kirki::add_field(
        $config_id, array(
            'type'     => 'custom',
            'settings' => 'page_404_title',
            'section'  => 'section_404',
            'default'  => '<div class="options-title-divider">' . esc_html__( '404 page', 'loversy' ) . '</div>'
        )
    );
    
    // 404 image
    Kirki::add_field(
        $config_id, array(
            'type'     => 'image',
            'settings' => 'image_404',
            'label'    => esc_html__( '404 image', 'loversy' ),
            'section'  => 'section_404',
            'default'  => '',
            'choices'  => array(
                'save_as' => 'id'
            )
        )
    );
    
    //=============================
    // Portfolio
    //=============================
    if ( class_exists( 'ADVEITS_PORTFOLIO_Plugin' ) ) {
        $portfolio_url = admin_url( 'edit.php?post_type=adveits_portfolio&page=adveits-portfolio-settings' );
        
        // Add section
        Kirki::add_section(
            'section_portfolio', array(
                'title'    => __( 'Portfolio', 'loversy' ),
                'panel'    => 'panel_loversy_options',
                'priority' => 7
            )
        );
        
        // Default title
        Kirki::add_field(
            $config_id, array(
                'type'     => 'custom',
                'settings' => 'portfolio_default_title',
                'section'  => 'section_portfolio',
                'default'  => '<div class="options-title-divider">' . esc_html__( 'Default', 'loversy' ) . '</div>'
            )
        );
        
        // Portfolio page title
        Kirki::add_field(
            $config_id, array(
                'type'        => 'custom',
                'settings'    => 'portfolio_page_title',
                'label'       => esc_html__( 'Portfolio page title', 'loversy' ),
                'description' => esc_html__( 'Set the title of the Portfolio page when it is in archive page.', 'loversy' ),
                'section'     => 'section_portfolio',
                'default'     => '<a class="button" target="_blank" href="' . esc_url( wp_nonce_url( $portfolio_url ) ) . '">' . esc_html__( 'Edit', 'loversy' ) . '</a>'
            )
        );
        
        // Portfolio page description
        Kirki::add_field(
            $config_id, array(
                'type'     => 'textarea',
                'settings' => 'portfolio_page_description',
                'label'    => esc_html__( 'Portfolio page description', 'loversy' ),
                'section'  => 'section_portfolio',
                'default'  => ''
            )
        );
        
        // Portfolio permalinks
        Kirki::add_field(
            $config_id, array(
                'type'        => 'custom',
                'settings'    => 'portfolio_permalinks',
                'label'       => esc_html__( 'Portfolio permalinks', 'loversy' ),
                'description' => esc_html__( 'Set up custom permalinks for the portfolio section on your site.', 'loversy' ),
                'section'     => 'section_portfolio',
                'default'     => '<a class="button" target="_blank" href="' . esc_url( wp_nonce_url( $portfolio_url ) ) . '">' . esc_html__( 'Edit', 'loversy' ) . '</a>'
            )
        );
        
        // Portfolio shortcode
        Kirki::add_field(
            $config_id, array(
                'type'     => 'custom',
                'settings' => 'portfolio_shortcode_title',
                'section'  => 'section_portfolio',
                'default'  => '<div class="options-title-divider">' . esc_html__( 'Shortcode', 'loversy' ) . '</div>'
            )
        );
        
        // Portfolio shortcode information
        Kirki::add_field(
            $config_id, array(
                'type'        => 'custom',
                'settings'    => 'portfolio_shortcode_information',
                'section'     => 'section_portfolio',
                'description' => wp_kses_post(
                    'Code: <strong>[display-portfolio]</strong><br><br>
                 Additional parameters: <br>
                 - <strong>num=""</strong> - number of posts. Default is 9.<br>
                 - <strong>order=""</strong> - order of posts. Default is ASC.<br>
                 - <strong>orderby=""</strong> - orderby of posts. Default is post_date.<br><br>
                 Example: <strong>[display-portfolio num="9" order="ASC" orderby="post_date"]</strong>', 'loversy'
                )
            )
        );
    }
    
    //========================================
    // Disable loader
    //========================================
    function loversy_kirki_styling( $config ) {
        return wp_parse_args(
            array(
                'disable_loader' => true
            ), $config
        );
    }
    
    add_filter( 'kirki_config', 'loversy_kirki_styling' );
    
    //========================================
    // Telemetry module
    //========================================
    add_filter( 'kirki_telemetry', '__return_false' );
}
