<?php
//=================================================
// Elementor
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

//=================================================
// Admin preview/editor style
//=================================================
function loversy_elementor_admin_preview_styles() {
    wp_enqueue_style( 'loversy-elementor-preview-style', LOVERSY_URL . '/inc/admin/elementor/assets/css/elementor-preview-style.css', array(), LOVERSY_VERSION );
}

add_action( 'elementor/preview/enqueue_styles', 'loversy_elementor_admin_preview_styles' );

function loversy_elementor_admin_editor_styles() {
    wp_enqueue_style( 'loversy-elementor-editor-style', LOVERSY_URL . '/inc/admin/elementor/assets/css/elementor-editor-style.css', array(), LOVERSY_VERSION );
}

add_action( 'elementor/editor/after_enqueue_styles', 'loversy_elementor_admin_editor_styles' );

//=================================================
// Admin preview inline script
//=================================================
function loversy_elementor_admin_preview_inline_script() { ?>
    <script>
        jQuery( function( $ ) {
            'use strict';
            
            // Scroll
            $( 'html' ).css( 'scroll-behavior', 'unset' );
            $( 'html' ).addClass( 'elementor-adv' );

            if ( window.elementorFrontend ) {
                elementorFrontend.hooks.addAction( 'frontend/element_ready/widget', function() {
                    var gallery_items_name        = '.gallery-items';
                    var gallery_item_name         = '.gallery-item';
                    var gallery_filter_name       = '.gallery-filter';
                    var gallery_filter_click_name = '.click';
                    var gallery_active_class_name = 'active';

                    $( gallery_items_name ).imagesLoaded( function() {
                        var $grid = $( gallery_items_name ).isotope( {
                            itemSelector: gallery_item_name,
                            masonry: {
                                horizontalOrder: true
                            }
                        } );

                        $( gallery_filter_name ).on( 'click', gallery_filter_click_name, function() {
                            var filterValue = $( this ).attr( 'data-filter' );

                            $( gallery_filter_name ).find( gallery_filter_click_name ).removeClass( gallery_active_class_name );
                            $( this ).addClass( gallery_active_class_name );
                            $( gallery_item_name ).removeClass( gallery_active_class_name );

                            $grid.isotope( {
                                filter: filterValue,
                            } );

                            return false;
                        } );

                        $( gallery_filter_name ).on( 'click', 'li:first-child() .click', function() {
                            $( gallery_item_name ).addClass( gallery_active_class_name );

                            $grid.isotope();
                        } );
                    } );
                } );
            }
        } );
    </script>
<?php }

if ( defined( 'ELEMENTOR_VERSION' ) && isset( $_GET['elementor-preview'] ) ) {
    add_action( 'wp_footer', 'loversy_elementor_admin_preview_inline_script' );
}

//=================================================
// Some cleanup
//=================================================
function loversy_elementor_some_cleanup() {
    // Theme settings
    update_option( 'elementor_disable_typography_schemes', 'yes' );
    update_option( 'elementor_disable_color_schemes', 'no' );
    update_option( 'elementor_container_width', '1700' );
    update_option( 'elementor_space_between_widgets', '0' );
    update_option( 'elementor_stretched_section_container', '.site-main' );
    update_option( 'elementor_page_title_selector', 'h1.entry-title' );
    update_option( 'elementor_viewport_lg', '1025' );
    update_option( 'elementor_viewport_md', '768' );
    update_option( 'elementor_load_fa4_shim', 'yes' );

    $cpt_support = get_option( 'elementor_cpt_support' );

    if ( ! $cpt_support ) {
        $cpt_support = [ 'page', 'adveits_portfolio' ];

        update_option( 'elementor_cpt_support', $cpt_support );
    }
}

add_action( 'after_switch_theme', 'loversy_elementor_some_cleanup' );

//=================================================
// Typography schemes
//
// $theme_typography_scheme array()
// '1' => 'Primary Headline'
// '2' => 'Secondary Headline'
// '3' => 'Body Text'
// '4' => 'Accent Text'
//=================================================
function loversy_elementor_typography_schemes() {
    $theme_typography_scheme = array();
}

//=================================================
// Color schemes
//
// $theme_color_scheme array()
// '1' => 'Primary'
// '2' => 'Secondary'
// '3' => 'Text'
// '4' => 'Accent'
//=================================================
function loversy_elementor_color_schemes() {
    $body_headline_color             = get_theme_mod( 'body_headline_color', '#274035' );
    $body_text_primary_color         = get_theme_mod( 'body_text_primary_color', '#706e67' );
    $body_main_element_primary_color = get_theme_mod( 'body_main_element_primary_color', '#274035' );

    $theme_color_scheme = array(
        '1' => $body_headline_color,
        '2' => $body_text_primary_color,
        '3' => $body_text_primary_color,
        '4' => $body_main_element_primary_color
    );

    if ( class_exists( 'Elementor\Schemes_Manager' ) ) {
        $schemes_manager = new Elementor\Schemes_Manager();

        $scheme_obj = $schemes_manager->get_scheme( 'color' );
        $scheme_obj->save_scheme( $theme_color_scheme );
    }
}

add_action( 'after_switch_theme', 'loversy_elementor_color_schemes' );
add_action( 'elementor/init', 'loversy_elementor_color_schemes' );

// Customize color
function loversy_elementor_customize_color_schemes() {
    $body_headline_color             = get_theme_mod( 'body_headline_color', '#274035' );
    $body_text_primary_color         = get_theme_mod( 'body_text_primary_color', '#706e67' );
    $body_main_element_primary_color = get_theme_mod( 'body_main_element_primary_color', '#274035' );

    $theme_color_scheme = array(
        '1' => $body_headline_color,
        '2' => $body_text_primary_color,
        '3' => $body_text_primary_color,
        '4' => $body_main_element_primary_color
    );

    if ( class_exists( 'Elementor\Schemes_Manager' ) ) {
        $schemes_manager = new Elementor\Schemes_Manager();

        $scheme_obj = $schemes_manager->get_scheme( 'color' );
        $scheme_obj->save_scheme( $theme_color_scheme );
    }
}

add_action( 'customize_preview_init', 'loversy_elementor_customize_color_schemes' );

//=================================================
// Elements
//=================================================
// Base elements
function loversy_get_base_elements() {
    $elements = array();

    $elements['section'] = array(
        'class' => 'Loversy_Section'
    );

    return $elements;
}

// Elements path
function loversy_get_elements_path( $name ) {
    $elements_file = '';

    if ( ! $elements_file || ! is_readable( $elements_file ) ) {
        $elements_file = dirname( __FILE__ ) . '/elements/' . $name . '.php';
    }

    if ( $elements_file && is_readable( $elements_file ) ) {
        return $elements_file;
    }

    return false;
}

// Base elementes overide register
function loversy_elementor_elements_registered() {
    if ( defined( 'ELEMENTOR_PATH' ) && class_exists( 'Elementor\Element_Base' ) ) {
        if ( class_exists( 'Elementor\Plugin' ) ) {
            if ( is_callable( 'Elementor\Plugin', 'instance' ) ) {
                $elementor = Elementor\Plugin::instance();

                if ( isset( $elementor->elements_manager ) ) {
                    if ( method_exists( $elementor->elements_manager, 'register_element_type' ) ) {
                        $elements = loversy_get_base_elements();

                        foreach ( $elements as $k => $element ) {
                            if ( $element_file = loversy_get_elements_path( $k ) ) {
                                require_once $element_file;
                                $class_name = 'Elementor\\' . $element['class'];

                                Elementor\Plugin::instance()->elements_manager->register_element_type( new $class_name );
                            }
                        }
                    }
                }
            }
        }
    }
}

add_action( 'elementor/elements/elements_registered', 'loversy_elementor_elements_registered' );

//=================================================
// Widgets
//=================================================
// Elements
function loversy_get_elements() {
    $elements = array();

    $elements['alert'] = array(
        'class' => 'Loversy_Alert'
    );

    $elements['button'] = array(
        'class' => 'Loversy_Button'
    );

    $elements['heading'] = array(
        'class' => 'Loversy_Heading'
    );

    $elements['progress'] = array(
        'class' => 'Loversy_Progress'
    );
    
    return $elements;
}

// Widgets path
function loversy_get_widgets_path( $name ) {
    $widget_file   = 'overrides/elementor/' . $name . '.php';
    $template_file = locate_template( $widget_file );

    if ( ! $template_file || ! is_readable( $template_file ) ) {
        $template_file = dirname( __FILE__ ) . '/widgets/' . $name . '.php';
    }

    if ( $template_file && is_readable( $template_file ) ) {
        return $template_file;
    }

    return false;
}

// Widgets registered
function loversy_elementor_widgets_registered() {
    if ( defined( 'ELEMENTOR_PATH' ) && class_exists( 'Elementor\Widget_Base' ) ) {
        if ( class_exists( 'Elementor\Plugin' ) ) {
            if ( is_callable( 'Elementor\Plugin', 'instance' ) ) {
                $elementor = Elementor\Plugin::instance();

                if ( isset( $elementor->widgets_manager ) ) {
                    if ( method_exists( $elementor->widgets_manager, 'register_widget_type' ) ) {
                        $elements = loversy_get_elements();

                        foreach ( $elements as $k => $element ) {
                            if ( $template_file = loversy_get_widgets_path( $k ) ) {
                                require_once $template_file;
                                $class_name = 'Elementor\\' . $element['class'];

                                Elementor\Plugin::instance()->widgets_manager->register_widget_type( new $class_name );
                            }
                        }
                    }
                }
            }
        }
    }
}

add_action( 'elementor/widgets/widgets_registered', 'loversy_elementor_widgets_registered' );

//=================================================
// Affiliate url
//=================================================
// First rewrite
function loversy_elementor_affiliate_url() {
    ob_start(
        function( $html ) {
            $html = str_replace(
                array(
                    'https://elementor.com/pro/',
                    'https://elementor.com/?ref=6580?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?ref=6580?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    '?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?ref=6580?utm_source=panel-widgets&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=wp-plugins&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'admin.php?page=go_elementor_pro',
                    'https://elementor.com/pro/?utm_source=wp-custom-fonts&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?utm_source=panel-widgets&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=panel-global&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=panel-library&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=wp-menu&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/popup-builder/?utm_source=popup-templates&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=wp-overview-widget&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=editor-notice-bar&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=icon-library-go-pro&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=panel-custom-css&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/pro/?utm_source=wp-role-manager&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?ref=6580?utm_source=panel-global&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?ref=6580?utm_source=wp-plugins&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?ref=6580?utm_source=panel-library&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy',
                    'https://elementor.com/?ref=6580?utm_source=editor-notice-bar&utm_campaign=gopro&utm_medium=wp-dash&utm_term=loversy'
                ), 'https://elementor.com/?ref=6580', $html
            );

            return $html;
        }
    );
}

add_action( 'admin_init', 'loversy_elementor_affiliate_url' );

// Second rewrite
function loversy_elementor_affiliate_url_script() {
    wp_enqueue_script( 'loversy-elementor-url-rewrites', LOVERSY_URL . '/inc/admin/elementor/assets/js/elementor-preview-rewrites.min.js', array(), LOVERSY_VERSION );
    wp_enqueue_script( 'loversy-elementor-scroll-behaviour', LOVERSY_URL . '/inc/admin/elementor/assets/js/elementor-scroll-behaviour.min.js', array(), LOVERSY_VERSION );
}

if ( class_exists( 'Elementor\Plugin' ) ) {
    add_action( 'elementor/editor/before_enqueue_scripts', 'loversy_elementor_affiliate_url_script' );
    add_action( 'admin_enqueue_scripts', 'loversy_elementor_affiliate_url_script' );
}

//=================================================
// Loaded
//=================================================
add_action(
    'admin_init', function() {
    if ( did_action( 'elementor/loaded' ) ) {
        remove_action(
            'admin_init', [
                \Elementor\Plugin::$instance->admin,
                'maybe_redirect_to_getting_started'
            ]
        );
    }
}, 1
);
