<?php
//=================================================
// Elementor alert widget
//
// Elementor widget that displays a collapsible display of content in an toggle
// style, allowing the user to open multiple items.
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Alert extends Widget_Base {
    public function get_name() {
        return 'alert';
    }

    public function get_title() {
        return __( 'Alert', 'loversy' );
    }
    
    public function get_icon() {
        return 'eicon-alert';
    }
    
    public function get_keywords() {
        return [
            'alert',
            'notice',
            'message'
        ];
    }

    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
        
        $this->start_controls_section(
            'section_content_alert', [
                'label' => __( 'Alert', 'loversy' )
            ]
        );
        
        $this->add_control(
            'alert_type', [
                'label'          => __( 'Type', 'loversy' ),
                'type'           => Controls_Manager::SELECT,
                'default'        => 'info',
                'options'        => [
                    'primary'   => __( 'Primary', 'loversy' ),
                    'secondary' => __( 'Secondary', 'loversy' ),
                    'success'   => __( 'Success', 'loversy' ),
                    'danger'    => __( 'Danger', 'loversy' ),
                    'warning'   => __( 'Warning', 'loversy' ),
                    'info'      => __( 'Info', 'loversy' ),
                    'light'     => __( 'Light', 'loversy' ),
                    'dark'      => __( 'Dark', 'loversy' )
                ],
                'style_transfer' => true
            ]
        );
        
        $this->add_control(
            'alert_title', [
                'label'       => __( 'Title & Description', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => __( 'Enter your title', 'loversy' ),
                'default'     => __( 'This is an Alert', 'loversy' ),
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'alert_description', [
                'label'       => __( 'Description', 'loversy' ),
                'type'        => Controls_Manager::TEXTAREA,
                'placeholder' => __( 'Enter your description', 'loversy' ),
                'default'     => __( 'I am a description. Click the edit button to change this text.', 'loversy' ),
                'separator'   => 'none',
                'show_label'  => false
            ]
        );
        
        $this->add_control(
            'show_dismiss', [
                'label'   => __( 'Dismiss Button', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'show',
                'options' => [
                    'show' => __( 'Show', 'loversy' ),
                    'hide' => __( 'Hide', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'view', [
                'label'   => __( 'View', 'loversy' ),
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'traditional'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_alert', [
                'label' => __( 'Alert', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_control(
            'background', [
                'label'     => __( 'Background Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .alert' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'border_color', [
                'label'     => __( 'Border Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .alert' => 'border-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'border_left-width', [
                'label'     => __( 'Left Border Width', 'loversy' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .alert' => 'border-left-width: {{SIZE}}{{UNIT}};'
                ]
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_title', [
                'label' => __( 'Title', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'title_color', [
                'label'     => __( 'Text Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .alert-title' => 'display:block; color: {{VALUE}};'
                ]
            ]
        );
    
        $this->add_responsive_control(
            'title_bottom_space', [
                'label'     => __( 'Spacing', 'loversy' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => $space_lg
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .alert-title' => 'margin-bottom: {{SIZE}}{{UNIT}} !important;'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'alert_title',
                'selector' => '{{WRAPPER}} .alert-title',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_description', [
                'label' => __( 'Description', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        
        $this->add_control(
            'description_color', [
                'label'     => __( 'Text Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .alert-description' => 'color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'alert_description',
                'selector' => '{{WRAPPER}} .alert-description',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_3
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function htmlspecialvars_decode( $text ) {
        echo strtr( $text, array_flip( get_html_translation_table( HTML_SPECIALCHARS ) ) );
    }

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( empty( $settings['alert_title'] ) ) {
			return;
		}

		if ( ! empty( $settings['alert_type'] ) ) {
			$this->add_render_attribute( 'wrapper', 'class', 'alert alert-' . $settings['alert_type'] );
		}

		$this->add_render_attribute( 'wrapper', 'role', 'alert' );

		$this->add_render_attribute( 'alert_title', 'class', 'alert-title' );

		$this->add_inline_editing_attributes( 'alert_title', 'none' );
		?>

        <div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
            <strong <?php $this->print_render_attribute_string( 'alert_title' ); ?>><?php $this->htmlspecialvars_decode( esc_html( $settings['alert_title'] ) ); ?></strong>
            <br>
			<?php if ( ! empty( $settings['alert_description'] ) ) :
				$this->add_render_attribute( 'alert_description', 'class', 'alert-description' );

				$this->add_inline_editing_attributes( 'alert_description' );
				?>
				<span <?php $this->print_render_attribute_string( 'alert_description' ); ?>><?php $this->htmlspecialvars_decode(esc_html($settings['alert_description'])); ?></span>
			<?php endif; ?>
   
			<?php if ( 'show' === $settings['show_dismiss'] ) : ?>
				<button type="button" class="elementor-alert-dismiss">
					<span aria-hidden="true">&times;</span>
					<span class="elementor-screen-only"><?php echo __( 'Dismiss alert', 'loversy' ); ?></span>
				</button>
			<?php endif; ?>
		</div>
		<?php
	}

	protected function _content_template() {
		?>
		<# if ( settings.alert_title ) {
			view.addRenderAttribute( {
				alert_title: { class: 'alert-title' },
				alert_description: { class: 'alert-description' }
			} );

			view.addInlineEditingAttributes( 'alert_title', 'none' );
			view.addInlineEditingAttributes( 'alert_description' );
			#>
			<div class="alert alert-{{ settings.alert_type }}" role="alert">
                <strong {{{ view.getRenderAttributeString( 'alert_title' ) }}}>{{{ settings.alert_title }}}</strong>
                <br>
				<span {{{ view.getRenderAttributeString( 'alert_description' ) }}}>{{{ settings.alert_description }}}</span>
    
				<# if ( 'show' === settings.show_dismiss ) { #>
					<button type="button" class="elementor-alert-dismiss">
						<span aria-hidden="true">&times;</span>
						<span class="elementor-screen-only"><?php echo __( 'Dismiss alert', 'loversy' ); ?></span>
					</button>
				<# } #>
			</div>
		<# } #>
		<?php
	}
}
