<?php
//=================================================
// Elementor button widget
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Button extends Widget_Base {
    public function get_name() {
        return 'button';
    }
    
    public function get_title() {
        return __( 'Button', 'loversy' );
    }

    public function get_icon() {
        return 'eicon-button';
    }
    
    public function get_categories() {
        return [ 'basic' ];
    }
    
    public static function get_button_sizes() {
        return [
            ''   => __( 'Default', 'loversy' ),
            'sm' => __( 'Small', 'loversy' ),
            'md' => __( 'Medium', 'loversy' ),
            'lg' => __( 'Large', 'loversy' )
        ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_button', [
                'label' => __( 'Button', 'loversy' )
            ]
        );
        
        $this->add_control(
            'style', [
                'label'   => __( 'Style', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''          => __( 'Default', 'loversy' ),
                    '-outline'  => __( 'Outline', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'type', [
                'label'     => __( 'Preset', 'loversy' ),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'primary',
                'options'   => [
                    ''          => __( 'Default', 'loversy' ),
                    'primary'   => __( 'Primary', 'loversy' ),
                    'secondary' => __( 'Secondary', 'loversy' ),
                    'success'   => __( 'Success', 'loversy' ),
                    'danger'    => __( 'Danger', 'loversy' ),
                    'warning'   => __( 'Warning', 'loversy' ),
                    'info'      => __( 'Info', 'loversy' ),
                    'light'     => __( 'Light', 'loversy' ),
                    'dark'      => __( 'Dark', 'loversy' ),
                    'link'      => __( 'Simple Link', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'text', [
                'label'       => __( 'Text', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true
                ],
                'default'     => __( 'Click here', 'loversy' ),
                'placeholder' => __( 'Click here', 'loversy' )
            ]
        );
        
        $this->add_control(
            'link', [
                'label'       => __( 'Link', 'loversy' ),
                'type'        => Controls_Manager::URL,
                'dynamic'     => [
                    'active' => true
                ],
                'placeholder' => __( 'https://your-link.com', 'loversy' ),
                'default'     => [
                    'url' => '#'
                ]
            ]
        );
        
        $this->add_responsive_control(
            'align', [
                'label'        => __( 'Alignment', 'loversy' ),
                'type'         => Controls_Manager::CHOOSE,
                'options'      => [
                    'left'    => [
                        'title' => __( 'Left', 'loversy' ),
                        'icon'  => 'fa fa-align-left'
                    ],
                    'center'  => [
                        'title' => __( 'Center', 'loversy' ),
                        'icon'  => 'fa fa-align-center'
                    ],
                    'right'   => [
                        'title' => __( 'Right', 'loversy' ),
                        'icon'  => 'fa fa-align-right'
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'loversy' ),
                        'icon'  => 'fa fa-align-justify'
                    ],
                ],
                'prefix_class' => 'elementor%s-align-',
                'default'      => ''
            ]
        );
        
        $this->add_control(
            'size', [
                'label'          => __( 'Size', 'loversy' ),
                'type'           => Controls_Manager::SELECT,
                'default'        => '',
                'options'        => self::get_button_sizes(),
                'style_transfer' => true
            ]
        );
        
        $this->add_control(
            'icon', [
                'label'       => __( 'Icon', 'loversy' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => ''
            ]
        );
        
        $this->add_control(
            'icon_align', [
                'label'   => __( 'Icon Position', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'left',
                'options' => [
                    'left'  => __( 'Before', 'loversy' ),
                    'right' => __( 'After', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'icon_indent', [
                'label'      => __( 'Icon Spacing', 'loversy' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                    'em',
                    'rem',
                    '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .btn .elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .btn .elementor-align-icon-left'  => 'margin-right: {{SIZE}}{{UNIT}};'
                ]
            ]
        );
        
        $this->add_control(
            'button_css_id', [
                'label'       => __( 'Button ID', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'title'       => __( 'Add your custom id WITHOUT the Pound key. e.g: my-id', 'loversy' ),
                'label_block' => false,
                'description' => __( 'Please make sure the ID is unique and not used elsewhere on the page this form is displayed. This field allows <code>A-z 0-9</code> & underscore chars without spaces.', 'loversy' ),
                'separator'   => 'before'
            ]
        );
        
        $this->add_control(
            'button_css_class', [
                'label'       => __( 'Button Class', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'label_block' => false,
                'separator'   => 'before'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_button', [
                'label' => __( 'Button', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'typography',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} a.btn, {{WRAPPER}} .btn'
            ]
        );
        
        $this->start_controls_tabs( 'tabs_button_style' );
        
        $this->start_controls_tab(
            'tab_button_normal', [
                'label' => __( 'Normal', 'loversy' )
            ]
        );
        
        $this->add_control(
            'text_color', [
                'label'     => __( 'Text Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} a.btn, {{WRAPPER}} .btn' => 'color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'text_weight', [
                'label'   => __( 'Text weight', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''        => __( 'Default', 'loversy' ),
                    'regular' => __( 'Regular', 'loversy' ),
                    'bold'    => __( 'Bold', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'background_color', [
                'label'     => __( 'Background Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .btn' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->end_controls_tab();
        
        $this->start_controls_tab(
            'tab_button_hover', [
                'label' => __( 'Hover', 'loversy' )
            ]
        );
        
        $this->add_control(
            'hover_color', [
                'label'     => __( 'Text Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.btn:hover, {{WRAPPER}} .btn:hover' => 'color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'background_hover_color', [
                'label'     => __( 'Background Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.btn:hover, {{WRAPPER}} .btn:hover' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'hover_border_color', [
                'label'     => __( 'Border Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'condition' => [
                    'border_border!' => ''
                ],
                'selectors' => [
                    '{{WRAPPER}} a.btn:hover, {{WRAPPER}} .btn:hover' => 'border-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'hover_animation', [
                'label'   => __( 'Hover Animation', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''                  => __( 'None', 'loversy' ),
                    'transform-scale-h' => __( 'Scale', 'loversy' )
                ]
            ]
        );
        
        $this->end_controls_tab();
        
        $this->end_controls_tabs();
        
        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name'        => 'border',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .btn',
                'separator'   => 'before'
            ]
        );
        
        $this->add_control(
            'border_radius', [
                'label'      => __( 'Border Radius', 'loversy' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    'em',
                    'rem',
                    '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} a.btn, {{WRAPPER}} .btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(), [
                'name'     => 'box_shadow',
                'selector' => '{{WRAPPER}} .btn'
            ]
        );
        
        $this->add_responsive_control(
            'text_padding', [
                'label'      => __( 'Padding', 'loversy' ),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => [
                    'px',
                    'em',
                    'rem',
                    '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} a.btn, {{WRAPPER}} .btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                ],
                'separator'  => 'before'
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
        
        if ( ! empty( $settings['link']['url'] ) ) {
            $this->add_render_attribute( 'button', 'href', $settings['link']['url'] );
    
            if ( $settings['link']['is_external'] ) {
                $this->add_render_attribute( 'button', 'target', '_blank' );
            }
            
            if ( $settings['link']['nofollow'] ) {
                $this->add_render_attribute( 'button', 'rel', 'nofollow' );
            }
        }
        
        $this->add_render_attribute( 'button', 'class', 'btn' );
        $this->add_render_attribute( 'button', 'role', 'button' );
        
        if ( ! empty( $settings['size'] ) ) {
            $this->add_render_attribute( 'button', 'class', 'btn-' . $settings['size'] );
        }
    
        $this->add_render_attribute( 'button', 'class', 'btn' . $settings['style'] . '-' . $settings['type'] );
    
        if ( $settings['text_weight'] ) {
            $this->add_render_attribute( 'button', 'class', 'btn-' . $settings['text_weight'] );
        }
        
        if ( $settings['hover_animation'] ) {
            $this->add_render_attribute( 'button', 'class', $settings['hover_animation'] );
        }
        
        if ( ! empty( $settings['button_css_id'] ) ) {
            $this->add_render_attribute( 'button', 'id', $settings['button_css_id'] );
        }
    
        if ( ! empty( $settings['button_css_class'] ) ) {
            $this->add_render_attribute( 'button', 'class', $settings['button_css_class'] );
        }
        ?>
        
        <a <?php $this->print_render_attribute_string( 'button' ); ?>>
            <?php $this->render_text(); ?>
        </a>
        <?php
    }
    
    protected function _content_template() {
        return false;
        ?>
        <#
        view.addRenderAttribute( 'text', 'class', 'button-text' );
        view.addInlineEditingAttributes( 'text', 'none' );

        var button_class = 'btn' + settings.style + '-' + settings.type ;
        #>
        
        <a id="{{ settings.button_css_id }}" class="btn btn-{{ settings.size }} {{ button_class }} {{ settings.hover_animation }} {{ settings.button_css_class }}" href="{{ settings.link.url }}" role="button">
            <span class="button-content-wrapper">
                <# if ( settings.icon ) { #>
                    <span class="button-icon elementor-align-icon-{{ settings.icon_align }}">
                        <i class="{{ settings.icon }}" aria-hidden="true"></i>
                    </span>
                <# } #>

                <span {{{ view.getRenderAttributeString( 'text' ) }}}>{{{ settings.text }}}</span>
            </span>
        </a>
        <?php
    }
    
    protected function render_text() {
        $settings = $this->get_settings_for_display();
        
        $this->add_render_attribute(
            [
                'content_wrapper' => [
                    'class' => 'button-content-wrapper'
                ],
                'icon_align'      => [
                    'class' => [
                        'button-icon',
                        'elementor-align-icon-' . $settings['icon_align']
                    ]
                ],
                'text'            => [
                    'class' => 'button-text'
                ]
            ]
        );
        
        $this->add_inline_editing_attributes( 'text', 'none' );
        ?>
        <span <?php $this->print_render_attribute_string( 'content_wrapper' ); ?>>
			<?php if ( ! empty( $settings['icon'] ) ) : ?>
                <?php if ( $settings['icon_align'] == 'left' ) : ?>
                    <span <?php $this->print_render_attribute_string( 'icon_align' ); ?>>
                        <i class="<?php echo esc_attr( $settings['icon'] ); ?>" aria-hidden="true"></i>
                    </span>

                    <span <?php $this->print_render_attribute_string( 'text' ); ?>><?php echo wp_kses_post( $settings['text'] ); ?></span>
                <?php elseif ( $settings['icon_align'] == 'right' ) : ?>
                    <span <?php $this->print_render_attribute_string( 'text' ); ?>><?php echo wp_kses_post( $settings['text'] ); ?></span>

                    <span <?php $this->print_render_attribute_string( 'icon_align' ); ?>>
                        <i class="<?php echo esc_attr( $settings['icon'] ); ?>" aria-hidden="true"></i>
                    </span>
                <?php endif; ?>
            <?php else : ?>
                <span <?php $this->print_render_attribute_string( 'text' ); ?>><?php echo wp_kses_post( $settings['text'] ); ?></span>
            <?php endif; ?>
		</span>
        <?php
    }
}
