<?php
//=================================================
// Elementor heading widget
//
// Elementor widget that displays an eye-catching headlines.
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Heading extends Widget_Base {
    public function get_name() {
        return 'heading';
    }
 
    public function get_title() {
        return __( 'Heading', 'loversy' );
    }
    
    public function get_icon() {
        return 'eicon-t-letter';
    }
    
    public function get_categories() {
        return [ 'basic' ];
    }
    
    public function get_keywords() {
        return [
            'heading',
            'title',
            'text'
        ];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'section_content_title', [
                'label' => __( 'Title', 'loversy' )
            ]
        );
        
        $this->add_control(
            'title', [
                'label'       => __( 'Title', 'loversy' ),
                'type'        => Controls_Manager::TEXTAREA,
                'dynamic'     => [
                    'active' => true
                ],
                'placeholder' => __( 'Enter your title', 'loversy' ),
                'default'     => __( 'Add Your Heading Text Here', 'loversy' )
            ]
        );
        
        $this->add_control(
            'link', [
                'label'     => __( 'Link', 'loversy' ),
                'type'      => Controls_Manager::URL,
                'dynamic'   => [
                    'active' => true
                ],
                'default'   => [
                    'url' => ''
                ],
                'separator' => 'before'
            ]
        );
    
        $this->add_control(
            'link_css_id', [
                'label'       => esc_html__( 'Link ID', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'label_block' => false
            ]
        );
        
        $this->add_control(
            'link_css_class', [
                'label'       => esc_html__( 'Link Class', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'label_block' => false
            ]
        );
        
        $this->add_control(
            'header_size', [
                'label'   => __( 'HTML Tag', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'h1'   => 'H1',
                    'h2'   => 'H2',
                    'h3'   => 'H3',
                    'h4'   => 'H4',
                    'h5'   => 'H5',
                    'h6'   => 'H6',
                    'div'  => 'div',
                    'span' => 'span',
                    'p'    => 'p'
                ],
                'default' => 'h2'
            ]
        );
        
        $this->add_responsive_control(
            'align', [
                'label'     => __( 'Alignment', 'loversy' ),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'    => [
                        'title' => __( 'Left', 'loversy' ),
                        'icon'  => 'eicon-text-align-left'
                    ],
                    'center'  => [
                        'title' => __( 'Center', 'loversy' ),
                        'icon'  => 'eicon-text-align-center'
                    ],
                    'right'   => [
                        'title' => __( 'Right', 'loversy' ),
                        'icon'  => 'eicon-text-align-right'
                    ],
                    'justify' => [
                        'title' => __( 'Justified', 'loversy' ),
                        'icon'  => 'eicon-text-align-justify'
                    ],
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}}'
                ]
            ]
        );
        
        $this->add_control(
            'title_css_class', [
                'label'       => __( 'Title Class', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => '',
                'label_block' => false,
                'separator'   => 'before'
            ]
        );
        
        $this->add_control(
            'view', [
                'label'   => __( 'View', 'loversy' ),
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'traditional'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_title', [
                'label' => __( 'Title', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_control(
            'title_color', [
                'label'     => __( 'Text Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'scheme'    => [
                    'type'  => Scheme_Color::get_type(),
                    'value' => Scheme_Color::COLOR_1
                ],
                'selectors' => [
                    '{{WRAPPER}} .title .heading-title' => 'color: {{VALUE}}'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'typography',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .title .heading-title'
            ]
        );
        
        $this->add_group_control(
            Group_Control_Text_Shadow::get_type(), [
                'name'     => 'text_shadow',
                'selector' => '{{WRAPPER}} .title .heading-title'
            ]
        );
        
        $this->add_control(
            'blend_mode', [
                'label'     => __( 'Blend Mode', 'loversy' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    ''            => __( 'Normal', 'loversy' ),
                    'multiply'    => 'Multiply',
                    'screen'      => 'Screen',
                    'overlay'     => 'Overlay',
                    'darken'      => 'Darken',
                    'lighten'     => 'Lighten',
                    'color-dodge' => 'Color Dodge',
                    'saturation'  => 'Saturation',
                    'color'       => 'Color',
                    'difference'  => 'Difference',
                    'exclusion'   => 'Exclusion',
                    'hue'         => 'Hue',
                    'luminosity'  => 'Luminosity'
                ],
                'selectors' => [
                    '{{WRAPPER}} .title .heading-title' => 'mix-blend-mode: {{VALUE}}'
                ],
                'separator' => 'none'
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function htmlspecialvars_decode( $text ) {
        echo strtr( $text, array_flip( get_html_translation_table( HTML_SPECIALCHARS ) ) );
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
        
        if ( '' === $settings['title'] ) {
            return;
        }
        
        $this->add_render_attribute( 'title', 'class', 'heading-title' );
        
        if ( ! empty( $settings['title_css_class'] ) ) {
            $this->add_render_attribute( 'title', 'class', $settings['title_css_class'] );
        }
        
        $this->add_inline_editing_attributes( 'title' );
        
        $title       = $settings['title'];
        $header_size = $settings['header_size'];
        
        if ( ! empty( $settings['link']['url'] ) ) {
            $this->add_render_attribute( 'url', 'href', $settings['link']['url'] );
            
            if ( $settings['link']['is_external'] ) {
                $this->add_render_attribute( 'url', 'target', '_blank' );
            }
            
            if ( ! empty( $settings['link']['nofollow'] ) ) {
                $this->add_render_attribute( 'url', 'rel', 'nofollow' );
            }
            
            if ( ! empty( $settings['link_css_class'] ) ) {
                $this->add_render_attribute( 'url', 'class', $settings['link_css_class'] );
            }
    
            if ( ! empty( $settings['link_css_id'] ) ) {
                $this->add_render_attribute( 'url', 'id', $settings['link_css_id'] );
            }
            
            $title = sprintf( '<a %1$s>%2$s</a>', $this->get_render_attribute_string( 'url' ), $title );
        }
        
        $title_html = sprintf( '<div class="title"><%1$s %2$s>%3$s</%1$s></div>', $settings['header_size'], $this->get_render_attribute_string( 'title' ), $title );
        
        $this->htmlspecialvars_decode( esc_html( $title_html ) );
    }
    
    protected function _content_template() {
        ?>
        <#
        var title = settings.title;
        var header_size = settings.header_size;

        if ( '' !== settings.link.url ) {
            if ( '' !== settings.link_css_class || '' !== settings.link_css_id ) {
                title = '<a class="' + settings.link_css_class + '" id="' + settings.link_css_id + '" href="' + settings.link.url + '">' + title + '</a>';
            } else {
                title = '<a href="' + settings.link.url + '">' + title + '</a>';
            }
        }

        view.addRenderAttribute( 'title', 'class', [ 'heading-title', settings.title_css_class ] );

        view.addInlineEditingAttributes( 'title' );

        var title_html = '<' + settings.header_size  + ' ' + view.getRenderAttributeString( 'title' ) + '>' + title + '</' + settings.header_size + '>';

        #><div class="title"><#
            print( title_html );
        #></div><#
        #>
        <?php
    }
}
