<?php
//=================================================
// Elementor progress widget
//
// Elementor widget that displays an escalating progress bar.
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

class Loversy_Progress extends Widget_Base {
    public function get_name() {
        return 'progress';
    }
    
    public function get_title() {
        return __( 'Progress Bar', 'loversy' );
    }
    
    public function get_icon() {
        return 'eicon-skill-bar';
    }
    
    public function get_keywords() {
        return [
            'progress',
            'bar'
        ];
    }

    protected function _register_controls() {
        $space_xl = 140;
        $space_lg = 60;
        $space_md = 50;
        $space_sm = 30;
        $space_xs = 20;
        
        $this->start_controls_section(
            'section_content_progress_bar', [
                'label' => __( 'Progress Bar', 'loversy' )
            ]
        );
        
        $this->add_control(
            'title', [
                'label'       => __( 'Title', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true
                ],
                'placeholder' => __( 'Enter your title', 'loversy' ),
                'default'     => __( 'My Skill', 'loversy' ),
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'progress_type', [
                'label'   => __( 'Type', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => '',
                'options' => [
                    ''          => __( 'Default', 'loversy' ),
                    'primary'   => __( 'Primary', 'loversy' ),
                    'secondary' => __( 'Secondary', 'loversy' ),
                    'success'   => __( 'Success', 'loversy' ),
                    'danger'    => __( 'Danger', 'loversy' ),
                    'warning'   => __( 'Warning', 'loversy' ),
                    'info'      => __( 'Info', 'loversy' ),
                    'light'     => __( 'Light', 'loversy' ),
                    'dark'      => __( 'Dark', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'percent', [
                'label'       => __( 'Percentage', 'loversy' ),
                'type'        => Controls_Manager::SLIDER,
                'default'     => [
                    'size' => 50,
                    'unit' => '%'
                ],
                'dynamic'     => [
                    'active' => true
                ],
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'display_percentage', [
                'label'   => __( 'Display Percentage', 'loversy' ),
                'type'    => Controls_Manager::SELECT,
                'default' => 'show',
                'options' => [
                    'show' => __( 'Show', 'loversy' ),
                    'hide' => __( 'Hide', 'loversy' )
                ]
            ]
        );
        
        $this->add_control(
            'inner_text', [
                'label'       => __( 'Inner Text', 'loversy' ),
                'type'        => Controls_Manager::TEXT,
                'dynamic'     => [
                    'active' => true
                ],
                'placeholder' => __( 'e.g. Web Designer', 'loversy' ),
                'default'     => __( 'Web Designer', 'loversy' ),
                'label_block' => true
            ]
        );
        
        $this->add_control(
            'view', [
                'label'   => __( 'View', 'loversy' ),
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'traditional'
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_progress_bar', [
                'label' => __( 'Progress Bar', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_control(
            'bar_color', [
                'label'     => __( 'Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'scheme'    => [
                    'type'  => Scheme_Color::get_type(),
                    'value' => Scheme_Color::COLOR_1
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-progress-wrapper .elementor-progress-bar' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'bar_bg_color', [
                'label'     => __( 'Background Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-progress-wrapper' => 'background-color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_control(
            'bar_height', [
                'label'     => __( 'Height', 'loversy' ),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .elementor-progress-bar' => 'height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};'
                ]
            ]
        );
        
        $this->add_control(
            'bar_border_radius', [
                'label'      => __( 'Border Radius', 'loversy' ),
                'type'       => Controls_Manager::SLIDER,
                'size_units' => [
                    'px',
                    '%'
                ],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-progress-wrapper' => 'border-radius: {{SIZE}}{{UNIT}}; overflow: hidden;'
                ]
            ]
        );
        
        $this->add_control(
            'heading_inner_text', [
                'label'     => __( 'Inner Text', 'loversy' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );
        
        $this->add_control(
            'bar_inline_color', [
                'label'     => __( 'Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-progress-bar' => 'color: {{VALUE}};'
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'bar_inner_typography',
                'selector' => '{{WRAPPER}} .elementor-progress-bar',
                'exclude'  => [
                    'line_height'
                ]
            ]
        );
        
        $this->end_controls_section();
        
        $this->start_controls_section(
            'section_style_title', [
                'label' => __( 'Title Style', 'loversy' ),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
        
        $this->add_control(
            'title_color', [
                'label'     => __( 'Text Color', 'loversy' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};'
                ],
                'scheme'    => [
                    'type'  => Scheme_Color::get_type(),
                    'value' => Scheme_Color::COLOR_1
                ]
            ]
        );
        
        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'typography',
                'selector' => '{{WRAPPER}} .title',
                'scheme'   => Scheme_Typography::TYPOGRAPHY_3
            ]
        );
    
        $this->add_responsive_control(
            'title_bottom_space', [
                'label'     => __( 'Spacing', 'loversy' ),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => $space_lg
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .title' => 'display: block; margin-bottom: {{SIZE}}{{UNIT}} !important;'
                ]
            ]
        );
        
        $this->end_controls_section();
    }
    
    protected function htmlspecialvars_decode( $text ) {
        echo strtr( $text, array_flip( get_html_translation_table( HTML_SPECIALCHARS ) ) );
    }
    
    protected function render() {
        $settings = $this->get_settings_for_display();
        
        $progress_percentage = is_numeric( $settings['percent']['size'] ) ? $settings['percent']['size'] : '0';
        
        if ( 100 < $progress_percentage ) {
            $progress_percentage = 100;
        }
        
        $this->add_render_attribute(
            'wrapper', [
                'class'          => 'elementor-progress-wrapper',
                'role'           => 'progressbar',
                'aria-valuemin'  => '0',
                'aria-valuemax'  => '100',
                'aria-valuenow'  => $progress_percentage,
                'aria-valuetext' => $settings['inner_text'],
            ]
        );
        
        if ( ! empty( $settings['progress_type'] ) ) {
            $this->add_render_attribute( 'wrapper', 'class', 'progress-' . $settings['progress_type'] );
        }
        
        $this->add_render_attribute(
            'progress-bar', [
                'class'    => 'elementor-progress-bar bg-' . $settings['progress_type'],
                'data-max' => $progress_percentage,
            ]
        );
        
        $this->add_render_attribute(
            'inner_text', [
                'class' => 'elementor-progress-text',
            ]
        );
        
        $this->add_inline_editing_attributes( 'inner_text' );
        
        if ( ! empty( $settings['title'] ) ) { ?>
            <span class="title"><?php $this->htmlspecialvars_decode( esc_html( $settings['title'] ) ); ?></span>
        <?php } ?>

		<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
			<div <?php $this->print_render_attribute_string( 'progress-bar' ); ?>>
				<span <?php $this->print_render_attribute_string( 'inner_text' ); ?>><?php $this->htmlspecialvars_decode(esc_html($settings['inner_text'])); ?></span>
				<?php if ( 'hide' !== $settings['display_percentage'] ) { ?>
					<span class="elementor-progress-percentage"><?php $this->htmlspecialvars_decode(esc_html($progress_percentage)); ?>%</span>
				<?php } ?>
			</div>
		</div>
		<?php
	}
	
	protected function _content_template() {
		?>
		<#
		let progress_percentage = 0;
  
		if ( ! isNaN( settings.percent.size ) ) {
			progress_percentage = 100 < settings.percent.size ? 100 : settings.percent.size;
		}

		view.addRenderAttribute( 'progressWrapper', {
			'class': [ 'elementor-progress-wrapper', 'progress-' + settings.progress_type ],
			'role': 'progressbar',
			'aria-valuemin': '0',
			'aria-valuemax': '100',
			'aria-valuenow': progress_percentage,
			'aria-valuetext': settings.inner_text
		} );

		view.addRenderAttribute( 'inner_text', {
			'class': 'elementor-progress-text'
		} );

		view.addInlineEditingAttributes( 'inner_text' );
		#>
		<# if ( settings.title ) { #>
			<span class="title">{{{ settings.title }}}</span><#
		} #>
  
		<div {{{ view.getRenderAttributeString( 'progressWrapper' ) }}}>
			<div class="elementor-progress-bar bg-{{ settings.progress_type }}" data-max="{{ progress_percentage }}">
				<span {{{ view.getRenderAttributeString( 'inner_text' ) }}}>{{{ settings.inner_text }}}</span>
				<# if ( 'hide' !== settings.display_percentage ) { #>
					<span class="elementor-progress-percentage">{{{ progress_percentage }}}%</span>
				<# } #>
			</div>
		</div>
		<?php
	}
}
