<?php
//=================================================
// Welcome class
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.1.0
//=================================================

//=================================================
// Config
//=================================================
if ( ! class_exists( 'loversy_theme_config' ) ) {
    class loversy_theme_config {
        public static $vars;
        
        public function __construct() {
            add_action(
                'admin_post_activation_status', array(
                    $this,
                    'activation_status'
                )
            );
            
            if ( ! is_child_theme() ) {
                add_action(
                    'after_switch_theme', array(
                        $this,
                        'deactivate_status_after_switch'
                    )
                );
            }
        }
        
        public function init_vars() {
            $this::$vars['status'] = get_option( 'status' );
            $this::$vars['demo']   = get_option( 'demo' );
            $this::$vars['theme']  = 26548190;
            $this::$vars['email']  = get_option( 'admin_email' );
            add_option( 'adveits_theme_id', 26548190 );
            update_option( 'adveits_theme_id', 26548190 );
            
            return $this::$vars;
        }
        
        public function demo_status() {
            if ( $this::init_vars()['status'] == 'purchase' && $this::init_vars()['demo'] == 'demo' ) {
                return false;
            } else {
                return true;
            }
        }
        
        public function get_purchase_data( $code, $theme, $domain ) {
            $purchase_get = wp_remote_get( 'https://store.adveits.com/API/getPurchaseData.php?envato-product=' . $theme . '&envato-code=' . $code . '&envato-domain=' . $domain . '&envato-email=' . $this::$vars['email'] );
            
            // Check for error
            if ( ! is_wp_error( $purchase_get ) ) {
                $response = wp_remote_retrieve_body( $purchase_get );
                
                // Check for error
                if ( ! is_wp_error( $response ) ) {
                    $response = json_decode( $response );
                    
                    return $response;
                }
            }
            
            return false;
        }
        
        public function get_domain() {
            $domain = get_option( 'siteurl' );
            
            if ( strpos( $domain, 'https' ) === false ) {
                $domain = str_replace( 'http://', '', $domain );
            } else {
                $domain = str_replace( 'https://', '', $domain );
            }
            
            if ( strpos( $domain, 'www.' ) !== false ) {
                $domain = str_replace( 'www.', '', $domain );
            }
            
            return $domain;
        }
        
        public function activation_status() {
            if ( isset( $_POST['loversy_purchase_code'] ) ) {
                if ( get_option( "envato_purchase_code" ) != '' && $_POST['loversy_purchase_code'] == get_option( "envato_purchase_code" ) ) {
                    update_option( 'status', 'purchased' );
                    update_option( 'demo', 'live' );
                    set_transient( 'loversy_registration_message', 1, 3600 );
                } else {
                    $info = $this->get_purchase_data( $_POST['loversy_purchase_code'], $this::$vars['theme'], $this->get_domain() );
                    if ( ! isset( $info->error ) && isset( $info->envato_products_id ) ) {
                        update_option( 'status', 'purchased' );
                        update_option( 'demo', 'live' );
                        add_option( 'envato_purchase_code', $_POST['loversy_purchase_code'] );
                        update_option( 'envato_purchase_code', $_POST['loversy_purchase_code'] );
                        set_transient( 'loversy_registration_message', 1, 3600 );
                    } else {
                        set_transient( 'loversy_registration_message', 0, 3600 );
                        set_transient( 'loversy_api_response', $info->error );
                    }
                }
            }
            
            wp_redirect( admin_url( 'themes.php?page=welcome_to_loversy_theme' ) );
        }
        
        public function deactivate_status_after_switch() {
            update_option( 'status', 'purchase' );
            update_option( 'demo', 'demo' );
        }
    }
}

//=================================================
// Admin menu
//=================================================
if ( ! class_exists( 'loversy_admin_menu' ) ) {
    class loversy_admin_menu {
        public static $settings;
        
        public function __construct( $core ) {
            $this->core = $core;
            $settings   = array();
            
            $this::$settings = wp_parse_args(
                $settings, array(
                    'page-title' => esc_html__( 'Loversy', 'loversy' ),
                    'menu-title' => esc_html__( 'Loversy', 'loversy' ),
                    'menu-slug'  => 'welcome_to_loversy_theme',
                    'capability' => 'edit_theme_options',
                    'function'   => array(
                        $this,
                        'menu_content'
                    ),
                )
            );
        }
        
        public function run() {
            add_action(
                'admin_menu', array(
                    $this,
                    'menu'
                )
            );
        }
        
        public function get_settings( $setting ) {
            return $this::$settings[$setting];
        }
        
        public function menu() {
            $page = add_theme_page( $this::$settings['page-title'], $this::$settings['menu-title'], $this::$settings['capability'], $this::$settings['menu-slug'], $this::$settings['function'], 2 );
            add_action(
                'load-' . $page, array(
                    $this,
                    'menu_scripts'
                )
            );
        }
        
        public function menu_content() {
            require_once get_template_directory() . '/inc/admin/welcome/template/welcome-page.php';
        }
        
        public function menu_scripts() {
            add_action(
                'admin_enqueue_scripts', array(
                $this,
                'register_scripts'
            ), 10, 1
            );
        }
        
        public function register_scripts( $hook ) {
            // Welcome style
            wp_enqueue_style( 'loversy-welcome-style', LOVERSY_URL . '/inc/admin/welcome/assets/css/style.css' );
            
            // Welcome script
            wp_enqueue_script( 'loversy-welcome-script', LOVERSY_URL . '/inc/admin/welcome/assets/js/main.js', array( 'jquery' ), time() );
            
            // Demo import styles and scripts
            if ( class_exists( 'OCDI_Plugin' ) ) {
                $ocdi  = OCDI\OneClickDemoImport::get_instance();
                $theme = wp_get_theme();
                
                wp_enqueue_script( 'jquery-ui-dialog' );
                wp_enqueue_style( 'wp-jquery-ui-dialog' );
                
                wp_enqueue_script(
                    'loversy-install-demo-script', PT_OCDI_URL . 'assets/js/main.js', array(
                    'jquery',
                    'jquery-ui-dialog'
                ), PT_OCDI_VERSION
                );
                
                wp_localize_script(
                    'loversy-install-demo-script', 'ocdi', array(
                        'ajax_url'         => admin_url( 'admin-ajax.php' ),
                        'ajax_nonce'       => wp_create_nonce( 'ocdi-ajax-verification' ),
                        'import_files'     => $ocdi->import_files,
                        'wp_customize_on'  => apply_filters( 'pt-ocdi/enable_wp_customize_save_hooks', false ),
                        'import_popup'     => apply_filters( 'pt-ocdi/enable_grid_layout_import_popup_confirmation', true ),
                        'theme_screenshot' => $theme->get_screenshot(),
                        'texts'            => array(
                            'missing_preview_image' => esc_html__( 'No preview image defined for this import.', 'loversy' ),
                            'dialog_title'          => esc_html__( 'Are you sure?', 'loversy' ),
                            'dialog_no'             => esc_html__( 'Cancel', 'loversy' ),
                            'dialog_yes'            => esc_html__( 'Yes, import!', 'loversy' ),
                            'selected_import_title' => esc_html__( 'Selected demo import:', 'loversy' ),
                        ),
                        'dialog_options'   => apply_filters( 'pt-ocdi/confirmation_dialog_options', array() )
                    )
                );
                
                wp_enqueue_style( 'loversy-install-demo-style', PT_OCDI_URL . 'assets/css/main.css', array(), PT_OCDI_VERSION );
            }
        }
    }
}

//=================================================
// Redirect
//=================================================
if ( ! class_exists( 'loversy_redirect' ) ) {
    class loversy_redirect {
        function __construct( $core ) {
            $this->core = $core;
        }
        
        public function run() {
            add_action(
                'after_switch_theme', array(
                    $this,
                    'activate_theme'
                )
            );
            add_action(
                'admin_enqueue_scripts', array(
                    $this,
                    'update_redirect'
                )
            );
        }
        
        public function get_menu_slug() {
            $menu = new loversy_admin_menu( $this->core );
            
            return $menu->get_settings( 'menu-slug' );
        }
        
        public function activate_theme() {
            global $pagenow;
            
            if ( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) {
                wp_redirect( esc_url( admin_url( 'themes.php?page=' . $this->get_menu_slug() . '' ) ), 302 );
                
                die();
            }
        }
        
        public function update_redirect() {
            wp_localize_script(
                'be-update-redirect', 'be_redirect', array(
                    'url' => esc_url( admin_url( 'themes.php?page=' . $this->get_menu_slug() . '' ) ),
                )
            );
        }
    }
}

//=================================================
// Install plugins
//=================================================
if ( ! class_exists( 'loversy_install_plugins' ) ) {
    class loversy_install_plugins {
        function loversy_plugin_link( $item ) {
            if ( current_user_can( 'edit_theme_options' ) ) {
                if ( isset( $_GET['loversy-deactivate'] ) && $_GET['loversy-deactivate'] == 'deactivate-plugin' ) {
                    check_admin_referer( 'loversy-deactivate', 'loversy-deactivate-nonce' );
                    $plugins = TGM_Plugin_Activation::$instance->plugins;
                    
                    foreach ( $plugins as $plugin ) {
                        if ( $plugin['slug'] == $_GET['plugin'] ) {
                            deactivate_plugins( $plugin['file_path'] );
                        }
                    }
                }
                
                if ( isset ( $_GET['loversy-activate'] ) && $_GET['loversy-activate'] == 'activate-plugin' ) {
                    check_admin_referer( 'loversy-activate', 'loversy-activate-nonce' );
                    $plugins = TGM_Plugin_Activation::$instance->plugins;
                    
                    foreach ( $plugins as $plugin ) {
                        if ( $plugin['slug'] == $_GET['plugin'] ) {
                            activate_plugin( $plugin['file_path'] );
                        }
                    }
                }
            }
            
            $installed_plugins        = get_plugins();
            $item['sanitized_plugin'] = $item['name'];
            
            if ( ! isset( $installed_plugins[$item['file_path']] ) ) {
                $actions = array(
                    'install' => sprintf(
                        '<a href="%1$s" class="button button-primary" title="%3$s %2$s">%4$s</a>', esc_url(
                        wp_nonce_url(
                            add_query_arg(
                                array(
                                    'page'          => urlencode( TGM_Plugin_Activation::$instance->menu ),
                                    'plugin'        => urlencode( $item['slug'] ),
                                    'plugin_name'   => urlencode( $item['sanitized_plugin'] ),
                                    'plugin_source' => urlencode( $item['source'] ),
                                    'tgmpa-install' => 'install-plugin',
                                    'return_url'    => 'welcome_to_loversy_theme#install-plugins'
                                ), admin_url( TGM_Plugin_Activation::$instance->parent_slug )
                            ), 'tgmpa-install', 'tgmpa-nonce'
                        )
                    ), $item['sanitized_plugin'], esc_attr__( 'Install', 'loversy' ), esc_html__( 'Install', 'loversy' )
                    ),
                );
            } elseif ( is_plugin_inactive( $item['file_path'] ) ) {
                if ( version_compare( $item['version'], $installed_plugins[$item['file_path']]['Version'], '>' ) ) {
                    $actions = array(
                        'update' => sprintf(
                            '<a href="%1$s" class="button button-primary" title="%3$s %2$s">%4$s</a>', wp_nonce_url(
                            add_query_arg(
                                array(
                                    'page'          => urlencode( TGM_Plugin_Activation::$instance->menu ),
                                    'plugin'        => urlencode( $item['slug'] ),
                                    'plugin_name'   => urlencode( $item['sanitized_plugin'] ),
                                    'plugin_source' => urlencode( $item['source'] ),
                                    'version'       => urlencode( $item['version'] ),
                                    'tgmpa-update'  => 'update-plugin',
                                    'return_url'    => 'welcome_to_loversy_theme#install-plugins',
                                ), admin_url( TGM_Plugin_Activation::$instance->parent_slug )
                            ), 'tgmpa-update', 'tgmpa-nonce'
                        ), $item['sanitized_plugin'], esc_attr__( 'Update', 'loversy' ), esc_html__( 'Update', 'loversy' )
                        ),
                    );
                } else {
                    $actions = array(
                        'activate' => sprintf(
                            '<a href="%1$s" class="button button-primary" title="%3$s %2$s">%4$s</a>', esc_url(
                            add_query_arg(
                                array(
                                    'plugin'                 => urlencode( $item['slug'] ),
                                    'plugin_name'            => urlencode( $item['sanitized_plugin'] ),
                                    'plugin_source'          => urlencode( $item['source'] ),
                                    'loversy-activate-nonce' => wp_create_nonce( 'loversy-activate' ),
                                    'loversy-activate'       => 'activate-plugin',
                                    'activated'              => 'true'
                                ), admin_url( 'themes.php?page=welcome_to_loversy_theme#install-plugins' )
                            )
                        ), $item['sanitized_plugin'], esc_attr__( 'Activate', 'loversy' ), esc_html__( 'Activate', 'loversy' )
                        ),
                    );
                }
            } elseif ( version_compare( $item['version'], $installed_plugins[$item['file_path']]['Version'], '>' ) ) {
                $actions = array(
                    'update' => sprintf(
                        '<a href="%1$s" class="button button-primary" title="%3$s %2$s">%3$s</a>', wp_nonce_url(
                        add_query_arg(
                            array(
                                'page'          => urlencode( TGM_Plugin_Activation::$instance->menu ),
                                'plugin'        => urlencode( $item['slug'] ),
                                'plugin_name'   => urlencode( $item['sanitized_plugin'] ),
                                'plugin_source' => urlencode( $item['source'] ),
                                'version'       => urlencode( $item['version'] ),
                                'tgmpa-update'  => 'update-plugin',
                                'return_url'    => 'welcome_to_loversy_theme#install-plugins',
                            ), admin_url( TGM_Plugin_Activation::$instance->parent_slug )
                        ), 'tgmpa-update', 'tgmpa-nonce'
                    ), $item['sanitized_plugin'], esc_attr__( 'Update', 'loversy' ), esc_html__( 'Update', 'loversy' )
                    ),
                );
            } elseif ( ! is_plugin_inactive( $item['file_path'] ) ) {
                $actions = array(
                    'deactivate' => sprintf(
                        '<a href="%1$s" class="button button-primary" title="%3$s %2$s">%4$s</a>', esc_url(
                        add_query_arg(
                            array(
                                'plugin'                   => urlencode( $item['slug'] ),
                                'plugin_name'              => urlencode( $item['sanitized_plugin'] ),
                                'plugin_source'            => urlencode( $item['source'] ),
                                'loversy-deactivate-nonce' => wp_create_nonce( 'loversy-deactivate' ),
                                'loversy-deactivate'       => 'deactivate-plugin',
                            ), admin_url( 'themes.php?page=welcome_to_loversy_theme#install-plugins' )
                        )
                    ), $item['sanitized_plugin'], esc_attr__( 'Deactivate', 'loversy' ), esc_html__( 'Deactivate', 'loversy' )
                    ),
                );
            }
            
            return $actions;
        }
    }
}

//=================================================
// Demo import
//=================================================
if ( class_exists( 'OCDI_Plugin' ) ) {
    // Import files
    function loversy_import_files() {
        return array(
            array(
                'import_file_name'           => 'Loversy - All content',
                'import_file_url'            => 'https://store.adveits.com/project/loversy/wp/xml/loversy-all-content.xml',
                'import_widget_file_url'     => 'https://store.adveits.com/project/loversy/wp/xml/loversy-widgets.wie',
                'import_customizer_file_url' => 'https://store.adveits.com/project/loversy/wp/xml/loversy-customizer.dat',
                'import_preview_image_url'   => 'https://store.adveits.com/project/loversy/wp/xml/demo-screenshot.png',
                'import_notice'              => __( 'After you import this demo, you will have to setup the slider separately.', 'loversy' ),
                'preview_url'                => 'https://store.adveits.com/project/loversy/wp/demo',
            )
        );
    }
    
    add_filter( 'pt-ocdi/import_files', 'loversy_import_files' );
    
    // Disable notification
    add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
    
    // Disable page setup
    add_filter( 'pt-ocdi/plugin_page_setup', '__return_false' );
    
    function loversy_ocdi_plugin_page_setup( $default_settings ) {
        $settings['parent_slug'] = false;
        $settings['page_title']  = false;
        $settings['menu_title']  = false;
        $settings['capability']  = false;
        $settings['menu_slug']   = false;
        
        return $settings;
    }
    
    add_filter( 'pt-ocdi/plugin_page_setup', 'loversy_ocdi_plugin_page_setup' );
    
    // After import
    function loversy_after_import_setup() {
        // Assign menus to their locations.
        $menu_1 = get_term_by( 'name', 'Primary', 'nav_menu' );
        
        set_theme_mod(
            'nav_menu_locations', array(
                'menu-1' => $menu_1->term_id
            )
        );
        
        // Assign front page and posts page (blog page).
        $front_page_id = get_page_by_title( 'Home' );
        $blog_page_id  = get_page_by_title( 'Blog' );
        
        update_option( 'show_on_front', 'page' );
        update_option( 'page_on_front', $front_page_id->ID );
        update_option( 'page_for_posts', $blog_page_id->ID );
        update_option( 'posts_per_page', '6' );
        
        // Custom date format
        update_option( 'date_format', 'd M, Y' );
        
        // Discussion settings
        update_option( 'page_comments', '1' );
        update_option( 'comments_per_page', '1' );
        
        // Widget order and title
        $sidebar      = get_option( 'sidebars_widgets' );
        $widget_count = count( $sidebar['sidebar-1'] );
        
        $sidebar['sidebar-1'][0] = 'search-2';
        $sidebar['sidebar-1'][1] = 'categories-2';
        $sidebar['sidebar-1'][2] = 'loversy-recent-posts-1';
        $sidebar['sidebar-1'][3] = 'recent-comments-2';
        $sidebar['sidebar-1'][4] = 'tag_cloud-1';
        
        for ( $i = 5; $i < $widget_count; $i++ ) {
            unset( $sidebar['sidebar-1'][$i] );
        }
        
        update_option( 'sidebars_widgets', $sidebar );
        
        $recent_comments                                       = get_option( 'widget_recent-comments' );
        $recent_comments_title_key                             = key( $recent_comments );
        $recent_comments[$recent_comments_title_key]['number'] = '3';
        
        update_option( 'widget_recent-comments', $recent_comments );
    }
    
    add_action( 'pt-ocdi/after_import', 'loversy_after_import_setup' );
}

//=================================================
// Purchase data
//=================================================
function loversy_check_purchase_data( $code, $theme, $domain ) {
    $purchase_get = wp_remote_get( 'https://store.adveits.com/API/checkPurchaseData.php?envato-product=' . $theme . '&envato-code=' . $code . '&envato-domain=' . $domain );
    
    // Check for error
    if ( ! is_wp_error( $purchase_get ) ) {
        $response = wp_remote_retrieve_body( $purchase_get );
        
        // Check for error
        if ( ! is_wp_error( $response ) ) {
            $response = json_decode( $response );
            
            return $response;
        }
    }
    
    return false;
}

function loversy_check_data_status( $theme, $email, $domain ) {
    $data_get = wp_remote_get( 'https://store.adveits.com/API/checkData.php?envato-product=' . $theme . '&envato-email=' . $email . '&envato-domain=' . $domain );
    
    // Check for error
    if ( ! is_wp_error( $data_get ) ) {
        $response = wp_remote_retrieve_body( $data_get );
        
        // Check for error
        if ( ! is_wp_error( $response ) ) {
            $response = json_decode( $response );
            
            return $response;
        }
    }
    
    return false;
}

function loversy_get_domain() {
    $domain = get_option( 'siteurl' );
    
    if ( strpos( $domain, 'https' ) === false ) {
        $domain = str_replace( 'http://', '', $domain );
    } else {
        $domain = str_replace( 'https://', '', $domain );
    }
    
    if ( strpos( $domain, 'www.' ) !== false ) {
        $domain = str_replace( 'www.', '', $domain );
    }
    
    return $domain;
}

function loversy_check_activation_status() {
    $domain     = loversy_get_domain();
    $info       = loversy_check_purchase_data( get_option( 'envato_purchase_code' ), get_option( 'adveits_theme_id' ), $domain );
    $info_check = loversy_check_data_status( get_option( 'adveits_theme_id' ), get_option( 'admin_email' ), $domain );
    
    if ( isset( $info->error ) && ! empty( $info->error ) ) {
        update_option( 'status', 'purchase' );
        update_option( 'demo', 'demo' );
        update_option( 'envato_purchase_code', '' );
    }
}

add_action( 'admin_init', 'loversy_check_activation_status' );
