<?php
//=================================================
// System status
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================
?>

<div class="system-status nav-content" data-content="system-status">
    <?php
    $max_execution_time = ini_get( 'max_execution_time' );
    $max_input_vars     = ini_get( 'max_input_vars' );
    $post_max_size      = ini_get( 'post_max_size' );
    $php_version        = phpversion();
    $php_version_class  = version_compare( $php_version, '5.6', '>=' ) ? ' dashicons-yes green' : ' dashicons-no red';
    
    ob_start();
    phpinfo( INFO_MODULES );
    $info = ob_get_contents();
    ob_end_clean();
    $info = stristr( $info, 'Client API version' );
    preg_match( '/[1-9].[0-9].[1-9][0-9]/', $info, $match );
    $mysql_version       = $match[0];
    $mysql_version_class = version_compare( $mysql_version, '5', '>=' ) ? ' dashicons-yes green' : ' dashicons-no red';
    
    $max_execution_class = $max_execution_time >= 300 ? ' dashicons-yes green' : ' dashicons-no red';
    $max_input_class     = $max_input_vars >= 2000 ? ' dashicons-yes green' : ' dashicons-no red';
    $post_max            = str_replace( "M", "", $post_max_size );
    $post_max_class      = $post_max >= 10 ? ' dashicons-yes green' : ' dashicons-no red';
    
    $wp_version       = get_bloginfo( 'version' );
    $wp_version_class = version_compare( $wp_version, '5.0', '>=' ) ? ' dashicons-yes green' : ' dashicons-no red';
    
    $wp_memory       = str_replace( "M", "", WP_MEMORY_LIMIT );
    $wp_memory_class = $wp_memory >= 64 ? ' dashicons-yes green' : ' dashicons-no red';
    
    $upload_dir        = wp_upload_dir();
    $wp_writable_class = is_writable( trailingslashit( $upload_dir['basedir'] ) ) ? ' dashicons-yes green' : ' dashicons-no red';
    
    $wp_debug_class = defined( ( 'WP_DEBUG' ) ) && ( WP_DEBUG === false ) ? ' dashicons-yes green' : ' dashicons-no red';
    ?>

    <h3><?php esc_html_e( 'System status:', 'loversy' ); ?></h3>
    <p>Requirements listed below must be ensured by your server. You can contact your web host to help change these settings.</p>

    <table class="widefat" cellspacing="0">
        <thead>
            <tr>
                <th colspan="4"><b><?php esc_html_e( 'Theme config', 'loversy' ); ?></b></th>
            </tr>
        </thead>

        <tbody>
            <tr>
                <td width="20%"><?php esc_html_e( 'Theme name', 'loversy' ); ?></td>
                <td><?php echo esc_html( $theme_name ); ?></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'Theme Version', 'loversy' ); ?></td>
                <td><?php echo esc_html( $theme_version ); ?></td>
            </tr>
        </tbody>
    </table>

    <table class="widefat" cellspacing="0">
        <thead>
            <tr>
                <th colspan="4"><b><?php esc_html_e( 'PHP config', 'loversy' ); ?></b></th>
            </tr>
        </thead>

        <tbody>
            <tr>
                <td width="20%"><?php esc_html_e( 'PHP', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html( $php_version ); ?></td>
                <td width="40%"><?php esc_html_e( 'Required version 5.6 or greater', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $php_version_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'MySQL', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html( $mysql_version ); ?></td>
                <td width="40%"><?php esc_html_e( 'Required version 5 or greater', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $mysql_version_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'max_execution_time', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html( $max_execution_time ); ?></td>
                <td width="40%"><?php esc_html_e( 'Required max_execution_time 300', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $max_execution_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'max_input_vars', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html( $max_input_vars ); ?></td>
                <td width="40%"><?php esc_html_e( 'Required max_input_vars 2000', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $max_input_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'post_max_size', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html( $post_max_size ); ?></td>
                <td width="40%"><?php esc_html_e( 'Required post_max_size 10M', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $post_max_class ); ?>"></i></td>
            </tr>
        </tbody>
    </table>

    <table class="widefat" cellspacing="0">
        <thead>
            <tr>
                <th colspan="4"><b><?php esc_html_e( 'WordPress config', 'loversy' ); ?></b></th>
            </tr>
        </thead>

        <tbody>
            <tr>
                <td width="20%"><?php esc_html_e( 'Site URL', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_url( get_site_url() ); ?></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'Home URL', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_url( get_home_url() ); ?></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'File permissions', 'loversy' ); ?></td>
                <td width="30%"><?php echo is_writable( trailingslashit( $upload_dir['basedir'] ) ) ? esc_html( 'Uploads folder is writable', 'loversy' ) : esc_html( 'Uploads folder is not writable', 'loversy' ); ?>
                </td>
                <td width="40%"><?php esc_html_e( 'Required uploads folder is writable', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $wp_writable_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'WP version', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html( $wp_version ); ?></td>
                <td width="40%"><?php esc_html_e( 'Required version 5.0 or greater', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $wp_version_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'WP Memory Limit', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html(WP_MEMORY_LIMIT); ?></td>
                <td width="40%"><?php esc_html_e( 'Required memory limit 64M', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $wp_memory_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'WP Debug', 'loversy' ); ?></td>
                <td width="30%"><?php if ( defined( 'WP_DEBUG' ) && WP_DEBUG === true ) : ?>ON<?php else : ?>OFF<?php endif; ?></td>
                <td width="40%"><?php esc_html_e( 'OK - Debug is OFF', 'loversy' ); ?></td>
                <td><i class="dashicons<?php echo esc_attr( $wp_debug_class ); ?>"></i></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'WP Multisite Status', 'loversy' ); ?></td>
                <td width="30%"><?php echo is_multisite() ? esc_html( 'Yes', 'loversy' ) : esc_html( 'No', 'loversy' ); ?></td>
            </tr>

            <tr>
                <td width="20%"><?php esc_html_e( 'WP Language', 'loversy' ); ?></td>
                <td width="30%"><?php echo esc_html(get_locale()); ?></td>
            </tr>
        </tbody>
    </table>
</div>
