<?php
//=================================================
// Template fuctions for loversy theme
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

//=================================================
// Add a pingback url auto-discovery header for single posts, pages, or attachments
//=================================================
function loversy_pingback_header() {
    if ( is_singular() && pings_open() ) {
        printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
    }
}

add_action( 'wp_head', 'loversy_pingback_header' );

//=================================================
// Ajax actions
//=================================================
// Post loadmore
function loversy_posts_loadmore_ajax_handler( $query ) {
    $type                = $_POST['type'];
    $args                = json_decode( stripslashes( $_POST['query'] ), true );
    $args['paged']       = $_POST['page'] + 1;
    $args['post_status'] = 'publish';
    
    query_posts( $args );
    
    if ( $type == 'search' ) :
        if ( have_posts() ) :
            while ( have_posts() ) : the_post();
                get_template_part( 'template-parts/content', 'search', get_post_format() );
            endwhile;
            
            wp_reset_query();
        endif;
    else :
        if ( have_posts() ) :
            while ( have_posts() ) : the_post();
                get_template_part( 'template-parts/content', get_post_format() );
            endwhile;
            
            wp_reset_query();
        endif;
    endif;
    die;
}

add_action( 'wp_ajax_loadmore', 'loversy_posts_loadmore_ajax_handler' );
add_action( 'wp_ajax_nopriv_loadmore', 'loversy_posts_loadmore_ajax_handler' );

// Comments loadmore
function loversy_comments_loadmore_handler() {
    global $post;
    
    $post = get_post( $_POST['post_id'] );
    setup_postdata( $post );
    
    wp_list_comments(
        array(
            'style'    => 'li',
            'callback' => 'loversy_comments',
            'page'     => $_POST['cpage'],
            'per_page' => get_option( 'comments_per_page' )
        )
    );
    
    die;
}

add_action( 'wp_ajax_cloadmore', 'loversy_comments_loadmore_handler' );
add_action( 'wp_ajax_nopriv_cloadmore', 'loversy_comments_loadmore_handler' );

//=================================================
// Widget
//=================================================
// Tag cloud
function loversy_set_widget_tag_cloud_args( $args ) {
    $my_args = array(
        'smallest' => 0.789,
        'largest'  => 0.789,
        'unit'     => 'rem'
    );
    
    $args = wp_parse_args( $args, $my_args );
    
    return $args;
}

add_filter( 'widget_tag_cloud_args', 'loversy_set_widget_tag_cloud_args' );

//=================================================
// Body class filter
//=================================================
function loversy_body_classes( $classes ) {
    // Adds a class of no-sidebar when there is no sidebar present
    if ( ! is_active_sidebar( 'sidebar-1' ) ) {
        $classes[] .= 'no-sidebar';
    }
    
    // Adds a class of search page
    if ( is_search() ) {
        $classes[] .= 'search-results';
    }
    
    return $classes;
}

add_filter( 'body_class', 'loversy_body_classes' );

//=================================================
// Main class
//=================================================
if ( ! function_exists( 'loversy_main' ) ) {
    function loversy_main() {
        $classes = '';
        $classes .= 'site-main';
        
        // Check template file
        if ( is_page_template( 'template/page-no-title-and-content-spacing.php' ) ) {
            $classes .= ' content-no-spacing';
        }
        
        echo esc_attr( $classes );
    }
}

//=================================================
// Adding specific design to widget area menu
//=================================================
function loversy_widget_area_menu( $args ) {
    return array_merge(
        $args, array(
            'container'       => 'nav',
            'container_class' => 'menu-primary',
            'items_wrap'      => '<ul>%3$s</ul>',
            'walker'          => new Loversy_Walker_Nav_Menu_Widget()
        )
    );
}

add_filter( 'widget_nav_menu_args', 'loversy_widget_area_menu' );

//=================================================
// Filter for wp kses allowed tags
//=================================================
function loversy_wp_kses_allowed_tags( $tags, $context ) {
    switch ( $context ) {
        case 'loversy-global-escape':
            $tags = array(
                'address'    => array(),
                'a'          => array(
                    'class'    => true,
                    'href'     => true,
                    'rel'      => true,
                    'rev'      => true,
                    'name'     => true,
                    'target'   => true,
                    'download' => array(
                        'valueless' => 'y',
                    ),
                ),
                'abbr'       => array(),
                'acronym'    => array(),
                'area'       => array(
                    'alt'    => true,
                    'coords' => true,
                    'href'   => true,
                    'nohref' => true,
                    'shape'  => true,
                    'target' => true,
                ),
                'article'    => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'aside'      => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'audio'      => array(
                    'autoplay' => true,
                    'controls' => true,
                    'loop'     => true,
                    'muted'    => true,
                    'preload'  => true,
                    'src'      => true,
                ),
                'b'          => array(),
                'bdo'        => array(
                    'dir' => true,
                ),
                'big'        => array(),
                'blockquote' => array(
                    'cite'     => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'br'         => array(),
                'button'     => array(
                    'id'       => true,
                    'class'    => true,
                    'disabled' => true,
                    'name'     => true,
                    'type'     => true,
                    'value'    => true,
                ),
                'caption'    => array(
                    'align' => true,
                ),
                'cite'       => array(
                    'dir'  => true,
                    'lang' => true,
                ),
                'code'       => array(),
                'col'        => array(
                    'align'   => true,
                    'char'    => true,
                    'charoff' => true,
                    'span'    => true,
                    'dir'     => true,
                    'valign'  => true,
                    'width'   => true,
                ),
                'colgroup'   => array(
                    'align'   => true,
                    'char'    => true,
                    'charoff' => true,
                    'span'    => true,
                    'valign'  => true,
                    'width'   => true,
                ),
                'del'        => array(
                    'datetime' => true,
                ),
                'dd'         => array(),
                'dfn'        => array(),
                'details'    => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'open'     => true,
                    'xml:lang' => true,
                ),
                'input'      => array(
                    'class'         => true,
                    'type'          => true,
                    'name'          => true,
                    'value'         => true,
                    'size'          => true,
                    'id'            => true,
                    'aria-required' => true,
                    'aria-invalid'  => true,
                    'placeholder'   => true
                
                ),
                'div'        => array(
                    'id'       => true,
                    'role'     => true,
                    'class'    => true,
                    'style'    => true,
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'dl'         => array(),
                'dt'         => array(),
                'em'         => array(),
                'form'       => array(
                    'action'     => true,
                    'method'     => true,
                    'novalidate' => true,
                    'class'      => true
                ),
                'fieldset'   => array(),
                'figure'     => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'figcaption' => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'font'       => array(
                    'color' => true,
                    'face'  => true,
                    'size'  => true,
                ),
                'footer'     => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'h1'         => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'h2'         => array(
                    'align' => true,
                ),
                'h3'         => array(
                    'align' => true,
                ),
                'h4'         => array(
                    'align' => true,
                ),
                'h5'         => array(
                    'align' => true,
                ),
                'h6'         => array(
                    'align' => true,
                ),
                'header'     => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'hgroup'     => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'hr'         => array(
                    'align'   => true,
                    'noshade' => true,
                    'size'    => true,
                    'width'   => true,
                ),
                'i'          => array(
                    'class' => true
                ),
                'img'        => array(
                    'alt'      => true,
                    'align'    => true,
                    'border'   => true,
                    'height'   => true,
                    'hspace'   => true,
                    'longdesc' => true,
                    'vspace'   => true,
                    'src'      => true,
                    'usemap'   => true,
                    'width'    => true,
                ),
                'ins'        => array(
                    'datetime' => true,
                    'cite'     => true,
                ),
                'kbd'        => array(),
                'label'      => array(
                    'for'   => true,
                    'class' => true
                ),
                'legend'     => array(
                    'align' => true,
                ),
                'li'         => array(
                    'class' => true,
                    'align' => true,
                    'value' => true,
                ),
                'map'        => array(
                    'name' => true,
                ),
                'mark'       => array(),
                'menu'       => array(
                    'type' => true,
                ),
                'nav'        => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'p'          => array(
                    'class'    => true,
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'pre'        => array(
                    'width' => true,
                ),
                'q'          => array(
                    'cite' => true,
                ),
                's'          => array(),
                'samp'       => array(),
                'span'       => array(
                    'class'    => true,
                    'dir'      => true,
                    'align'    => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'section'    => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'small'      => array(),
                'strike'     => array(),
                'strong'     => array(),
                'sub'        => array(),
                'summary'    => array(
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'sup'        => array(),
                'table'      => array(
                    'align'       => true,
                    'bgcolor'     => true,
                    'border'      => true,
                    'cellpadding' => true,
                    'cellspacing' => true,
                    'dir'         => true,
                    'rules'       => true,
                    'summary'     => true,
                    'width'       => true,
                ),
                'tbody'      => array(
                    'align'   => true,
                    'char'    => true,
                    'charoff' => true,
                    'valign'  => true,
                ),
                'td'         => array(
                    'abbr'    => true,
                    'align'   => true,
                    'axis'    => true,
                    'bgcolor' => true,
                    'char'    => true,
                    'charoff' => true,
                    'colspan' => true,
                    'dir'     => true,
                    'headers' => true,
                    'height'  => true,
                    'nowrap'  => true,
                    'rowspan' => true,
                    'scope'   => true,
                    'valign'  => true,
                    'width'   => true,
                ),
                'textarea'   => array(
                    'name'          => true,
                    'class'         => true,
                    'id'            => true,
                    'aria-required' => true,
                    'aria-invalid'  => true,
                    'placeholder'   => true,
                    'cols'          => true,
                    'rows'          => true,
                    'disabled'      => true,
                    'readonly'      => true,
                ),
                'tfoot'      => array(
                    'align'   => true,
                    'char'    => true,
                    'charoff' => true,
                    'valign'  => true,
                ),
                'th'         => array(
                    'abbr'    => true,
                    'align'   => true,
                    'axis'    => true,
                    'bgcolor' => true,
                    'char'    => true,
                    'charoff' => true,
                    'colspan' => true,
                    'headers' => true,
                    'height'  => true,
                    'nowrap'  => true,
                    'rowspan' => true,
                    'scope'   => true,
                    'valign'  => true,
                    'width'   => true,
                ),
                'thead'      => array(
                    'align'   => true,
                    'char'    => true,
                    'charoff' => true,
                    'valign'  => true,
                ),
                'title'      => array(),
                'tr'         => array(
                    'align'   => true,
                    'bgcolor' => true,
                    'char'    => true,
                    'charoff' => true,
                    'valign'  => true,
                ),
                'track'      => array(
                    'default' => true,
                    'kind'    => true,
                    'label'   => true,
                    'src'     => true,
                    'srclang' => true,
                ),
                'tt'         => array(),
                'u'          => array(),
                'ul'         => array(
                    'type' => true,
                ),
                'ol'         => array(
                    'start'    => true,
                    'type'     => true,
                    'reversed' => true,
                ),
                'var'        => array(),
                'video'      => array(
                    'autoplay' => true,
                    'controls' => true,
                    'height'   => true,
                    'loop'     => true,
                    'muted'    => true,
                    'poster'   => true,
                    'preload'  => true,
                    'src'      => true,
                    'width'    => true,
                ),
            );
            
            return $tags;
        case 'loversy-theme-typography':
            $tags = array(
                'a'    => array(
                    'href'     => true,
                    'rel'      => true,
                    'rev'      => true,
                    'name'     => true,
                    'target'   => true,
                    'download' => array(
                        'valueless' => 'y',
                    ),
                ),
                'div'  => array(
                    'id'       => true,
                    'role'     => true,
                    'class'    => true,
                    'style'    => true,
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'font' => array(
                    'color' => true,
                    'face'  => true,
                    'size'  => true,
                ),
                'h1'   => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'h2'   => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'h3'   => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'h4'   => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'h5'   => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'h6'   => array(
                    'class' => true,
                    'style' => true,
                    'align' => true,
                ),
                'i'    => array(
                    'class' => true
                ),
                'p'    => array(
                    'class'    => true,
                    'align'    => true,
                    'dir'      => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
                'span' => array(
                    'class'    => true,
                    'dir'      => true,
                    'align'    => true,
                    'lang'     => true,
                    'xml:lang' => true,
                ),
            );
            
            return $tags;
        case 'loversy-theme-welcome':
            $tags = array(
                'br' => array()
            );
            
            return $tags;
        case 'loversy-theme-breadcrumb':
            $tags = array(
                'a'  => array(
                    'href'     => true,
                    'rel'      => true,
                    'rev'      => true,
                    'name'     => true,
                    'target'   => true,
                    'download' => array(
                        'valueless' => 'y',
                    ),
                ),
                'li' => array(
                    'class' => true,
                ),
            
            );
            
            return $tags;
        default:
            return $tags;
    }
}

add_filter( 'wp_kses_allowed_html', 'loversy_wp_kses_allowed_tags', 10, 2 );

// Allowing style attribute display
add_filter(
    'safe_style_css', function( $styles ) {
    $styles[] = 'display';
    
    return $styles;
}
);
