<?php
//=================================================
// Template tags for loversy theme
// 
// Eventually, some of the functionality here could be replaced by core features.
// 
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

//=================================================
// Logo container width
//=================================================
if ( ! function_exists( 'loversy_logo_container_width' ) ) {
    function loversy_logo_container_width() {
        $logo_container_width = get_theme_mod( 'logo_container_width', 104 );
        
        $base_font_size                         = '19';
        $logo_container_width_px                = $logo_container_width;
        $logo_container_width_rem               = $logo_container_width_px / $base_font_size * 1;
        $logo_container_width_rem_format_number = number_format( $logo_container_width_rem, 3, '.', '' );
        
        if ( $logo_container_width ) { ?>
            <style>
                .site-header .logo img,
                #menu-modal .modal-header .logo img {
                    width: <?php echo esc_attr( $logo_container_width_px ); ?>px !important;
                }
            </style>
        <?php }
    }
}

//=================================================
// Post
//=================================================
//=============================
// Post title
//=============================
if ( ! function_exists( 'loversy_post_title' ) ) {
    function loversy_post_title() {
        global $wp_query;
        
        $title           = get_the_title();
        $blog_page_title = get_theme_mod( 'blog_page_title', 'Blog' );
        $posts_page_id   = get_option( 'page_for_posts' );
        $posts_page      = get_page( $posts_page_id );
        
        // Class
        $title_class = 'class="large ' . str_split( $title )[0] . '"';
        
        if ( is_singular( 'post' ) ) {
            echo '<h2>' . $title . '</h2>';
        } else if ( is_singular() && ! is_page_template() ) {
            echo '<h1 class="large">' . $title . '.</h1>';
        } else if ( is_home() ) {
            if ( $posts_page_id ) {
                echo '<h1 class="large">' . $posts_page->post_title . '.</h1>';
            } else {
                echo '<h1 class="large">' . $blog_page_title . '.</h1>';
            }
        } else if ( is_search() ) {
            echo '<h1>' . $wp_query->found_posts . ' ' . esc_html__( 'results for:', 'loversy' ), ' ' . get_search_query() . '</h1>';
        } else if ( is_page_template() ) {
            echo '<h1 ' . $title_class . '>' . $title . '.</h1>';
        } else {
            echo '<h5 class="title"><a title="' . $title . '" href="' . esc_url( get_permalink() ) . '">' . $title . '</a></h5>';
        }
    }
}

//=============================
// Post thumbnail
//=============================
if ( ! function_exists( 'loversy_post_thumbnail' ) ) {
    function loversy_post_thumbnail() {
        if ( post_password_required() || is_attachment() ) {
            return;
        }
        
        $thumb_id                              = get_post_thumbnail_id();
        $thumb_medium_large                    = wp_get_attachment_image_src( $thumb_id, 'medium_large', true );
        $thumb_large                           = wp_get_attachment_image_src( $thumb_id, 'large', true );
        $single_post_page_thumbnail_variations = get_theme_mod( 'single_post_page_thumbnail_variations', 'width-object-fit' );
        
        if ( is_single() ) : ?>
            <?php if ( $single_post_page_thumbnail_variations == 'width-object-fit' ) : ?>
                <?php if ( has_post_thumbnail() ) : ?>
                    <div class="img object-fit">
                        <div class="object-fit-cover">
                            <img src="<?php echo esc_url( $thumb_large[0] ); ?>" alt="<?php the_title_attribute(); ?>">
                        </div>
                    </div>
                <?php endif; ?>
            <?php else : ?>
                <?php if ( has_post_thumbnail() ) : ?>
                    <div class="img">
                        <img class="img-fluid" src="<?php echo esc_url( $thumb_large[0] ); ?>" alt="<?php the_title_attribute(); ?>">
                    </div>
                <?php endif; ?>
            <?php endif; ?>
        <?php else : ?>
            <?php if ( has_post_thumbnail() ) : ?>
                <div class="img object-fit overflow-hidden">
                    <div class="object-fit-cover transform-scale-h">
                        <img class="card-top-img" src="<?php echo esc_url( $thumb_medium_large[0] ); ?>" alt="<?php the_title_attribute(); ?>">
                    </div>
                </div>
            <?php endif; ?>
        <?php endif;
    }
}

//=============================
// Post category
//=============================
if ( ! function_exists( 'loversy_post_category' ) ) {
    function loversy_get_the_category_list( $separator = '', $parents = '', $post_id = false ) {
        global $wp_rewrite;
        
        $categories = apply_filters( 'the_category_list', get_the_category( $post_id ), $post_id );
        $rel        = ( is_object( $wp_rewrite ) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';
        $thelist    = '';
        
        if ( $categories ) {
            $i = 0;
            
            foreach ( $categories as $category ) {
                $i++;
                
                if ( is_singular( 'post' ) ) {
                    if ( $i == count( $categories ) ) {
                        $thelist .= '<a title="' . $category->name . '" href="' . get_category_link( $category->term_id ) . ' " ' . $rel . '>' . $category->name . '</a>';
                    } else {
                        $thelist .= '<a title="' . $category->name . '" href="' . get_category_link( $category->term_id ) . ' " ' . $rel . '>' . $category->name . '</a><span>, </span>';
                    }
                } else {
                    if ( $i == 1 ) {
                        if ( get_search_query() || isset( $_POST['type'] ) && $_POST['type'] == 'search' || isset( $_GET['s'] ) && $_GET['s'] == '' ) {
                            $thelist .= $separator;
                            $thelist .= '<p class="p-small"><a title="' . $category->name . '" class="text-secondary"  href="' . get_category_link( $category->term_id ) . '" ' . $rel . '>' . $category->name . '</a></p>';
                        } else {
                            $thelist .= $separator;
                            $thelist .= '<a title="' . $category->name . '" class="a-small"  href="' . get_category_link( $category->term_id ) . ' " ' . $rel . '>' . $category->name . '</a>';
                        }
                    }
                }
            }
        } else {
            $thelist .= $separator;
        }
        
        return $thelist;
    }
    
    function loversy_post_category() {
        if ( 'post' === get_post_type() ) {
            $categories_list = loversy_get_the_category_list();
            
            if ( $categories_list ) {
                echo wp_kses( $categories_list, 'loversy-global-escape' );
            }
        }
    }
}

//=============================
// Post posted on
//=============================
if ( ! function_exists( 'loversy_posted_on' ) ) {
    function loversy_posted_on() {
        $time_string  = get_the_date();
        $time_explode = explode( ' ', $time_string );
        
        if ( strpos( $time_string, ' ' ) == true ) {
            echo '<span class="date">' . $time_explode[0] . ' ' . $time_explode[1] . ' ' . $time_explode[2] . '</span>';
        } else {
            echo '<span class="date">' . $time_string . '</span>';
        }
    }
}

//=============================
// Post posted by
//=============================
if ( ! function_exists( 'loversy_posted_by' ) ) {
    function loversy_posted_by() {
        $byline = sprintf(
            '<span><a href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html__( 'By', 'loversy' ) . ' ' . esc_html( get_the_author() ) . '</a></span>'
        );
        
        echo wp_kses( $byline, 'loversy-global-escape' );
    }
}

//=============================
// Post comments count
//=============================
if ( ! function_exists( 'loversy_comments_count' ) ) {
    function loversy_comments_count() {
        if ( 'post' === get_post_type() ) {
            $comments_count = get_comments_number();
            
            echo wp_kses( $comments_count, 'loversy-global-escape' );
        }
    }
}

//=============================
// Post tags
//=============================
if ( ! function_exists( 'loversy_post_tags' ) ) {
    function loversy_post_tags() {
        if ( 'post' === get_post_type() ) {
            $tags_list = get_the_tag_list();
            
            if ( $tags_list ) {
                echo '<div class="tags"><p>' . $tags_list . '</p></div>';
            }
        } elseif ( 'adveits_portfolio' === get_post_type() ) {
            $tags_list = get_the_term_list( get_the_ID(), 'adveits_portfolio_tag', '', '' );
            
            if ( $tags_list ) {
                echo '<div class="tags"><p>' . $tags_list . '</p></div>';
            }
        }
    }
}

//=================================================
// Excerpt limitation
//=================================================
if ( ! function_exists( 'loversy_excerpt' ) ) {
    function loversy_the_excerpt( $limit ) {
        $excerpt = explode( ' ', get_the_excerpt(), $limit );
        
        if ( count( $excerpt ) >= $limit ) {
            array_pop( $excerpt );
            $excerpt = implode( " ", $excerpt ) . '...';
        } else {
            $excerpt = implode( " ", $excerpt );
        }
        
        $excerpt = preg_replace( '`[[^]]*]`', '', $excerpt );
        
        echo wp_kses( $excerpt, 'loversy-global-escape' );
    }
}

//=================================================
// Archive
//=================================================
//=============================
// Archive title
//=============================
if ( ! function_exists( 'loversy_archive_title' ) ) {
    function loversy_archive_title() {
        $title           = get_the_archive_title();
        $blog_page_title = get_theme_mod( 'blog_page_title', 'Blog' );
        $posts_page_id   = get_option( 'page_for_posts' );
        $posts_page      = get_page( $posts_page_id );
        
        if ( strpos( $title, ':' ) == true ) {
            $words       = explode( ':', $title );
            $word_second = $words[1];
            
            $title_prim = $word_second;
        } else {
            $title_prim = $title;
        }
        
        if ( is_singular( 'post' ) ) {
            if ( $posts_page_id ) {
                echo '<h1 class="large">' . $posts_page->post_title . '.</h1>';
            } else {
                echo '<h1 class="large">' . $blog_page_title . '.</h1>';
            }
        } else if ( ! is_post_type_archive() || is_author() || is_category() || is_tag() ) {
            echo '<h1 class="large">' . $title_prim . '.</h1>';
        } else {
            echo '<h1 class="large">' . $title . '.</h1>';
        }
    }
}

//=================================================
// Search form
//=================================================
if ( ! function_exists( 'loversy_search_form' ) ) {
    function loversy_search_form( $form ) {
        $search_out = '<form class="search-form" role="search" method="get" action="' . esc_url( home_url( '/' ) ) . '">
            <div class="search input-group">
                <input type="search" class="form-control form-control-lg" placeholder="' . esc_attr__( 'Search', 'loversy' ) . '" value="' . get_search_query() . '" name="s">

                <div class="input-group-append">
                    <button class="btn btn-link border-0 p-0 min-w-auto">
                        <i class="fas fa-search"></i>
                    </button>
                </div>
            </div>
        </form>';
        
        return $search_out;
    }
    
    add_filter( 'get_search_form', 'loversy_search_form' );
}

//=================================================
// Load more
//=================================================
//=============================
// Posts load more
//=============================
if ( ! function_exists( 'loversy_posts_load_more' ) ) {
    function loversy_posts_load_more() {
        global $wp_query;
        $paginate = paginate_links();
        
        // Type
        $type = '';
        
        if ( is_search() ) {
            $type .= 'search';
        } else if ( is_front_page() && is_home() ) {
            $type .= 'home';
        } else if ( is_home() ) {
            $type .= 'blog';
        } else if ( is_archive() ) {
            $type .= 'archive';
        } else {
            $type .= 'post';
        }
        
        // Space class
        $space_class = '';
        
        if ( is_search() ) {
            $space_class .= 'm-top-lg';
        } else {
            $space_class .= 'm-top-lg';
        }
        
        if ( $paginate ) {
            if ( $wp_query->max_num_pages > 1 ) { ?>
                <div class="loadmore spacer <?php echo esc_attr( $space_class ); ?>">
                    <a title="<?php esc_html_e( 'Load more', 'loversy' ); ?>" class="btn btn-outline-primary text-uppercase" id="loadmore" data-type="<?php echo esc_attr( $type ); ?>" href="#"><?php esc_html_e( 'Load more', 'loversy' ); ?></a>
                </div>
            <?php } ?>
        <?php }
    }
}

//=============================
// Comments load more
//=============================
if ( ! function_exists( 'loversy_comments_load_more' ) ) {
    function loversy_comments_load_more() {
        global $wp_query;
        $paginate = paginate_comments_links( array( 'echo' => false ) );
        $cpage    = get_query_var( 'cpage' ) ? get_query_var( 'cpage' ) : 1;
        
        if ( $paginate ) {
            if ( $cpage > 1 ) { ?>
                <div class="loadmore spacer m-top-lg">
                    <a title="<?php esc_html_e( 'More comments', 'loversy' ); ?>" class="btn btn-outline-primary text-uppercase" id="comment_loadmore" href="#"><?php echo esc_html__( 'More comments', 'loversy' ); ?></a>
                </div>
                
                <?php
                add_action(
                    'wp_print_footer_scripts', function() {
                    $cpage = get_query_var( 'cpage' ) ? get_query_var( 'cpage' ) : 1;
                    ?>

                    <script>
                        parent_post_id = <?php echo esc_attr( get_the_ID() ); ?>,
                            cpage =; <?php echo esc_attr( $cpage ); ?>
                    </script>
                <?php }
                );
                ?>
            <?php }
        }
    }
}

//=================================================
// Breadcrumb
//=================================================
if ( ! function_exists( 'loversy_breadcrumb' ) ) {
    function loversy_breadcrumb() {
        $breadcrumb_type = get_theme_mod( 'breadcrumb_type', 'default' );
        
        if ( $breadcrumb_type == 'yoast_seo' && function_exists( 'yoast_breadcrumb' ) ) {
            yoast_breadcrumb( '<nav aria-label="breadcrumb">', '</nav>' );
        } else {
            global $post;
            $custom_taxonomy = '';
            $front_title     = '';
            $front_page_id   = get_option( 'page_on_front' );
            $front_page      = get_page( $front_page_id );
            
            if ( $front_page_id ) {
                $front_title .= $front_page->post_title;
            } else {
                $front_title .= __( 'Home', 'loversy' );
            }
            
            if ( ! is_front_page() ) {
                echo '<nav aria-label="breadcrumb">';
                echo '<ol class="breadcrumb">';
                echo '<li class="breadcrumb-item"><a href="' . get_home_url() . '" title="' . $front_title . '">' . $front_title . '</a></li>';
                
                if ( is_archive() && ! is_tax() && ! is_category() && ! is_tag() ) {
                    if ( is_author() ) {
                        global $author;
                        $userdata = get_userdata( $author );
                        
                        echo '<li class="breadcrumb-item active">' . $userdata->display_name . '</li>';
                    } else if ( is_day() ) {
                        echo '<li class="breadcrumb-item active">' . get_the_time( 'jS' ) . ' ' . get_the_time( 'M' ) . '</li>';
                    } else if ( is_month() ) {
                        echo '<li class="breadcrumb-item active">' . get_the_time( 'F' ) . ' ' . get_the_time( 'Y' ) . '</li>';
                    } else if ( is_year() ) {
                        echo '<li class="breadcrumb-item active">' . get_the_time( 'Y' ) . '</li>';
                    } else {
                        echo '<li class="breadcrumb-item active">' . get_the_archive_title() . '</li>';
                    }
                } else if ( is_archive() && is_tax() && ! is_category() && ! is_tag() ) {
                    $post_type = get_post_type();
                    
                    if ( $post_type != 'post' ) {
                        $post_type_object  = get_post_type_object( $post_type );
                        $post_type_archive = get_post_type_archive_link( $post_type );
                        
                        echo '<li class="breadcrumb-item"><a href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . '</a></li>';
                    }
                    
                    $custom_tax_name = get_queried_object()->name;
                    
                    echo '<li class="breadcrumb-item">' . $custom_tax_name . '</li>';
                } else if ( is_single() ) {
                    $post_type         = get_post_type();
                    $post_type_archive = get_post_type_archive_link( $post_type );
                    
                    if ( $post_type != 'post' ) {
                        $post_type_object = get_post_type_object( $post_type );
                        
                        echo '<li class="breadcrumb-item"><a href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . '</a></li>';
                    } else {
                        $blog_title = get_theme_mod( 'blog_page_title', 'Blog' );
                        
                        if ( get_option( 'page_for_posts' ) != 0 ) {
                            $blog_title = get_the_title( get_option( 'page_for_posts', true ) );
                            
                            echo '<li class="breadcrumb-item"><a href="' . $post_type_archive . '" title="' . $blog_title . '">' . $blog_title . '</a></li>';
                        }
                    }
                    
                    $category = get_the_category();
                    
                    if ( ! empty( $category ) && ! is_single() ) {
                        $last_category   = $category[0];
                        $get_cat_parents = rtrim( get_category_parents( $last_category->term_id, true, ',' ), ',' );
                        $cat_parents     = explode( ',', $get_cat_parents );
                        $cat_display     = '';
                        
                        foreach ( $cat_parents as $parents ) {
                            $cat_display .= '<li class="breadcrumb-item">' . $parents . '</li>';
                        }
                    }
                    
                    $taxonomy_exists = taxonomy_exists( $custom_taxonomy );
                    
                    if ( empty( $last_category ) && ! empty( $custom_taxonomy ) && $taxonomy_exists ) {
                        $taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );
                        $cat_id         = $taxonomy_terms[0]->term_id;
                        $cat_nicename   = $taxonomy_terms[0]->slug;
                        $cat_link       = get_term_link( $taxonomy_terms[0]->term_id, $custom_taxonomy );
                        $cat_name       = $taxonomy_terms[0]->name;
                    }
                    
                    if ( ! empty( $last_category ) ) {
                        echo wp_kses( $cat_display, 'loversy-theme-breadcrumb' );
                        echo '<li class="breadcrumb-item active">' . get_the_title() . '</li>';
                    } else if ( ! empty( $cat_id ) ) {
                        echo '<li class="breadcrumb-item"><a href="' . $cat_link . '" title="' . $cat_name . '">' . $cat_name . '</a></li>';
                        echo '<li class="breadcrumb-item active' . $post->ID . '">' . get_the_title() . '</li>';
                    } else {
                        echo '<li class="breadcrumb-item active">' . get_the_title() . '</li>';
                    }
                } else if ( is_category() ) {
                    echo '<li class="breadcrumb-item active">' . single_cat_title( '', false ) . '</li>';
                } else if ( is_page() ) {
                    if ( $post->post_parent ) {
                        $anc     = get_post_ancestors( $post->ID );
                        $anc     = array_reverse( $anc );
                        $parents = '';
                        
                        foreach ( $anc as $ancestor ) {
                            $parents .= '<li class="breadcrumb-item"><a href="' . get_permalink( $ancestor ) . '" title="' . get_the_title( $ancestor ) . '">' . get_the_title( $ancestor ) . '</a></li>';
                        }
                        
                        echo wp_kses( $parents, 'loversy-theme-breadcrumb' );
                        echo '<li class="breadcrumb-item active">' . get_the_title() . '</li>';
                    } else {
                        echo '<li class="breadcrumb-item active">' . get_the_title() . '</li>';
                    }
                } else if ( is_tag() ) {
                    $term_id       = get_query_var( 'tag_id' );
                    $taxonomy      = 'post_tag';
                    $args          = 'include=' . $term_id;
                    $terms         = get_terms( $taxonomy, $args );
                    $get_term_name = $terms[0]->name;
                    
                    echo '<li class="breadcrumb-item active">' . $get_term_name . '</li>';
                } else if ( get_query_var( 'paged' ) ) {
                    echo '<li class="breadcrumb-item active">' . get_query_var( 'paged' ) . '</li>';
                } else if ( is_search() ) {
                    echo '<li class="breadcrumb-item active">' . get_search_query() . '</li>';
                } elseif ( is_404() ) {
                    echo '<li class="breadcrumb-item active">' . __( 'Error 404', 'loversy' ) . '</li>';
                }
                
                if ( ! is_front_page() && is_home() ) {
                    $post_type         = get_post_type();
                    $post_type_archive = get_post_type_archive_link( $post_type );
                    $blog_title        = get_theme_mod( 'blog_page_title', 'Blog' );
                    
                    if ( get_option( 'page_for_posts' ) != 0 ) {
                        $blog_title = get_the_title( get_option( 'page_for_posts', true ) );
                    }
                    
                    echo '<li class="breadcrumb-item active">' . $blog_title . '</li>';
                }
                
                echo '</ol>';
                echo '</nav>';
            }
        }
    }
}

//=================================================
// Menu primary
//=================================================
// Header
if ( ! function_exists( 'loversy_menu_primary' ) ) {
    function loversy_menu_primary() {
        $output = '';
        
        $main = array(
            'container'       => 'nav',
            'container_class' => 'menu-primary',
            'fallback_cb'     => 'fallback_menu_primary',
            'theme_location'  => 'menu-1',
            'items_wrap'      => '<ul class="nav flex-column">%3$s</ul>',
            'walker'          => new Loversy_Walker_Nav_Menu()
        );
        
        $output .= wp_nav_menu( $main );
    }
}

if ( ! function_exists( 'fallback_menu_primary' ) ) {
    function fallback_menu_primary() {
        if ( current_user_can( 'administrator' ) ) {
            echo '<nav class="menu-primary"><ul class="nav flex-column"><li class="nav-item"><a href="' . esc_url( admin_url( "nav-menus.php" ) ) . '">' . esc_html__( 'Add a menu', 'loversy' ) . '</a></li></ul></nav>';
        } else {
            echo '';
        }
    }
}

//=================================================
// Menu class
//=================================================
class Loversy_Walker_Nav_Menu extends Walker_Nav_Menu {
    private $curItem;
    
    function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
        $this->curItem = $item;
        $title         = $item->title;
        $permalink     = $item->url;
        
        $class_names = '';
        $class_names .= in_array( 'menu-item-has-children', $item->classes ) ? ' nav-item-has-children dropdown-child-click-effect' : '';
        $class_names .= in_array( 'current-menu-item', $item->classes ) ? ' current-nav-item' : '';
        $class_names .= in_array( 'current-lang', $item->classes ) ? ' current-lang' : '';
        
        $class_names = esc_attr( $class_names );
        
        if ( $depth >= 1 ) {
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {
                if ( in_array( 'current-menu-item', $item->classes ) ) {
                    $output .= '<li class="nav-item current-nav-item nav-item-has-children dropdown-child-click-effect">';
                } else {
                    $output .= '<li class="nav-item nav-item-has-children dropdown-child-click-effect">';
                }
            } else {
                if ( in_array( 'current-menu-item', $item->classes ) ) {
                    $output .= '<li class="nav-item current-nav-item">';
                } else {
                    $output .= '<li class="nav-item">';
                }
            }
        } else {
            $output .= '<li class="nav-item' . $class_names . '">';
        }
        
        if ( $item->target ) {
            $output .= '<a title ="' . $title . '" href="' . $permalink . '" target="' . $item->target . '">';
        } else {
            $output .= '<a title ="' . $title . '" href="' . $permalink . '">';
        }
        
        $output .= $title;
        
        if ( in_array( 'menu-item-has-children', $item->classes ) ) {
            $output .= '</a><span class="dropdown-toggle dropdown-custom-icon"><span class="dropdown-icon"><i class="fas fa-caret-down"></i></span></span>';
        } else {
            $output .= '</a> ';
        }
    }
    
    function end_el( &$output, $item, $depth = 0, $args = array() ) {
        $output .= "</li>\n";
    }
    
    // Submenu
    function start_lvl( &$output, $depth = 0, $args = array() ) {
        $item = $this->curItem;
        
        $indent = str_repeat( "\t", $depth );
        $output .= "\n$indent<ul class=\"dropdown-menu\">\n";
    }
    
    function end_lvl( &$output, $depth = 0, $args = array() ) {
        $indent = str_repeat( "\t", $depth );
        $output .= "$indent</ul>\n";
    }
}

//=================================================
// Widget menu class
//=================================================
class Loversy_Walker_Nav_Menu_Widget extends Walker_Nav_Menu {
    private $curItem;
    
    function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
        $this->curItem = $item;
        $title         = $item->title;
        $permalink     = $item->url;
        
        $class_names = '';
        $class_names .= in_array( 'menu-item-has-children', $item->classes ) ? ' nav-item-has-children dropdown-child-click-effect a-hover' : '';
        
        $class_names .= in_array( 'current-menu-item', $item->classes ) ? ' current-nav-item' : '';
        $class_names .= in_array( 'current-lang', $item->classes ) ? ' current-lang' : '';
        $class_names = esc_attr( $class_names );
        
        if ( $depth >= 1 ) {
            if ( in_array( 'menu-item-has-children', $item->classes ) ) {
                if ( in_array( 'current-menu-item', $item->classes ) ) {
                    $output .= '<li class="nav-item current-nav-item nav-item-has-children dropdown-child-click-effect a-hover">';
                } else {
                    $output .= '<li class="nav-item nav-item-has-children dropdown-child-click-effect a-hover">';
                }
            } else {
                if ( in_array( 'current-menu-item', $item->classes ) ) {
                    $output .= '<li class="current-nav-item">';
                } else {
                    $output .= '<li>';
                }
            }
        } else {
            $output .= '<li class="nav-item' . $class_names . '">';
        }
        
        if ( $item->target ) {
            $output .= '<a title ="' . $title . '" href="' . $permalink . '" target="' . $item->target . '">';
        } else {
            $output .= '<a title ="' . $title . '" href="' . $permalink . '">';
        }
        
        $output .= $title;
        
        if ( in_array( 'menu-item-has-children', $item->classes ) ) {
            $output .= '</a><span class="dropdown-toggle dropdown-custom-icon"><span class="dropdown-icon"><i class="fas fa-caret-down"></i></span></span>';
        } else {
            $output .= '</a> ';
        }
    }
    
    function end_el( &$output, $item, $depth = 0, $args = array() ) {
        $output .= "</li>\n";
    }
    
    // Submenu
    function start_lvl( &$output, $depth = 0, $args = array() ) {
        $item = $this->curItem;
        
        $indent = str_repeat( "\t", $depth );
        $output .= "\n$indent<ul class=\"dropdown-menu\">\n";
    }
    
    function end_lvl( &$output, $depth = 0, $args = array() ) {
        $indent = str_repeat( "\t", $depth );
        $output .= "$indent</ul>\n";
    }
}

//=================================================
// Portfolio
//=================================================
//=============================
// Portfolio gallery
//=============================
if ( ! function_exists( 'loversy_portfolio_gallery' ) ) {
    function loversy_portfolio_gallery() {
        $images = get_field( 'adveits_portfolio_images' );
        
        if ( $images ) : ?>
            <div id="slider" class="block spacer p-top-xl">
                <div class="adv-slider">
                    <div class="adv-swiper-container">
                        <div class="adv-swiper-wrapper">
                            <?php foreach ( $images as $image ) : ?>
                                <?php if ( $image['adveits_portfolio_image']['url'] ) : ?>
                                    <div class="adv-swiper-slide">
                                        <div class="img object-fit">
                                            <div class="object-fit-cover">
                                                <img src="<?php echo esc_url( $image['adveits_portfolio_image']['sizes']['large'] ); ?>" alt="<?php the_title_attribute(); ?>">
                                            </div>
                                        </div>
                                    </div>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </div>

                        <div class="adv-2-swiper-button-next adv-swiper-button-white">
                            <i class="fas fa-long-arrow-alt-right"></i>
                        </div>

                        <div class="adv-2-swiper-button-prev adv-swiper-button-white">
                            <i class="fas fa-long-arrow-alt-left"></i>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif;
    }
}

//=============================
// Portfolio pagination
//=============================
if ( ! function_exists( 'loversy_portfolio_pagination' ) ) {
    function loversy_portfolio_pagination() { ?>
        <?php
        $current_id = get_the_ID();
        $prev_post  = get_previous_post();
        $next_post  = get_next_post();
        
        $args = array(
            'post_type'      => 'adveits_portfolio',
            'posts_per_page' => -1
        );
        
        $posts       = get_posts( $args );
        $posts_count = count( $posts );
        $last_post   = end( $posts );
        $first_post  = $posts[0];
        
        $first_id = $posts[0]->ID;
        $last_id  = $last_post->ID;
        
        $prev_post_id    = '';
        $prev_post_title = '';
        $next_post_id    = '';
        $next_post_title = '';
        
        if ( $posts_count > 1 ) {
            if ( $current_id == $first_id ) {
                $prev_post_id    = $prev_post->ID;
                $prev_post_title = $prev_post->post_title;
            } else if ( $current_id == $last_id ) {
                $prev_post_id    = $first_post->ID;
                $prev_post_title = $first_post->post_title;
            } else {
                $prev_post_id    = $prev_post->ID;
                $prev_post_title = $prev_post->post_title;
            }
            
            if ( $current_id != $first_id ) {
                $next_post_id    = $next_post->ID;
                $next_post_title = $next_post->post_title;
            } else {
                $next_post_id    = $last_post->ID;
                $next_post_title = $last_post->post_title;
            }
        }
        ?>
        
        <?php if ( $prev_post_title || $next_post_title ) : ?>
            <div id="pagination" class="block spacer p-top-xl">
                <div class="portfolio-pagination">
                    <div class="row justify-content-between gutter-width-md with-pb-lg">
                        <div class="col-sm-6 col-md-6 col-lg-6 col-xl-6">
                            <?php if ( $prev_post_title ) : ?>
                                <a class="d-flex justify-content-start link previous-link" href="<?php echo esc_url( get_permalink( $prev_post_id ) ); ?>">
                                    <div class="d-flex align-items-center justify-content-start">
                                        <div class="left">
                                            <p><i class="fas fa-long-arrow-alt-left"></i></p>
                                        </div>

                                        <div class="right">
                                            <p class="link-text after"><?php esc_html_e( 'Previous project', 'loversy' ); ?></p>
                                            <h4 class="link-title"><?php echo esc_html( $prev_post_title ); ?></h4>
                                        </div>
                                    </div>
                                </a>
                            <?php endif; ?>
                        </div>

                        <div class="col-sm-6 col-md-6 col-lg-6 col-xl-6">
                            <?php if ( $next_post_title ) : ?>
                                <a class="d-flex justify-content-end link next-link" href="<?php echo esc_url( get_permalink( $next_post_id ) ); ?>">
                                    <div class="d-flex align-items-center justify-content-end">
                                        <div class="left">
                                            <p class="link-text after"><?php esc_html_e( 'Next project', 'loversy' ); ?></p>
                                            <h4 class="link-title"><?php echo esc_html( $next_post_title ); ?></h4>
                                        </div>

                                        <div class="right">
                                            <p><i class="fas fa-long-arrow-alt-right"></i></p>
                                        </div>
                                    </div>
                                </a>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
    <?php }
}
