<?php
//=================================================
// Template part for displaying posts
//
// @package Loversy
// @author  Adveits <support@adveits.com>
// @version 1.0.0
//=================================================

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

$type = '';

if ( isset( $_POST['type'] ) ) {
    $type = $_POST['type'];
}

$blog_page_show_post_category       = get_theme_mod( 'blog_page_show_post_category', true );
$blog_page_show_post_title          = get_theme_mod( 'blog_page_show_post_title', true );
$blog_page_show_post_author         = get_theme_mod( 'blog_page_show_post_author', true );
$blog_page_show_post_comments_count = get_theme_mod( 'blog_page_show_post_comments_count', true );
$blog_page_show_post_excerpt        = get_theme_mod( 'blog_page_show_post_excerpt', true );
$blog_page_show_post_link           = get_theme_mod( 'blog_page_show_post_link', true );

$no_thumbnail = '';

$home_page_layout    = get_theme_mod( 'home_page_layout' );
$archive_page_layout = get_theme_mod( 'archive_page_layout' );
$classes             = '';

if ( is_front_page() && is_home() || $type == 'home' ) {
    if ( $home_page_layout == 'full' || ! is_active_sidebar( 'sidebar-1' ) ) {
        $classes = 'col-xl-4 col-lg-4 col-md-6 col-sm-6';
    } else {
        $classes = 'col-xl-6 col-lg-6 col-md-6 col-sm-6';
    }
} elseif ( is_home() || $type == 'blog' ) {
    if ( $home_page_layout == 'full' || ! is_active_sidebar( 'sidebar-1' ) ) {
        $classes = 'col-xl-4 col-lg-4 col-md-6 col-sm-6';
    } else {
        $classes = 'col-xl-6 col-lg-6 col-md-6 col-sm-6';
    }
} elseif ( is_archive() || $type == 'archive' ) {
    if ( $archive_page_layout == 'full' || ! is_active_sidebar( 'sidebar-1' ) ) {
        $classes = 'col-xl-4 col-lg-4 col-md-6 col-sm-6';
    } else {
        $classes = 'col-xl-6 col-lg-6 col-md-6 col-sm-6';
    }
} else {
    $classes = 'col-xl-6 col-lg-6 col-md-6 col-sm-6';
}
?>

<div class="<?php echo esc_attr( $classes ); ?>">
    <?php
    if ( ! has_post_thumbnail() ) {
        $no_thumbnail = 'no-thumbnail';
    }
    ?>

    <div id="post-<?php the_ID(); ?>" <?php post_class( 'card card-post ' . $no_thumbnail ); ?>>
        <?php if ( has_post_thumbnail() ) : ?>
            <div class="card-top position-relative">
                <a title="<?php the_title_attribute(); ?>" href="<?php echo esc_url( get_permalink() ); ?>">
                    <?php loversy_post_thumbnail(); ?>
                </a>
            </div>
        <?php endif; ?>

        <div class="card-body">
            <?php if ( $blog_page_show_post_author == true || $blog_page_show_post_comments_count == true || $blog_page_show_post_category == true ) : ?>
                <div class="card-meta">
                    <p>
                        <?php if ( $blog_page_show_post_author == true ) : ?>
                            <span><?php loversy_posted_by(); ?></span>
    
                            <?php if ( $blog_page_show_post_comments_count == true || $blog_page_show_post_category == true ) : ?>
                                <span>-</span>
                            <?php endif; ?>
                        <?php endif; ?>
    
                        <?php if ( $blog_page_show_post_comments_count == true ) : ?>
                            <span><?php esc_html_e( 'Comments', 'loversy' ); ?> (<?php loversy_comments_count(); ?>)</span>
    
                            <?php if ( $blog_page_show_post_category == true ) : ?>
                                <span>-</span>
                            <?php endif; ?>
                        <?php endif; ?>
    
                        <?php if ( $blog_page_show_post_category == true ) : ?>
                            <span><?php loversy_post_category(); ?></span>
                        <?php endif; ?>
                    </p>
                </div>
            <?php endif; ?>
            
            <?php if ( true == $blog_page_show_post_title ) : ?>
                <?php the_title( '<h5 class="card-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h5>' ); ?>
            <?php endif; ?>
            
            <?php if ( $blog_page_show_post_excerpt == true ) : ?>
                <p class="card-text"><?php loversy_the_excerpt( 20 ); ?></p>
            <?php endif; ?>
            
            <?php if ( $blog_page_show_post_link == true ) : ?>
                <div class="card-btn no-space">
                    <a title="<?php esc_attr_e( 'Read me', 'loversy' ); ?>" class="btn btn-link btn-line p-0 border-0 min-w-auto text-uppercase before" href="<?php echo esc_url( get_permalink() ); ?>"><?php esc_html_e( 'Read me', 'loversy' ); ?></a>
                </div>
            <?php endif; ?>
        </div>
    </div>
</div>
